@@ -1,5 +1,6 @@
 import { GlBadge } from '@gitlab/ui';
 import $ from 'jquery';
+import fuzzaldrinPlus from 'fuzzaldrin-plus';
 import '~/lib/utils/jquery_at_who';
 import { escape as lodashEscape, sortBy, template, escapeRegExp, memoize } from 'lodash';
 import * as Emoji from '~/emoji';
@@ -9,12 +10,10 @@ import { loadingIconForLegacyJS } from '~/loading_icon_for_legacy_js';
 import { s__, __, sprintf } from '~/locale';
 import { isUserBusy } from '~/set_status_modal/utils';
 import SidebarMediator from '~/sidebar/sidebar_mediator';
+import { currentAssignees, linkedItems } from '~/graphql_shared/issuable_client';
 import { state } from '~/sidebar/components/reviewers/sidebar_reviewers.vue';
-import {
-  ISSUABLE_EPIC,
-  WORK_ITEMS_TYPE_MAP,
-  WORK_ITEM_TYPE_ENUM_EPIC,
-} from '~/work_items/constants';
+import { ISSUABLE_EPIC, NAME_TO_ICON_MAP, WORK_ITEM_TYPE_NAME_EPIC } from '~/work_items/constants';
+import { InternalEvents } from '~/tracking';
 import AjaxCache from './lib/utils/ajax_cache';
 import { spriteIcon } from './lib/utils/common_utils';
 import { newDate } from './lib/utils/datetime_utility';
@@ -23,6 +22,8 @@ import { renderVueComponentForLegacyJS } from './render_vue_component_for_legacy
 
 const USERS_ALIAS = 'users';
 const ISSUES_ALIAS = 'issues';
+const ISSUES_ALTERNATIVE_ALIAS = 'issuesalternative';
+const WORK_ITEMS_ALIAS = 'workitems';
 const MILESTONES_ALIAS = 'milestones';
 const MERGEREQUESTS_ALIAS = 'mergerequests';
 const LABELS_ALIAS = 'labels';
@@ -168,6 +169,8 @@ export const defaultAutocompleteConfig = {
   emojis: true,
   members: true,
   issues: true,
+  issuesAlternative: true,
+  workItems: true,
   mergeRequests: true,
   epics: true,
   iterations: true,
@@ -177,15 +180,29 @@ export const defaultAutocompleteConfig = {
   vulnerabilities: true,
   contacts: true,
   wikis: true,
+  statuses: true,
 };
 
 class GfmAutoComplete {
   constructor(dataSources = {}) {
+    // Ensure that all possible work item paths are included
+    const { page } = document.body.dataset;
+    this.isWorkItemsView =
+      gon.features?.workItemViewForIssues &&
+      (page.includes('groups:work_items') ||
+        page.includes('projects:work_items') ||
+        page.includes('groups:issues') ||
+        page.includes('projects:issues') ||
+        page.includes('groups:epics') ||
+        page.includes('issues:show') ||
+        page.includes('epics:show'));
+
     this.dataSources = dataSources;
     this.cachedData = {};
     this.isLoadingData = {};
     this.previousQuery = undefined;
     this.currentBackendFilterRequestController = null;
+    this.enableExtensibleReferenceFilters = gon.features?.extensibleReferenceFilters ?? false;
   }
 
   setup(input, enableMap = defaultAutocompleteConfig) {
@@ -215,6 +232,10 @@ class GfmAutoComplete {
     if (this.enableMap.emojis) this.setupEmoji($input);
     if (this.enableMap.members) this.setupMembers($input);
     if (this.enableMap.issues) this.setupIssues($input);
+    if (this.enableMap.issuesAlternative && this.enableExtensibleReferenceFilters)
+      this.setupIssuesAlternative($input);
+    if (this.enableMap.workItems && this.enableExtensibleReferenceFilters)
+      this.setupWorkItem($input);
     if (this.enableMap.milestones) this.setupMilestones($input);
     if (this.enableMap.mergeRequests) this.setupMergeRequests($input);
     if (this.enableMap.labels) this.setupLabels($input);
@@ -281,7 +302,7 @@ class GfmAutoComplete {
             tpl += '<%- referencePrefix %>';
           } else {
             [[referencePrefix]] = value.params;
-            if (/^[@%~]/.test(referencePrefix)) {
+            if (/^[@%~"]/.test(referencePrefix)) {
               tpl += '<%- referencePrefix %>';
             } else if (/^[*]/.test(referencePrefix)) {
               // EE-ONLY
@@ -290,7 +311,13 @@ class GfmAutoComplete {
             }
           }
         }
-        return template(tpl, { interpolate: /<%=([\s\S]+?)%>/g })({ referencePrefix });
+
+        // We're post-processing template output to replace `&quot` back to `"`
+        // as that is needed for `/status "` (EE-only) to be inserted correctly.
+        return template(tpl, { interpolate: /<%=([\s\S]+?)%>/g })({ referencePrefix }).replace(
+          /&quot;/g,
+          '"',
+        );
       },
       suffix: '',
       callbacks: {
@@ -453,8 +480,16 @@ class GfmAutoComplete {
           });
 
           // Cache assignees & reviewers list for easier filtering later
-          assignees =
-            SidebarMediator.singleton?.store?.assignees?.map(createMemberSearchString) || [];
+          if (instance.isWorkItemsView) {
+            const element = this.$inputor.get(0).closest('.js-gfm-wrapper');
+            if (element) {
+              const { workItemId } = element.dataset;
+              assignees = (currentAssignees()[`${workItemId}`] || []).map(createMemberSearchString);
+            }
+          } else {
+            assignees =
+              SidebarMediator.singleton?.store?.assignees?.map(createMemberSearchString) || [];
+          }
           reviewers = state.issuable?.reviewers?.nodes?.map(createMemberSearchString) || [];
 
           const match = GfmAutoComplete.defaultMatcher(flag, subtext, this.app.controllers);
@@ -507,6 +542,13 @@ class GfmAutoComplete {
   }
 
   setupIssues($input) {
+    const instance = this;
+    const fetchData = this.fetchData.bind(this);
+    const MEMBER_COMMAND = {
+      UNLINK: '/unlink',
+    };
+    let command = '';
+
     $input.atwho({
       at: '#',
       alias: ISSUES_ALIAS,
@@ -539,11 +581,127 @@ class GfmAutoComplete {
             };
           });
         },
+        matcher(flag, subtext) {
+          const subtextNodes = subtext.split(/\n+/g).pop().split(GfmAutoComplete.regexSubtext);
+
+          // Check if # is followed by '/unlink' command.
+          command = subtextNodes.find((node) => {
+            if (Object.values(MEMBER_COMMAND).includes(node)) {
+              return node;
+            }
+            return null;
+          });
+
+          const match = GfmAutoComplete.defaultMatcher(flag, subtext, this.app.controllers);
+          return match && match.length ? match[1] : null;
+        },
+        filter(query, data) {
+          if (instance.isWorkItemsView && command === MEMBER_COMMAND.UNLINK) {
+            const { workItemFullPath, workItemIid } = this.$inputor
+              .get(0)
+              .closest('.js-gfm-wrapper').dataset;
+
+            // Only include items which are linked to the Issuable currently
+            // if `#` is followed by `/unlink` command.
+            const items = linkedItems()[`${workItemFullPath}:${workItemIid}`] || [];
+            return items.map((item) => ({
+              id: Number(item.iid),
+              title: item.title,
+              reference: item.reference,
+              search: `${item.iid} ${item.title}`,
+              iconName: item.workItemType.iconName,
+            }));
+          }
+
+          if (GfmAutoComplete.isLoading(data) || instance.previousQuery !== query) {
+            instance.previousQuery = query;
+
+            fetchData(this.$inputor, this.at, query);
+            return data;
+          }
+
+          // Return default data
+          return data;
+        },
       },
     });
     showAndHideHelper($input, ISSUES_ALIAS);
   }
 
+  setupIssuesAlternative($input) {
+    $input.atwho({
+      at: '[issue:',
+      alias: ISSUES_ALTERNATIVE_ALIAS,
+      delay: DEFAULT_DEBOUNCE_AND_THROTTLE_MS,
+      searchKey: 'search',
+      displayTpl(value) {
+        let tmpl = GfmAutoComplete.Loading.template;
+        if (value.title != null) {
+          tmpl = GfmAutoComplete.Issues.templateFunction(value);
+        }
+        return tmpl;
+      },
+      data: GfmAutoComplete.defaultLoadingData,
+      insertTpl: GfmAutoComplete.Issues.alternativeReferenceInsertTemplateFunction,
+      skipSpecialCharacterTest: true,
+      callbacks: {
+        ...this.getDefaultCallbacks(),
+        beforeSave(issues) {
+          return $.map(issues, (i) => {
+            if (i.title == null) {
+              return i;
+            }
+            return {
+              id: i.iid,
+              title: i.title,
+              reference: i.reference,
+              search: `${i.iid} ${i.title}`,
+              iconName: i.icon_name,
+            };
+          });
+        },
+      },
+    });
+    showAndHideHelper($input, ISSUES_ALTERNATIVE_ALIAS);
+  }
+
+  setupWorkItem($input) {
+    $input.atwho({
+      at: '[work_item:',
+      alias: WORK_ITEMS_ALIAS,
+      delay: DEFAULT_DEBOUNCE_AND_THROTTLE_MS,
+      searchKey: 'search',
+      displayTpl(value) {
+        let tmpl = GfmAutoComplete.Loading.template;
+        if (value.title != null) {
+          tmpl = GfmAutoComplete.Issues.templateFunction(value);
+        }
+        return tmpl;
+      },
+      data: GfmAutoComplete.defaultLoadingData,
+      insertTpl: GfmAutoComplete.Issues.alternativeReferenceInsertTemplateFunction,
+      skipSpecialCharacterTest: true,
+      callbacks: {
+        ...this.getDefaultCallbacks(),
+        beforeSave(workItems) {
+          return $.map(workItems, (w) => {
+            if (w.title == null) {
+              return w;
+            }
+            return {
+              id: w.iid,
+              title: w.title,
+              reference: w.reference,
+              search: `${w.iid} ${w.title}`,
+              iconName: w.icon_name,
+            };
+          });
+        },
+      },
+    });
+    showAndHideHelper($input, WORK_ITEMS_ALIAS);
+  }
+
   setupMilestones($input) {
     $input.atwho({
       at: '%',
@@ -664,7 +822,7 @@ class GfmAutoComplete {
       },
       // eslint-disable-next-line no-template-curly-in-string
       insertTpl: '${atwho-at}${title}',
-      limit: 20,
+      limit: 100,
       callbacks: {
         ...this.getDefaultCallbacks(),
         beforeSave(merges) {
@@ -732,6 +890,20 @@ class GfmAutoComplete {
 
           return data;
         },
+        sorter(query, items) {
+          this.setting.highlightFirst =
+            this.setting.alwaysHighlightFirst || query.trim().length > 0;
+          if (GfmAutoComplete.isLoading(items)) {
+            this.setting.highlightFirst = false;
+            return items;
+          }
+
+          if (query.trim()) {
+            return fuzzaldrinPlus.filter(items, query, { key: 'title' });
+          }
+
+          return items;
+        },
       },
     });
     showAndHideHelper($input, LABELS_ALIAS);
@@ -958,6 +1130,10 @@ class GfmAutoComplete {
     this.isLoadingData[at] = true;
     const dataSource = this.dataSources[GfmAutoComplete.atTypeMap[at]];
 
+    if (GfmAutoComplete.atTypeMap[at] === 'wikis') {
+      InternalEvents.trackEvent('trigger_autocomplete_for_wiki_links');
+    }
+
     if (GfmAutoComplete.isTypeWithBackendFiltering(at)) {
       if (this.cachedData[at]?.[search]) {
         this.loadData($input, at, this.cachedData[at][search], { search });
@@ -1096,6 +1272,8 @@ GfmAutoComplete.atTypeMap = {
   ':': 'emojis',
   '@': 'members',
   '#': 'issues',
+  '[issue:': 'issues',
+  '[work_item:': 'issues',
   '!': 'mergeRequests',
   '&': 'epics',
   '*iteration:': 'iterations',
@@ -1187,9 +1365,13 @@ GfmAutoComplete.Issues = {
     // eslint-disable-next-line no-template-curly-in-string
     return value.reference || '${atwho-at}${id}';
   },
+  alternativeReferenceInsertTemplateFunction(value) {
+    // eslint-disable-next-line no-template-curly-in-string
+    return value.reference || '#${id}';
+  },
   templateFunction({ id, title, reference, iconName }) {
     const mappedIconName =
-      iconName === ISSUABLE_EPIC ? WORK_ITEMS_TYPE_MAP[WORK_ITEM_TYPE_ENUM_EPIC].icon : iconName;
+      iconName === ISSUABLE_EPIC ? NAME_TO_ICON_MAP[WORK_ITEM_TYPE_NAME_EPIC] : iconName;
     const icon = mappedIconName
       ? spriteIcon(mappedIconName, 'gl-fill-icon-subtle s16 gl-mr-2')
       : '';
@@ -1227,7 +1409,7 @@ const loadingSpinner = loadingIconForLegacyJS({
 }).outerHTML;
 
 GfmAutoComplete.Loading = {
-  template: `<li style="pointer-events: none;">${loadingSpinner}Loading...</li>`,
+  template: `<li style="pointer-events: none;">${loadingSpinner}Loading…</li>`,
 };
 
 export default GfmAutoComplete;
