@@ -151,20 +151,6 @@ module MergeRequestsHelper
     end
   end
 
-  def user_merge_requests_counts
-    @user_merge_requests_counts ||= begin
-      assigned_count = assigned_issuables_count(:merge_requests)
-      review_requested_count = review_requested_merge_requests_count
-      total_count = assigned_count + review_requested_count
-
-      {
-        assigned: assigned_count,
-        review_requested: review_requested_count,
-        total: total_count
-      }
-    end
-  end
-
   def reviewers_label(merge_request, include_value: true)
     reviewers = merge_request.reviewers
 
@@ -184,6 +170,10 @@ module MergeRequestsHelper
     Feature.enabled?(:notifications_todos_buttons, current_user)
   end
 
+  def can_use_description_composer(_user, _merge_request)
+    false
+  end
+
   def diffs_tab_pane_data(project, merge_request, params)
     {
       "is-locked": merge_request.discussion_locked?,
@@ -225,12 +215,10 @@ module MergeRequestsHelper
   def how_merge_modal_data(merge_request)
     {
       is_fork: merge_request.for_fork?.to_s,
-      can_merge: merge_request.can_be_merged_by?(current_user).to_s,
       source_branch: merge_request.source_branch,
       source_project_path: merge_request.source_project&.path,
       source_project_full_path: merge_request.source_project&.full_path,
       source_project_default_url: merge_request.source_project && default_url_to_repo(merge_request.source_project),
-      target_branch: merge_request.target_branch,
       reviewing_docs_path: help_page_path(
         'user/project/merge_requests/merge_request_troubleshooting.md',
         anchor: "check-out-merge-requests-locally-through-the-head-ref"
@@ -274,6 +262,7 @@ module MergeRequestsHelper
     merge_project = merge_request_source_project_for_project(project)
 
     common_merge_request_list_data(current_user).merge({
+      namespace_id: project.id,
       full_path: project.full_path,
       has_any_merge_requests: project_merge_requests(project).exists?.to_s,
       new_merge_request_path: merge_project && project_new_merge_request_path(merge_project),
@@ -287,20 +276,9 @@ module MergeRequestsHelper
     })
   end
 
-  def project_merge_requests_list_more_actions_data(project, current_user)
-    {
-      is_signed_in: current_user.present?.to_s,
-      issuable_type: :merge_request,
-      issuable_count: issuables_count_for_state(:merge_request, params[:state]),
-      email: current_user.present? ? current_user.notification_email_or_default : nil,
-      export_csv_path: export_csv_project_merge_requests_path(project, request.query_parameters),
-      rss_url: url_for(safe_params.merge(rss_url_options))
-    }
-  end
-
   def group_merge_requests_list_data(group, current_user)
     common_merge_request_list_data(current_user).merge({
-      group_id: group.id,
+      namespace_id: group.id,
       full_path: group.full_path,
       show_new_resource_dropdown: (current_user.presence && any_projects?(@projects)).to_s,
       has_any_merge_requests: group_merge_requests(group).exists?.to_s,
@@ -329,6 +307,7 @@ module MergeRequestsHelper
       isFluidLayout: fluid_layout.to_s,
       blocksMerge: project.only_allow_merge_if_all_discussions_are_resolved?.to_s,
       imported: merge_request.imported?.to_s,
+      isDraft: merge_request.draft.to_s,
       tabs: [
         [
           'show',
@@ -369,10 +348,6 @@ module MergeRequestsHelper
 
   private
 
-  def review_requested_merge_requests_count
-    current_user.review_requested_open_merge_requests_count
-  end
-
   def default_suggestion_commit_message(project)
     project.suggestion_commit_message.presence || Gitlab::Suggestions::CommitMessage::DEFAULT_SUGGESTION_COMMIT_MESSAGE
   end
@@ -415,12 +390,12 @@ module MergeRequestsHelper
     link_to branch,
       branch_path,
       title: branch_title,
-      class: 'ref-container gl-inline-block gl-truncate gl-max-w-26 gl-ml-2'
+      class: 'ref-container gl-inline-block gl-truncate gl-max-w-26 gl-ml-2 gl-shrink-0'
   end
 
   def merge_request_header(merge_request)
     link_to_author = link_to_member(merge_request.author, size: 24, extra_class: 'gl-font-bold gl-mr-2', avatar: false)
-    target_branch_class = "ref-container gl-inline-block gl-truncate gl-max-w-26"
+    target_branch_class = "ref-container gl-inline-block gl-truncate gl-max-w-26 gl-shrink-0"
     copy_action_description = _('Copy branch name')
     copy_action_shortcut = 'b'
     copy_button_title = "#{copy_action_description} <kbd class='flat ml-1' " \
@@ -458,7 +433,9 @@ module MergeRequestsHelper
       copy_button: copy_button.html_safe,
       target_branch: target_branch.html_safe,
       target_copy_button: " ",
-      created_at: time_ago_with_tooltip(merge_request.created_at, html_class: 'gl-inline-block').html_safe
+      created_at: time_ago_with_tooltip(merge_request.created_at, html_class: 'gl-inline-block').html_safe,
+      author_container_start: '<div class="merge-request-author-container">'.html_safe,
+      author_container_end: '</div>'.html_safe
     }
 
     if @project.default_branch != merge_request.target_branch
@@ -466,7 +443,7 @@ module MergeRequestsHelper
     end
 
     safe_format(_(
-      '%{author} requested to merge %{source_branch} %{copy_button} ' \
+      '%{author_container_start}%{author}requested to merge %{author_container_end}%{source_branch} %{copy_button} ' \
         'into %{target_branch} %{target_copy_button} %{created_at}'
     ), copy_button_data)
   end
@@ -485,7 +462,110 @@ module MergeRequestsHelper
     { new_comment_template_paths: new_comment_template_paths(@project.group, @project).to_json }
   end
 
+  def merge_request_dashboard_role_based_data
+    {
+      tabs: [
+        {
+          title: s_('MergeRequestsTab|Active'),
+          key: '',
+          lists: [
+            [
+              {
+                id: 'reviews',
+                title: _('Reviewer (Active)'),
+                helpContent: _('Merge requests awaiting your review.'),
+                query: 'reviewRequestedMergeRequests',
+                variables: {
+                  reviewStates: %w[UNREVIEWED REVIEW_STARTED UNAPPROVED],
+                  perPage: 10
+                }
+              },
+              {
+                id: 'reviews_inactive',
+                title: _('Reviewer (Inactive)'),
+                hideCount: true,
+                helpContent: _("Merge requests you've reviewed."),
+                query: 'reviewRequestedMergeRequests',
+                variables: {
+                  reviewStates: %w[APPROVED REQUESTED_CHANGES REVIEWED],
+                  perPage: 10
+                }
+              },
+              {
+                id: 'assigned',
+                title: _('Your merge requests (Active)'),
+                helpContent: _(
+                  "Your merge requests that need reviewers assigned, " \
+                    "or has feedback to address."
+                ),
+                query: 'authorOrAssigneeMergeRequests',
+                variables: {
+                  or: {
+                    reviewerWildcard: "NONE",
+                    onlyReviewerUsername: duo_code_review_bot.username,
+                    reviewStates: %w[REVIEWED REQUESTED_CHANGES]
+                  },
+                  perPage: 10
+                }
+              },
+              {
+                id: 'assigned_inactive',
+                title: _('Your merge requests (Inactive)'),
+                hideCount: true,
+                helpContent: _(
+                  "Your merge requests awaiting approvals, " \
+                    "or has been approved by all assigned reviewers."
+                ),
+                query: 'authorOrAssigneeMergeRequests',
+                variables: {
+                  reviewStates: %w[APPROVED UNAPPROVED UNREVIEWED REVIEW_STARTED],
+                  not: {
+                    reviewStates: %w[REQUESTED_CHANGES REVIEWED]
+                  },
+                  ignoredReviewerUsername: duo_code_review_bot.username,
+                  perPage: 10
+                }
+              }
+            ]
+          ]
+        },
+        {
+          title: s_('MergeRequestsTab|Merged'),
+          key: 'merged',
+          lists: [
+            [
+              {
+                id: 'merged_recently_reviews',
+                title: _('Reviews'),
+                helpContent: _('Your review requests that have been merged.'),
+                query: 'reviewRequestedMergeRequests',
+                variables: {
+                  state: 'merged',
+                  mergedAfter: 2.weeks.ago.to_time.iso8601,
+                  sort: 'MERGED_AT_DESC'
+                }
+              },
+              {
+                id: 'merged_recently_assigned',
+                title: _('Assigned'),
+                helpContent: _('Your merge requests that have been merged.'),
+                query: 'authorOrAssigneeMergeRequests',
+                variables: {
+                  state: 'merged',
+                  mergedAfter: 2.weeks.ago.to_time.iso8601,
+                  sort: 'MERGED_AT_DESC'
+                }
+              }
+            ]
+          ]
+        }
+      ]
+    }
+  end
+
   def merge_request_dashboard_data
+    return merge_request_dashboard_role_based_data if current_user.user_preference.role_based?
+
     {
       tabs: [
         {
@@ -497,9 +577,10 @@ module MergeRequestsHelper
                 id: 'returned_to_you',
                 title: _('Returned to you'),
                 helpContent: _('Reviewers left feedback, or requested changes from you, on these merge requests.'),
-                query: 'assignedMergeRequests',
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
-                  reviewStates: %w[REVIEWED REQUESTED_CHANGES]
+                  reviewStates: %w[REVIEWED REQUESTED_CHANGES],
+                  ignoredReviewerUsername: duo_code_review_bot.username
                 }
               },
               {
@@ -513,22 +594,25 @@ module MergeRequestsHelper
               },
               {
                 id: 'assigned_to_you',
-                title: _('Assigned to you'),
-                helpContent: _("You're assigned to these merge requests, but they don't have reviewers yet."),
-                query: 'assignedMergeRequests',
+                title: _('Your merge requests'),
+                helpContent: _("Merge requests you authored or are assigned to, without reviewers."),
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
-                  reviewerWildcardId: 'NONE'
+                  or: {
+                    reviewerWildcard: 'NONE',
+                    onlyReviewerUsername: duo_code_review_bot.username
+                  }
                 }
               }
             ],
             [
               {
                 id: 'waiting_for_assignee',
-                title: _('Waiting for assignee'),
+                title: _('Waiting for author or assignee'),
                 hideCount: true,
                 helpContent: _(
-                  'Your assigned merge requests that are waiting for approvals, ' \
-                    'and reviews you have requested changes for.'
+                  "Your reviews you've requested changes for " \
+                    "or commented on."
                 ),
                 query: 'reviewRequestedMergeRequests',
                 variables: {
@@ -539,12 +623,10 @@ module MergeRequestsHelper
                 id: 'waiting_for_approvals',
                 title: _('Waiting for approvals'),
                 hideCount: true,
-                helpContent: _(
-                  'Your assigned merge requests that are waiting for approvals, ' \
-                    'and reviews you have requested changes for.'
-                ),
-                query: 'assignedMergeRequests',
+                helpContent: _('Your merge requests that are waiting for approvals.'),
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
+                  ignoredReviewerUsername: duo_code_review_bot.username,
                   reviewStates: %w[UNREVIEWED UNAPPROVED REVIEW_STARTED],
                   not: {
                     reviewStates: %w[REQUESTED_CHANGES REVIEWED]
@@ -565,9 +647,10 @@ module MergeRequestsHelper
                 id: 'approved_by_others',
                 title: _('Approved by others'),
                 hideCount: true,
-                helpContent: _('Includes all merge requests you are assigned to and a reviewer has approved.'),
-                query: 'assignedMergeRequests',
+                helpContent: _('Your merge requests with approvals by all assigned reviewers.'),
+                query: 'authorOrAssigneeMergeRequests',
                 variables: {
+                  ignoredReviewerUsername: duo_code_review_bot.username,
                   reviewState: 'APPROVED',
                   not: {
                     reviewStates: %w[REQUESTED_CHANGES REVIEWED UNREVIEWED REVIEW_STARTED UNAPPROVED]
@@ -585,7 +668,7 @@ module MergeRequestsHelper
               id: 'merged_recently',
               title: _('Merged recently'),
               helpContent: _('These merge requests merged after %{date}. You were an assignee or a reviewer.') % {
-                date: 2.weeks.ago.to_date.to_formatted_s(:long)
+                date: l(2.weeks.ago.to_date, format: :long)
               },
               query: 'assigneeOrReviewerMergeRequests',
               variables: {
@@ -599,6 +682,19 @@ module MergeRequestsHelper
       ]
     }
   end
+
+  def dashboard_list_title(list_id)
+    merge_request_dashboard_data[:tabs]
+      .flat_map { |tab| tab[:lists] }
+      .flatten
+      .find { |list| list[:id] == list_id }
+      &.dig(:title) || ''
+  end
+
+  def duo_code_review_bot
+    ::Users::Internal.duo_code_review_bot
+  end
+  strong_memoize_attr :duo_code_review_bot
 end
 
 MergeRequestsHelper.prepend_mod_with('MergeRequestsHelper')
