@@ -11,7 +11,6 @@ module SearchHelper
     :snippets,
     :sort,
     :force_search_results,
-    :project_ids,
     :type
   ].freeze
 
@@ -162,11 +161,6 @@ module SearchHelper
     params[:repository_ref].to_s.presence || project.default_branch
   end
 
-  # Overridden in EE
-  def search_blob_title(_project, path)
-    path
-  end
-
   def search_service
     @search_service ||= ::SearchService.new(current_user, params)
   end
@@ -310,8 +304,9 @@ module SearchHelper
       { category: "Help", label: _("Markdown Help"),                url: help_page_path("user/markdown.md") },
       { category: "Help", label: _("Permissions Help"),             url: help_page_path("user/permissions.md") },
       { category: "Help", label: _("Public Access Help"),           url: help_page_path("user/public_access.md") },
-      { category: "Help", label: _("Rake Tasks Help"),              url: help_page_path("raketasks/_index.md") },
-      { category: "Help", label: _("SSH Keys Help"),                url: help_page_path("user/ssh.md") },
+      { category: "Help", label: _("Rake Tasks Help"),
+        url: help_page_path("administration/raketasks/_index.md") },
+      { category: "Help", label: _("SSH Keys Help"), url: help_page_path("user/ssh.md") },
       {
         category: "Help",
         label: s_("Webhooks|System hooks help"),
@@ -403,15 +398,11 @@ module SearchHelper
 
   # Autocomplete results for the current user's projects
   def projects_autocomplete(term, limit = 5)
-    projects = if Feature.enabled?(:autocomplete_projects_use_search_service, current_user)
-                 search_using_search_service(current_user, 'projects', term, limit)
-               else
-                 current_user.authorized_projects.order_id_desc.search(
-                   term,
-                   include_namespace: true,
-                   use_minimum_char_limit: false
-                 ).sorted_by_stars_desc.non_archived.limit(limit)
-               end
+    projects = current_user.authorized_projects.order_id_desc.search(
+      term,
+      include_namespace: true,
+      use_minimum_char_limit: false
+    ).sorted_by_stars_desc.non_archived.limit(limit)
 
     projects.map do |p|
       {
@@ -480,29 +471,6 @@ module SearchHelper
     Sanitize.clean(str)
   end
 
-  def search_filter_link(scope, label, data: {}, search: {})
-    search_params = params
-      .merge(search)
-      .merge({ scope: scope })
-      .permit(SEARCH_GENERIC_PARAMS)
-
-    if @scope == scope
-      li_class = 'active'
-      count = formatted_count(scope)
-    else
-      badge_class = 'js-search-count hidden'
-      badge_data = { url: search_count_path(search_params) }
-    end
-
-    content_tag :li, class: li_class, data: data do
-      link_to search_path(search_params) do
-        concat label
-        concat ' '
-        concat gl_badge_tag(count, { class: badge_class, data: badge_data })
-      end
-    end
-  end
-
   def active_nav?(active_scope, active_type, type)
     return active_scope unless @scope.to_s == 'issues'
     return active_type if type
