@@ -56,9 +56,6 @@ class Issue < ApplicationRecord
   # This default came from the enum `issue_type` column. Defined as default in the DB
   DEFAULT_ISSUE_TYPE = :issue
 
-  # prevent caching this column by rails, as we want to easily remove it after the backfilling
-  ignore_column :tmp_epic_id, remove_with: '16.11', remove_after: '2024-03-31'
-
   # Interim columns to convert integer IDs to bigint
   ignore_column :author_id_convert_to_bigint, remove_with: '17.8', remove_after: '2024-12-13'
   ignore_column :closed_by_id_convert_to_bigint, remove_with: '17.8', remove_after: '2024-12-13'
@@ -70,7 +67,8 @@ class Issue < ApplicationRecord
   ignore_column :project_id_convert_to_bigint, remove_with: '17.8', remove_after: '2024-12-13'
   ignore_column :promoted_to_epic_id_convert_to_bigint, remove_with: '17.8', remove_after: '2024-12-13'
   ignore_column :updated_by_id_convert_to_bigint, remove_with: '17.8', remove_after: '2024-12-13'
-  ignore_column :correct_work_item_type_id, remove_with: '18.0', remove_after: '2025-04-17'
+
+  ignore_column :external_key, remove_with: '18.5', remove_after: '2025-09-18'
 
   belongs_to :project
   belongs_to :namespace, inverse_of: :issues
@@ -126,7 +124,7 @@ class Issue < ApplicationRecord
     inverse_of: :work_item,
     autosave: true
 
-  alias_attribute :escalation_status, :incident_management_issuable_escalation_status
+  alias_method :escalation_status, :incident_management_issuable_escalation_status
 
   accepts_nested_attributes_for :issuable_severity, update_only: true
   accepts_nested_attributes_for :sentry_issue
@@ -152,7 +150,14 @@ class Issue < ApplicationRecord
   scope :in_projects, ->(project_ids) { where(project_id: project_ids) }
   scope :not_in_projects, ->(project_ids) { where.not(project_id: project_ids) }
 
-  scope :non_archived, -> { left_joins(:project).where(project_id: nil).or(where(projects: { archived: false })) }
+  scope :join_project_through_namespace, -> do
+    joins("JOIN projects ON projects.project_namespace_id = issues.namespace_id")
+  end
+
+  scope :non_archived, ->(use_existing_join: false) do
+    relation = use_existing_join ? self : left_joins(:project)
+    relation.where(project_id: nil).or(relation.where(projects: { archived: false }))
+  end
 
   scope :with_due_date, -> { where.not(due_date: nil) }
   scope :without_due_date, -> { where(due_date: nil) }
@@ -163,8 +168,13 @@ class Issue < ApplicationRecord
 
   scope :not_authored_by, ->(user) { where.not(author_id: user) }
 
+  # N.B. The start_date and due_date columns are preserved on the issues table to enable performant sorting by these
+  # dates, since we would otherwise need to perform a join for the sort. These are synced via the DB trigger
+  # sync_issues_dates_with_work_item_dates_sources() from the work_item_dates_sources table
   scope :order_due_date_asc, -> { reorder(arel_table[:due_date].asc.nulls_last) }
   scope :order_due_date_desc, -> { reorder(arel_table[:due_date].desc.nulls_last) }
+  scope :order_start_date_asc, -> { reorder(arel_table[:start_date].asc.nulls_last) }
+  scope :order_start_date_desc, -> { reorder(arel_table[:start_date].desc.nulls_last) }
   scope :order_closest_future_date, -> { reorder(Arel.sql("CASE WHEN issues.due_date >= CURRENT_DATE THEN 0 ELSE 1 END ASC, ABS(CURRENT_DATE - issues.due_date) ASC")) }
   scope :order_created_at_desc, -> { reorder(created_at: :desc) }
   scope :order_severity_asc, -> do
@@ -189,8 +199,6 @@ class Issue < ApplicationRecord
   scope :order_escalation_status_desc, -> { includes(:incident_management_issuable_escalation_status).order(IncidentManagement::IssuableEscalationStatus.arel_table[:status].desc.nulls_last).references(:incident_management_issuable_escalation_status) }
   scope :order_closed_at_asc, -> { reorder(arel_table[:closed_at].asc.nulls_last) }
   scope :order_closed_at_desc, -> { reorder(arel_table[:closed_at].desc.nulls_last) }
-  scope :order_start_date_asc, -> { left_joins(:dates_source).order(WorkItems::DatesSource.arel_table[:start_date].asc.nulls_last) }
-  scope :order_start_date_desc, -> { left_joins(:dates_source).order(WorkItems::DatesSource.arel_table[:start_date].desc.nulls_last) }
 
   scope :preload_associated_models, -> { preload(:assignees, :labels, project: :namespace) }
   scope :with_web_entity_associations, -> do
@@ -200,6 +208,8 @@ class Issue < ApplicationRecord
   scope :preload_awardable, -> { preload(:award_emoji) }
   scope :preload_namespace, -> { preload(:namespace) }
   scope :preload_routables, -> { preload(project: [:route, { namespace: :route }]) }
+  scope :preload_namespace_routables, -> { preload(namespace: [:route, { parent: :route }]) }
+  scope :preload_for_rss, -> { preload(:author, :assignees, :labels, :milestone, :work_item_type, :project, { project: :namespace }) }
 
   scope :with_alert_management_alerts, -> { joins(:alert_management_alert) }
   scope :with_api_entity_associations, -> {
@@ -211,19 +221,18 @@ class Issue < ApplicationRecord
     )
   }
   scope :with_issue_type, ->(types) {
-    types = Array(types)
+    type_ids = Array(types).filter_map do |type|
+      WorkItems::Type::BASE_TYPES.dig(type.to_sym, :id)
+    end
 
-    # Using != 1 since we also want the guard clause to handle empty arrays
-    return joins(:work_item_type).where(work_item_types: { base_type: types }) if types.size != 1
-
-    # This optimization helps the planer use the correct indexes when filtering by a single type
-    where(
-      '"issues"."work_item_type_id" = (?)',
-      WorkItems::Type.by_type(types.first).select(:id).limit(1)
-    )
+    where(work_item_type_id: type_ids)
   }
   scope :without_issue_type, ->(types) {
-    joins(:work_item_type).where.not(work_item_types: { base_type: types })
+    type_ids = Array(types).filter_map do |type|
+      WorkItems::Type::BASE_TYPES.dig(type.to_sym, :id)
+    end
+
+    where.not(work_item_type_id: type_ids)
   }
 
   scope :public_only, -> { where(confidential: false) }
@@ -231,7 +240,9 @@ class Issue < ApplicationRecord
   scope :confidential_only, -> { where(confidential: true) }
 
   scope :without_hidden, -> {
-    where('NOT EXISTS (?)', Users::BannedUser.select(1).where('issues.author_id = banned_users.user_id'))
+    # We add `+ 0` to the author_id to make the query planner use a nested loop and prevent
+    # loading of all banned user IDs for certain queries
+    where_not_exists(Users::BannedUser.where('banned_users.user_id = (issues.author_id + 0)'))
   }
 
   scope :counts_by_state, -> { reorder(nil).group(:state_id).count }
@@ -326,6 +337,13 @@ class Issue < ApplicationRecord
       where('issues.namespace_id IN (SELECT id FROM namespace_ids)').with(cte.to_arel)
     end
 
+    def with_accessible_sub_namespace_ids_cte(namespace_ids)
+      # Using materialized: true to ensure the CTE is computed once and reused, which significantly improves performance
+      # for complex queries. See: https://gitlab.com/gitlab-org/gitlab/-/issues/548094
+      accessible_sub_namespace_ids = Gitlab::SQL::CTE.new(:accessible_sub_namespace_ids, namespace_ids, materialized: true)
+      with(accessible_sub_namespace_ids.to_arel)
+    end
+
     override :order_upvotes_desc
     def order_upvotes_desc
       reorder(upvotes_count: :desc)
@@ -355,12 +373,6 @@ class Issue < ApplicationRecord
     [:assignees] + super
   end
 
-  def work_item_type_id=(input_work_item_type_id)
-    work_item_type = WorkItems::Type.find_by_id_with_fallback(input_work_item_type_id)
-
-    super(work_item_type&.id)
-  end
-
   def next_object_by_relative_position(ignoring: nil, order: :asc)
     array_mapping_scope = ->(id_expression) do
       relation = Issue.where(Issue.arel_table[:project_id].eq(id_expression))
@@ -403,20 +415,40 @@ class Issue < ApplicationRecord
   # Alternative prefix for situations where the standard prefix would be
   # interpreted as a comment, most notably to begin commit messages with
   # (e.g. "GL-123: My commit")
-  def self.alternative_reference_prefix
+  def self.alternative_reference_prefix_without_postfix
     'GL-'
   end
 
-  # Pattern used to extract `#123` issue references from text
-  #
+  def self.alternative_reference_prefix_with_postfix
+    '[issue:'
+  end
+
+  def self.reference_postfix
+    ']'
+  end
+
+  # Pattern used to extract issue references from text
   # This pattern supports cross-project references.
   def self.reference_pattern
-    @reference_pattern ||= %r{
+    prefix_with_postfix = alternative_reference_prefix_with_postfix
+    if prefix_with_postfix.empty?
+      @reference_pattern ||= %r{
       (?:
         (#{Project.reference_pattern})?#{Regexp.escape(reference_prefix)} |
-        #{Regexp.escape(alternative_reference_prefix)}
+        #{Regexp.escape(alternative_reference_prefix_without_postfix)}
       )#{Gitlab::Regex.issue}
     }x
+    else
+      %r{
+    ((?:
+      (#{Project.reference_pattern})?#{Regexp.escape(reference_prefix)} |
+      #{alternative_reference_prefix_without_postfix}
+    )#{Gitlab::Regex.issue}) |
+    ((?:
+      #{Regexp.escape(prefix_with_postfix)}(#{Project.reference_pattern}/)?
+    )#{Gitlab::Regex.issue(reference_postfix)})
+  }x
+    end
   end
 
   def self.link_reference_pattern
@@ -450,6 +482,8 @@ class Issue < ApplicationRecord
     when 'closest_future_date', 'closest_future_date_asc' then order_closest_future_date
     when 'due_date', 'due_date_asc'                       then order_due_date_asc.with_order_id_desc
     when 'due_date_desc'                                  then order_due_date_desc.with_order_id_desc
+    when 'start_date', 'start_date_asc'                   then order_start_date_asc.with_order_id_desc
+    when 'start_date_desc'                                then order_start_date_desc.with_order_id_desc
     when 'relative_position', 'relative_position_asc'     then order_by_relative_position
     when 'severity_asc'                                   then order_severity_asc
     when 'severity_desc'                                  then order_severity_desc
@@ -457,8 +491,6 @@ class Issue < ApplicationRecord
     when 'escalation_status_desc'                         then order_escalation_status_desc
     when 'closed_at', 'closed_at_asc'                     then order_closed_at_asc
     when 'closed_at_desc'                                 then order_closed_at_desc
-    when 'start_date', 'start_date_asc'                   then order_start_date_asc
-    when 'start_date_desc'                                then order_start_date_desc
     else
       super
     end
@@ -510,6 +542,17 @@ class Issue < ApplicationRecord
     branch_name
   end
 
+  def self.supported_keyset_orderings
+    {
+      id: [:asc, :desc],
+      title: [:asc, :desc],
+      created_at: [:asc, :desc],
+      updated_at: [:asc, :desc],
+      due_date: [:asc, :desc],
+      relative_position: [:asc, :desc]
+    }
+  end
+
   # Temporary disable moving null elements because of performance problems
   # For more information check https://gitlab.com/gitlab-com/gl-infra/production/-/issues/4321
   def check_repositioning_allowed!
@@ -608,16 +651,6 @@ class Issue < ApplicationRecord
     !self.closed? && !self.project.forked?
   end
 
-  # Returns `true` if the current issue can be viewed by either a logged in User
-  # or an anonymous user.
-  def visible_to_user?(user = nil)
-    return publicly_visible? unless user
-    return true if user.can_read_all_resources?
-    return readable_by?(user) unless project
-
-    readable_by?(user) && access_allowed_for_project_with_external_authorization?(user, project)
-  end
-
   # Always enforce spam check for support bot but allow for other users when issue is not publicly visible
   def allow_possible_spam?(user)
     return true if Gitlab::CurrentSettings.allow_possible_spam
@@ -654,12 +687,10 @@ class Issue < ApplicationRecord
   end
 
   # rubocop: disable CodeReuse/ServiceClass
-  def update_project_counter_caches
-    # TODO: Fix counter cache for issues in group
-    # TODO: see https://gitlab.com/gitlab-org/gitlab/-/work_items/393125
+  def invalidate_project_counter_caches
     return unless project
 
-    Projects::OpenIssuesCountService.new(project).refresh_cache
+    Projects::OpenIssuesCountService.new(project).delete_cache
   end
   # rubocop: enable CodeReuse/ServiceClass
 
@@ -729,23 +760,6 @@ class Issue < ApplicationRecord
     self.update_column(:upvotes_count, self.upvotes)
   end
 
-  # Returns `true` if the given User can read the current Issue.
-  #
-  # This method duplicates the same check of issue_policy.rb
-  # for performance reasons, check commit: 002ad215818450d2cbbc5fa065850a953dc7ada8
-  # Make sure to sync this method with issue_policy.rb
-  def readable_by?(user)
-    if user.can_read_all_resources?
-      true
-    elsif hidden?
-      false
-    elsif project
-      project_level_readable_by?(user)
-    else
-      group_level_readable_by?(user)
-    end
-  end
-
   def hidden?
     author&.banned?
   end
@@ -827,40 +841,6 @@ class Issue < ApplicationRecord
 
   private
 
-  def project_level_readable_by?(user)
-    if !project.issues_enabled?
-      false
-    elsif project.personal? && project.team.owner?(user)
-      true
-    elsif confidential? && !assignee_or_author?(user)
-      project.member?(user, Gitlab::Access::PLANNER)
-    elsif project.public? || (project.internal? && !user.external?)
-      project.feature_available?(:issues, user)
-    else
-      project.member?(user)
-    end
-  end
-
-  def group_level_readable_by?(user)
-    # This should never happen as we don't support personal namespace level issues. Just additional safety.
-    return false unless namespace.is_a?(::Group)
-
-    if confidential? && !assignee_or_author?(user)
-      namespace.member?(user, Gitlab::Access::PLANNER)
-    else
-      namespace.member?(user)
-    end
-  end
-
-  def access_allowed_for_project_with_external_authorization?(user, project)
-    return false if project.blank?
-
-    ::Gitlab::ExternalAuthorization.access_allowed?(
-      user,
-      project.external_authorization_classification_label
-    )
-  end
-
   def due_date_after_start_date
     return unless start_date.present? && due_date.present?
 
