@@ -4,7 +4,7 @@ module Packages
   module Maven
     class CreatePackageService < ::Packages::CreatePackageService
       def execute
-        return ERROR_RESPONSE_PACKAGE_PROTECTED if package_protected?
+        return ERROR_RESPONSE_PACKAGE_PROTECTED if package_protected?(package_name: params[:name], package_type: :maven)
 
         app_group, _, app_name = params[:name].rpartition('/')
         app_group.tr!('/', '.')
@@ -19,19 +19,16 @@ module Packages
         )
 
         ServiceResponse.success(payload: { package: package })
-      rescue ActiveRecord::RecordInvalid => e
-        reason = e.record&.errors&.of_kind?(:name, :taken) ? :name_taken : :invalid_parameter
+      rescue ActiveRecord::RecordInvalid, ActiveRecord::RecordNotUnique => e
+        reason = case e
+                 when ActiveRecord::RecordNotUnique
+                   :name_taken
+                 when ActiveRecord::RecordInvalid
+                   e.record.errors&.of_kind?(:name, :taken) ? :name_taken : :invalid_parameter
+                 end
 
         ServiceResponse.error(message: e.message, reason: reason)
       end
-
-      private
-
-      def package_protected?
-        return false if Feature.disabled?(:packages_protected_packages_maven, project)
-
-        super(package_name: params[:name], package_type: :maven)
-      end
     end
   end
 end
