@@ -41,7 +41,7 @@ module Gitlab
     config.active_support.executor_around_test_case = nil # New default is true
     config.active_support.isolation_level = nil # New default is thread
     config.active_support.key_generator_hash_digest_class = nil # New default is OpenSSL::Digest::SHA256
-    config.active_support.cache_format_version = nil
+    config.active_support.cache_format_version = 7.1
 
     # Rails 6.1
     config.action_dispatch.cookies_same_site_protection = nil # New default is :lax
@@ -82,18 +82,13 @@ module Gitlab
     require_dependency Rails.root.join('lib/gitlab/middleware/handle_malformed_strings')
     require_dependency Rails.root.join('lib/gitlab/middleware/path_traversal_check')
     require_dependency Rails.root.join('lib/gitlab/middleware/rack_multipart_tempfile_factory')
+    require_dependency Rails.root.join('lib/gitlab/middleware/secure_headers')
     require_dependency Rails.root.join('lib/gitlab/runtime')
     require_dependency Rails.root.join('lib/gitlab/patch/database_config')
     require_dependency Rails.root.join('lib/gitlab/patch/redis_cache_store')
-    require_dependency Rails.root.join('lib/gitlab/patch/old_redis_cache_store')
+    require_dependency Rails.root.join('lib/gitlab/pdf')
     require_dependency Rails.root.join('lib/gitlab/exceptions_app')
 
-    unless ::Gitlab.next_rails?
-      config.active_support.disable_to_s_conversion = false # New default is true
-      config.active_support.use_rfc4122_namespaced_uuids = true
-      ActiveSupport.to_time_preserves_timezone = false
-    end
-
     config.exceptions_app = Gitlab::ExceptionsApp.new(Gitlab.jh? ? Rails.root.join('jh/public') : Rails.public_path)
 
     # This preload is required to:
@@ -124,12 +119,7 @@ module Gitlab
 
     config.generators.templates.push("#{config.root}/generator_templates")
 
-    foss_eager_load_paths =
-      if Gitlab.next_rails?
-        config.all_eager_load_paths.dup.freeze
-      else
-        config.eager_load_paths.dup.freeze
-      end
+    foss_eager_load_paths = config.all_eager_load_paths.dup.freeze
 
     load_paths = ->(dir:) do
       ext_paths = foss_eager_load_paths.each_with_object([]) do |path, memo|
@@ -177,6 +167,7 @@ module Gitlab
     # config.i18n.load_path += Dir[Rails.root.join('my', 'locales', '*.{rb,yml}').to_s]
     # config.i18n.default_locale = :de
     config.i18n.enforce_available_locales = false
+    Gitlab.ee { config.i18n.load_path += Dir[config.root.join("ee/config/locales/*.yml").to_s] }
 
     # Enable locale fallbacks for I18n (makes lookups for any locale fall back to
     # the I18n.default_locale when a translation can not be found).
@@ -286,7 +277,6 @@ module Gitlab
     config.assets.precompile << "mailers/highlighted_diff_email.css"
     config.assets.precompile << "mailers/mailer.css"
     config.assets.precompile << "mailers/mailer_client_specific.css"
-    config.assets.precompile << "mailers/notify.css"
     config.assets.precompile << "mailers/notify_enhanced.css"
     config.assets.precompile << "page_bundles/_mixins_and_variables_and_functions.css"
     config.assets.precompile << "page_bundles/admin/elasticsearch_form.css"
@@ -304,6 +294,7 @@ module Gitlab
     config.assets.precompile << "page_bundles/commit_description.css"
     config.assets.precompile << "page_bundles/commit_rapid_diffs.css"
     config.assets.precompile << "page_bundles/commits.css"
+    config.assets.precompile << "page_bundles/compare_rapid_diffs.css"
     config.assets.precompile << "page_bundles/cycle_analytics.css"
     config.assets.precompile << "page_bundles/dashboard.css"
     config.assets.precompile << "page_bundles/dashboard_projects.css"
@@ -311,7 +302,6 @@ module Gitlab
     config.assets.precompile << "page_bundles/dev_ops_reports.css"
     config.assets.precompile << "page_bundles/editor.css"
     config.assets.precompile << "page_bundles/environments.css"
-    config.assets.precompile << "page_bundles/epics.css"
     config.assets.precompile << "page_bundles/error_tracking_details.css"
     config.assets.precompile << "page_bundles/escalation_policies.css"
     config.assets.precompile << "page_bundles/graph_charts.css"
@@ -335,14 +325,17 @@ module Gitlab
     config.assets.precompile << "page_bundles/merge_request_analytics.css"
     config.assets.precompile << "page_bundles/merge_request_rapid_diffs.css"
     config.assets.precompile << "page_bundles/merge_requests.css"
+    config.assets.precompile << "page_bundles/merge_request_creation_rapid_diffs.css"
     config.assets.precompile << "page_bundles/milestone.css"
     config.assets.precompile << "page_bundles/ml_experiment_tracking.css"
     config.assets.precompile << "page_bundles/new_namespace.css"
     config.assets.precompile << "page_bundles/notes_shared.css"
+    config.assets.precompile << "page_bundles/observability.css"
     config.assets.precompile << "page_bundles/oncall_schedules.css"
     config.assets.precompile << "page_bundles/operations.css"
     config.assets.precompile << "page_bundles/organizations.css"
     config.assets.precompile << "page_bundles/paginated_table.css"
+    config.assets.precompile << "page_bundles/personal_homepage.css"
     config.assets.precompile << "page_bundles/pipeline.css"
     config.assets.precompile << "page_bundles/pipeline_editor.css"
     config.assets.precompile << "page_bundles/pipelines.css"
@@ -358,7 +351,6 @@ module Gitlab
     config.assets.precompile << "page_bundles/reports.css"
     config.assets.precompile << "page_bundles/requirements.css"
     config.assets.precompile << "page_bundles/roadmap.css"
-    config.assets.precompile << "page_bundles/runner_details.css"
     config.assets.precompile << "page_bundles/runners.css"
     config.assets.precompile << "page_bundles/search.css"
     config.assets.precompile << "page_bundles/security_dashboard.css"
@@ -445,6 +437,8 @@ module Gitlab
 
     config.middleware.insert_before Rack::Runtime, ::Gitlab::Middleware::CompressedJson
 
+    config.middleware.insert_after ActionDispatch::Cookies, ::Gitlab::Middleware::SecureHeaders
+
     # Allow access to GitLab API from other domains
     config.middleware.insert_before Warden::Manager, Rack::Cors do
       headers_to_expose = %w[Link X-Total X-Total-Pages X-Per-Page X-Page X-Next-Page X-Prev-Page X-Gitlab-Blob-Id X-Gitlab-Commit-Id X-Gitlab-Content-Sha256 X-Gitlab-Encoding X-Gitlab-File-Name X-Gitlab-File-Path X-Gitlab-Last-Commit-Id X-Gitlab-Ref X-Gitlab-Size X-Request-Id ETag]
@@ -535,11 +529,7 @@ module Gitlab
     end
 
     # Use caching across all environments
-    if ::Gitlab.next_rails?
-      ActiveSupport::Cache::RedisCacheStore.prepend(Gitlab::Patch::RedisCacheStore)
-    else
-      ActiveSupport::Cache::RedisCacheStore.prepend(Gitlab::Patch::OldRedisCacheStore)
-    end
+    ActiveSupport::Cache::RedisCacheStore.prepend(Gitlab::Patch::RedisCacheStore)
 
     config.cache_store = :redis_cache_store, Gitlab::Redis::Cache.active_support_config
 
