@@ -9,16 +9,16 @@ module QA
         include Page::Component::BlobContent
         include Shared::Editor
 
-        view 'app/assets/javascripts/repository/components/blob_button_group.vue' do
-          element 'lock-button'
-        end
-
         view 'app/assets/javascripts/vue_shared/components/web_ide_link.vue' do
           element 'action-dropdown'
           element 'edit-menu-item', ':data-testid="`${action.key}-menu-item`"' # rubocop:disable QA/ElementWithPattern
           element 'webide-menu-item', ':data-testid="`${action.key}-menu-item`"' # rubocop:disable QA/ElementWithPattern
         end
 
+        view 'app/assets/javascripts/repository/components/code_dropdown/compact_code_dropdown.vue' do
+          element 'code-dropdown'
+        end
+
         def click_edit
           click_element('action-dropdown')
           click_element('edit-menu-item')
