@@ -1,3 +1,7 @@
+#!/usr/bin/env bash
+export STABLE_BRANCH_PATTERN="^[0-9-]+-stable(-ee)?$"
+export VERSION_TAG_PATTERN="^v([0-9]+)\.([0-9]+)\.([0-9]+).+(ee)$"
+
 function retry() {
   retry_times_sleep 2 3 "$@"
 }
@@ -85,16 +89,7 @@ function rspec_section() {
 }
 
 function bundle_install_script() {
-  local extra_install_args="${1}"
-
-  if [[ "${extra_install_args}" =~ "--without" ]]; then
-    echoerr "The '--without' flag shouldn't be passed as it would replace the default \${BUNDLE_WITHOUT} (currently set to '${BUNDLE_WITHOUT}')."
-    echoerr "Set the 'BUNDLE_WITHOUT' variable instead, e.g. '- export BUNDLE_WITHOUT=\"\${BUNDLE_WITHOUT}:any:other:group:not:to:install\"'."
-    exit 1;
-  fi;
-
-  section_start "bundle-install" "Installing gems"
-
+  section_start "bundle-info" "Ruby env info and bundle config"
   gem --version
   bundle --version
   test -d jh && bundle config set --local gemfile 'jh/Gemfile'
@@ -103,17 +98,14 @@ function bundle_install_script() {
 
   echo "${BUNDLE_WITHOUT}"
   bundle config
+  section_end "bundle-info"
 
-  run_timed_command "bundle install ${BUNDLE_INSTALL_FLAGS} ${extra_install_args}"
+  section_start "bundle-install" "Installing gems"
 
-  if [[ $(bundle info pg) ]]; then
-    # Bundler will complain about replacing gems in world-writeable directories, so lock down access.
-    # This appears to happen when the gems are uncached, since the Runner uses a restrictive umask.
-    find vendor -type d -exec chmod 700 {} +
-    # When we test multiple versions of PG in the same pipeline, we have a single `setup-test-env`
-    # job but the `pg` gem needs to be rebuilt since it includes extensions (https://guides.rubygems.org/gems-with-extensions).
-    # Uncomment the following line if multiple versions of PG are tested in the same pipeline.
-    run_timed_command "bundle pristine pg"
+  echo "Checking if all dependencies are satisfied"
+  if ! bundle check; then
+    # Call `eval` explicitly to run the shell functions stored inside BUNDLE_INSTALL_FLAGS
+    eval "bundle install ${BUNDLE_INSTALL_FLAGS}"
   fi
 
   section_end "bundle-install"
@@ -135,14 +127,6 @@ function yarn_install_script_storybook() {
   section_end "yarn-install-storybook"
 }
 
-function assets_compile_script() {
-  section_start "assets-compile" "Compiling frontend assets"
-
-  bin/rake gitlab:assets:compile
-
-  section_end "assets-compile"
-}
-
 function setup_database_yml() {
   if [ "$DECOMPOSED_DB" == "true" ]; then
     if [ "$SEC_DECOMPOSED_DB" == "true" ]; then
@@ -164,7 +148,7 @@ function setup_database_yml() {
 
   # Set up Geo database if the job name matches `rspec-ee` or `geo`.
   # Since Geo is an EE feature, we shouldn't set it up for non-EE tests.
-  if [[ "${CI_JOB_NAME}" =~ "rspec-ee" ]] || [[ "${CI_JOB_NAME}" =~ "geo" ]]; then
+  if [[ "${CI_JOB_NAME}" =~ "rspec-ee" ]] || [[ "${CI_JOB_NAME}" =~ "geo" ]] || [[ "${CI_JOB_NAME}" =~ "db:setup-ee" ]]; then
     echoinfo "Geo DB will be set up."
   else
     echoinfo "Geo DB won't be set up."
@@ -173,7 +157,7 @@ function setup_database_yml() {
 
   # Set up Embedding database if the job name matches `rspec-ee`
   # Since Embedding is an EE feature, we shouldn't set it up for non-EE tests.
-  if [[ "${CI_JOB_NAME}" =~ "rspec-ee" ]]; then
+  if [[ "${CI_JOB_NAME}" =~ "rspec-ee" ]] || [[ "${CI_JOB_NAME}" =~ "db:setup-ee" ]]; then
     echoinfo "Embedding DB will be set up."
   else
     echoinfo "Embedding DB won't be set up."
@@ -221,20 +205,20 @@ function setup_db() {
 }
 
 function install_gitlab_gem() {
-  run_timed_command "gem install httparty --no-document --version 0.20.0"
-  run_timed_command "gem install gitlab --no-document --version 4.19.0"
+  gem install httparty --no-document --version 0.20.0
+  gem install gitlab --no-document --version 4.19.0
 }
 
 function install_tff_gem() {
-  run_timed_command "gem install test_file_finder --no-document --version 0.3.1"
+  gem install test_file_finder --no-document --version 0.3.1
 }
 
 function install_activesupport_gem() {
-  run_timed_command "gem install activesupport --no-document --version 7.0.8.4"
+  gem install activesupport --no-document --version 7.0.8.4
 }
 
 function install_junit_merge_gem() {
-  run_timed_command "gem install junit_merge --no-document --version 0.1.2"
+  gem install junit_merge --no-document --version 0.1.2
 }
 
 function select_existing_files() {
@@ -371,14 +355,11 @@ function fail_pipeline_early() {
   fi
 }
 
-# We're inlining this function in `.gitlab/ci/test-on-omnibus/main.gitlab-ci.yml` so make sure to reflect any changes there
 function assets_image_tag() {
-  local cache_assets_hash_file="cached-assets-hash.txt"
-
   if [[ -n "${CI_COMMIT_TAG}" ]]; then
     echo -n "${CI_COMMIT_REF_NAME}"
-  elif [[ -f "${cache_assets_hash_file}" ]]; then
-    echo -n "assets-hash-$(cat ${cache_assets_hash_file} | cut -c1-10)"
+  elif [[ -f "${GLCI_GITLAB_ASSETS_HASH_FILE}" ]]; then
+    echo -n "assets-hash-$(cat ${GLCI_GITLAB_ASSETS_HASH_FILE} | cut -c1-10)"
   else
     echo -n "${CI_COMMIT_SHA}"
   fi
@@ -485,12 +466,22 @@ function download_local_gems() {
 }
 
 function define_trigger_branch_in_build_env() {
-  target_branch_name="${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-${CI_COMMIT_REF_NAME}}"
-  stable_branch_regex="^[0-9-]+-stable(-ee)?$"
+  target_branch_name="${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-${CI_COMMIT_BRANCH}}"
+
+  # If target_branch_name is empty and CI_COMMIT_TAG has version format, derive from tag
+  if [[ -z "$target_branch_name" && -n "$CI_COMMIT_TAG" ]]; then
+    # Match pattern like v42.2.0-rc42-ee and extract version parts
+    if [[ $CI_COMMIT_TAG =~ $VERSION_TAG_PATTERN ]]; then
+      major="${BASH_REMATCH[1]}"
+      minor="${BASH_REMATCH[2]}"
+      ee_suffix="${BASH_REMATCH[4]}"
+      target_branch_name="${major}-${minor}-stable-${ee_suffix}"
+    fi
+  fi
 
   echo "target_branch_name: ${target_branch_name}"
 
-  if [[ $target_branch_name =~ $stable_branch_regex  ]]
+  if [[ $target_branch_name =~ $STABLE_BRANCH_PATTERN  ]]
   then
     export TRIGGER_BRANCH="${target_branch_name%-ee}"
   else
@@ -508,11 +499,12 @@ function log_disk_usage() {
 
   available_space=$(df -h | awk 'NR==2 {print $4}') # value at the 2nd row 4th column of the df -h output
 
+  section_start "log_disk_usage" "Disk usage detail"
+
   echo "*******************************************************"
   echo "This runner currently has ${available_space} free disk space."
   echo "*******************************************************"
 
-  section_start "log_disk_usage" "Disk usage detail" "true"
   echo -e "df -h"
   df -h
   section_end "log_disk_usage"
@@ -534,7 +526,6 @@ function log_disk_usage() {
       echo "********************************************************************"
 
       exit_code=111
-      alert_job_in_slack $exit_code "Auto-retried due to low free disk space."
 
       exit $exit_code
     fi
@@ -543,25 +534,29 @@ function log_disk_usage() {
 
 # all functions below are for customizing CI job exit code
 function run_with_custom_exit_code() {
-  set +e # temporarily disable exit on error to prevent premature exit
+  "$@"
 
-  # runs command passed in as argument, save standard error and standard output
-  output=$(set -e; "$@" 2>&1)
-  initial_exit_code=$?
+  # set -o pipefail # Take the exit status of the rightmost command that failed
+  # set +e          # temporarily disable exit on error to prevent premature exit
 
-  echo "initial_exit_code: $initial_exit_code"
+  # local trace_file="/tmp/stdout_stderr_log.out"
 
-  local trace_file="stdout_stderr_log.out"
+  # # Run the command and tee output to both the terminal and the file
+  # "$@" 2>&1 | tee "$trace_file"
+  # initial_exit_code=$?
 
-  echo "$output" | tee "$trace_file"
+  # echo "initial_exit_code: $initial_exit_code"
 
-  find_custom_exit_code "$initial_exit_code" "$trace_file"
-  new_exit_code=$?
+  # find_custom_exit_code "$initial_exit_code" "$trace_file"
+  # new_exit_code=$?
 
-  echo "new_exit_code=$new_exit_code"
-  set -e
+  # echo "new_exit_code=$new_exit_code"
 
-  exit "$new_exit_code"
+  # # Restore shell default behavior
+  # set -e
+  # set +o pipefail
+
+  # exit "$new_exit_code"
 }
 
 function find_custom_exit_code() {
@@ -584,19 +579,16 @@ function find_custom_exit_code() {
     -e "OpenSSL::SSL::SSLError" "$trace_file"; then
     echoerr "Detected network connection error. Changing exit code to 110."
     exit_code=110
-    alert_job_in_slack "$exit_code" "Network connection error"
 
   elif grep -i -q -e "no space left on device" "$trace_file"; then
     echoerr "Detected no space left on device. Changing exit code to 111."
     exit_code=111
-    alert_job_in_slack "$exit_code" "Low disk space"
 
   elif grep -i -q \
     -e "error: downloading artifacts from coordinator" \
     -e "error: uploading artifacts as \"archive\" to coordinator" "$trace_file"; then
     echoerr "Detected artifact transit error. Changing exit code to 160."
     exit_code=160
-    alert_job_in_slack "$exit_code" "Artifact transit error"
 
   elif grep -i -q \
     -e "500 Internal Server Error" \
@@ -608,18 +600,15 @@ function find_custom_exit_code() {
     -e "503 Service Unavailable" "$trace_file"; then
     echoerr "Detected 5XX error. Changing exit code to 161."
     exit_code=161
-    alert_job_in_slack "$exit_code" "5XX error"
 
   elif grep -i -q -e "gitaly spawn failed" "$trace_file"; then
     echoerr "Detected gitaly spawn failure error. Changing exit code to 162."
     exit_code=162
-    alert_job_in_slack "$exit_code" "Gitaly spawn failure"
 
   elif grep -i -q -e \
     "Rspec suite is exceeding the 80 minute limit and is forced to exit with error" "$trace_file"; then
     echoerr "Detected rspec timeout risk. Changing exit code to 163."
     exit_code=163
-    alert_job_in_slack "$exit_code" "RSpec taking longer than 80 minutes and forced to fail."
 
   elif grep -i -q \
     -e "Redis client could not fetch cluster information: Connection refused" \
@@ -627,23 +616,19 @@ function find_custom_exit_code() {
     -e "CLUSTERDOWN The cluster is down" "$trace_file"; then
     echoerr "Detected Redis cluster error. Changing exit code to 164."
     exit_code=164
-    alert_job_in_slack "$exit_code" "Redis cluster error"
 
   elif grep -i -q -e "segmentation fault" "$trace_file"; then
     echoerr "Detected segmentation fault. Changing exit code to 165."
     exit_code=165
-    alert_job_in_slack "$exit_code" "Segmentation fault"
 
   elif grep -i -q -e "Error: EEXIST: file already exists" "$trace_file"; then
     echoerr "Detected EEXIST error. Changing exit code to 166."
     exit_code=166
-    alert_job_in_slack "$exit_code" "EEXIST: file already exists"
 
   elif grep -i -q -e \
     "fatal: remote error: GitLab is currently unable to handle this request due to load" "$trace_file"; then
     echoerr "Detected GitLab overload error in job trace. Changing exit code to 167."
     exit_code=167
-    alert_job_in_slack "$exit_code" "gitlab.com overload"
 
   elif grep -i -q -e "GRPC::ResourceExhausted" "$trace_file"; then
     echoerr "Detected GRPC::ResourceExhausted. Changing exit code to 168."
@@ -664,52 +649,3 @@ function find_custom_exit_code() {
   echoinfo "will exit with $exit_code"
   return "$exit_code"
 }
-
-function alert_job_in_slack() {
-  local exit_code=$1
-  local alert_reason=$2
-  local slack_channel="#dx_development-analytics_alerts"
-
-  echoinfo "Reporting ${CI_JOB_URL} to Slack channel ${slack_channel}"
-
-  json_payload=$(cat <<JSON
-{
-	"blocks": [
-		{
-			"type": "section",
-			"text": {
-				"type": "mrkdwn",
-				"text": "*<${CI_PROJECT_URL}|${CI_PROJECT_PATH}> pipeline <${CI_PIPELINE_URL}|#${CI_PIPELINE_ID}> needs attention*"
-			}
-		},
-		{
-			"type": "section",
-			"fields": [
-				{
-					"type": "mrkdwn",
-					"text": "*Branch:* \n\`${CI_COMMIT_REF_NAME}\`"
-				},
-				{
-					"type": "mrkdwn",
-					"text": "*Job:* \n<${CI_JOB_URL}|${CI_JOB_NAME}>"
-				},
-				{
-					"type": "mrkdwn",
-					"text": "*Error code:* \n\`${exit_code}\`"
-				},
-				{
-					"type": "mrkdwn",
-					"text": "*Reason:* \n${alert_reason}"
-				}
-			]
-		}
-	],
-  "channel": "${slack_channel}"
-}
-JSON
-)
-
-  curl --silent -o /dev/null -X POST "${CI_SLACK_WEBHOOK_URL}" \
-    -H 'Content-type: application/json' \
-    -d "${json_payload}"
-}
