@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-RSpec.describe OmniauthCallbacksController, type: :controller, feature_category: :system_access do
+RSpec.describe OmniauthCallbacksController, :with_current_organization, type: :controller, feature_category: :system_access do
   include LoginHelpers
 
   shared_examples 'stores value for provider_2FA to session according to saml response' do
@@ -163,7 +163,7 @@ RSpec.describe OmniauthCallbacksController, type: :controller, feature_category:
       Rails.application.env_config['omniauth.auth'] = @original_env_config_omniauth_auth
     end
 
-    context 'when authentication succeeds' do
+    context 'when authentication succeeds', :prometheus do
       let(:extern_uid) { 'my-uid' }
       let(:provider) { :github }
 
@@ -171,15 +171,22 @@ RSpec.describe OmniauthCallbacksController, type: :controller, feature_category:
         it 'increments Prometheus counter' do
           expect { post(provider) }.to(
             change do
-              Gitlab::Metrics.registry
-                             .get(:gitlab_omniauth_login_total)
-                             .get(omniauth_provider: 'github', status: 'succeeded')
+              Gitlab::Metrics.client
+                            .get(:gitlab_omniauth_login_total)
+                            &.get(omniauth_provider: 'github', status: 'succeeded')
+                            .to_f
             end.by(1)
           )
         end
+
+        it 'creates an authentication audit event' do
+          expect { post provider }.to change {
+            AuditEvent.where("details LIKE '%authenticated_with_oauth%'").count
+          }.by(1)
+        end
       end
 
-      context 'with signed-in user' do
+      context 'with signed-in user', :prometheus do
         before do
           sign_in user
         end
@@ -191,9 +198,10 @@ RSpec.describe OmniauthCallbacksController, type: :controller, feature_category:
         it 'increments Prometheus counter' do
           expect { post(provider) }.to(
             change do
-              Gitlab::Metrics.registry
+              Gitlab::Metrics.client
                              .get(:gitlab_omniauth_login_total)
-                             .get(omniauth_provider: 'github', status: 'succeeded')
+                             &.get(omniauth_provider: 'github', status: 'succeeded')
+                             .to_f
             end.by(1)
           )
         end
@@ -246,6 +254,23 @@ RSpec.describe OmniauthCallbacksController, type: :controller, feature_category:
       end
     end
 
+    context 'when the user is trying to sign-in from restricted country' do
+      let(:extern_uid) { 'my-uid' }
+      let(:provider) { :github }
+      let(:error_message) { "It looks like you are visiting GitLab from Mainland China, Macau, or Hong Kong" }
+
+      before do
+        allow(controller).to receive(:allowed_new_user?).and_raise(OmniauthCallbacksController::SignUpFromRestrictedCountyError)
+
+        post provider
+      end
+
+      it 'redirects to root path with message' do
+        expect(response).to redirect_to new_user_session_path
+        expect(flash[:alert]).to include(error_message)
+      end
+    end
+
     context 'when the user is on the last sign in attempt' do
       let(:extern_uid) { 'my-uid' }
 
@@ -280,7 +305,7 @@ RSpec.describe OmniauthCallbacksController, type: :controller, feature_category:
       end
     end
 
-    context 'when sign in fails' do
+    context 'when sign in fails', :prometheus do
       include RoutesHelpers
 
       let(:extern_uid) { 'my-uid' }
@@ -304,9 +329,10 @@ RSpec.describe OmniauthCallbacksController, type: :controller, feature_category:
         ForgeryProtection.with_forgery_protection do
           expect { post :failure }.to(
             change do
-              Gitlab::Metrics.registry
+              Gitlab::Metrics.client
                              .get(:gitlab_omniauth_login_total)
-                             .get(omniauth_provider: 'saml', status: 'failed')
+                             &.get(omniauth_provider: 'saml', status: 'failed')
+                             .to_f
             end.by(1)
           )
         end
@@ -803,6 +829,113 @@ RSpec.describe OmniauthCallbacksController, type: :controller, feature_category:
     end
 
     it_behaves_like "sets provider_2FA session variable according to bypass_two_factor return value"
+
+    context 'for step-up authentication' do
+      context 'with different step-up authentication configurations' do
+        using RSpec::Parameterized::TableSyntax
+
+        let(:ommiauth_provider_config_with_step_up_auth) do
+          GitlabSettings::Options.new(
+            name: "openid_connect",
+            step_up_auth: {
+              admin_mode: {
+                id_token: {
+                  required: required_id_token_claims,
+                  included: included_id_token_claims
+                }
+              }
+            }
+          )
+        end
+
+        before do
+          mock_auth_hash(provider, extern_uid, user.email, additional_info: { extra: { raw_info: mock_auth_hash_extra_raw_info } })
+
+          request.env['omniauth.auth'] = Rails.application.env_config['omniauth.auth']
+          session['omniauth_step_up_auth'] = { 'openid_connect' => { 'admin_mode' => { 'state' => 'requested' } } }
+
+          stub_omniauth_setting(enabled: true, auto_link_user: true, block_auto_created_users: false, providers: [ommiauth_provider_config_with_step_up_auth])
+        end
+
+        where(:required_id_token_claims, :included_id_token_claims, :mock_auth_hash_extra_raw_info, :step_up_auth_authenticated) do
+          { claim_1: 'gold' } | nil                          | { claim_1: 'gold' }                         | 'succeeded'
+          { claim_1: 'gold' } | nil                          | { claim_1: 'gold', claim_2: 'mfa' }         | 'succeeded'
+          { claim_1: 'gold' } | nil                          | { claim_1: 'silver' }                       | 'failed'
+          { claim_1: 'gold' } | nil                          | { claim_1: 'silver', claim_2: 'other_amr' } | 'failed'
+          { claim_1: 'gold' } | nil                          | { claim_1: nil }                            | 'failed'
+          { claim_1: 'gold' } | nil                          | { claim_3: 'other_value' }                  | 'failed'
+          { claim_1: 'gold' } | nil                          | {}                                          | 'failed'
+
+          nil                 | { claim_2: %w[mfa fpt] }     | { claim_2: 'mfa', claim_3: 'other_value' }  | 'succeeded'
+          nil                 | { claim_2: %w[mfa fpt] }     | { claim_2: 'fpt' }                          | 'succeeded'
+          nil                 | { claim_2: %w[mfa fpt] }     | { claim_2: 'other_amr' }                    | 'failed'
+
+          { claim_1: 'gold' } | { claim_1: ['gold'] }        | { claim_1: 'gold' }                         | 'succeeded'
+          { claim_1: 'gold' } | { claim_1: %w[gold silver] } | { claim_1: 'gold' }                         | 'succeeded'
+          { claim_1: 'gold' } | { claim_1: %w[gold silver] } | { claim_1: 'silver' }                       | 'failed'
+          { claim_1: 'gold' } | { claim_2: %w[mfa fpt] }     | { claim_1: 'gold', claim_2: 'mfa' }         | 'succeeded'
+          { claim_1: 'gold' } | { claim_2: %w[mfa fpt] }     | { claim_1: 'gold', claim_2: 'other_amr' }   | 'failed'
+          { claim_1: 'gold' } | { claim_2: %w[mfa fpt] }     | { claim_1: 'silver', claim_2: 'mfa' }       | 'failed'
+          { claim_1: 'gold' } | { claim_2: %w[mfa fpt] }     | { claim_1: 'silver', claim_2: 'other_amr' } | 'failed'
+        end
+
+        with_them do
+          context 'when user is signed in' do
+            before do
+              sign_in user
+            end
+
+            it 'evaluates step-up authentication conditions and stores result in session' do
+              get provider
+
+              expect(session.to_h.dig('omniauth_step_up_auth', 'openid_connect', 'admin_mode', 'state'))
+                .to eq step_up_auth_authenticated
+            end
+
+            context 'when feature flag :omniauth_step_up_auth_for_admin_mode disabled' do
+              before do
+                stub_feature_flags(omniauth_step_up_auth_for_admin_mode: false)
+                session.delete 'omniauth_step_up_auth'
+              end
+
+              it 'does not store step-up authentication evaluation result in session' do
+                get provider
+
+                expect(session).not_to include 'omniauth_step_up_auth'
+              end
+            end
+          end
+
+          context 'when user is not signed in' do
+            before do
+              session.delete 'omniauth_step_up_auth'
+            end
+
+            it 'does not store step-up authentication evaluation result in session' do
+              get provider
+
+              expect(session).not_to include 'omniauth_step_up_auth'
+            end
+          end
+        end
+      end
+
+      context 'without step-up authentication configuration' do
+        let(:ommiauth_provider_config_with_step_up_auth) { GitlabSettings::Options.new(name: "openid_connect") }
+
+        it 'does not add session key "step_up_auth"' do
+          get provider
+
+          expect(session).not_to include 'step_up_auth'
+        end
+      end
+    end
+
+    it 'does not log saml_response for debugging' do
+      expect(Gitlab::AuthLogger).not_to receive(:info).with(payload_type: 'saml_response', saml_response: anything)
+
+      get provider
+    end
   end
 
   describe '#saml' do
@@ -972,9 +1105,21 @@ RSpec.describe OmniauthCallbacksController, type: :controller, feature_category:
 
         expect(request.env['warden']).to be_authenticated
       end
+
+      it 'logs saml_response for debugging' do
+        expect(Gitlab::AuthLogger).to receive(:info).with(payload_type: 'saml_response', saml_response: anything)
+
+        post :saml_okta, params: { SAMLResponse: mock_saml_response }
+      end
     end
 
     it_behaves_like "stores value for provider_2FA to session according to saml response"
+
+    it 'logs saml_response for debugging' do
+      expect(Gitlab::AuthLogger).to receive(:info).with(payload_type: 'saml_response', saml_response: anything)
+
+      post :saml, params: { SAMLResponse: mock_saml_response }
+    end
   end
 
   describe 'enable admin mode' do
