@@ -40,60 +40,62 @@ RSpec.describe Projects::BlobController, feature_category: :source_code_manageme
         it_behaves_like '#set_is_ambiguous_ref when ref is not ambiguous'
       end
 
-      context "valid branch, valid file" do
-        let(:id) { 'master/README.md' }
+      context 'when the branch is valid' do
+        let(:id) { "#{ref}/#{path}" }
+        let(:ref) { 'master' }
 
-        it { is_expected.to respond_with(:success) }
-      end
+        context 'and the file is valid' do
+          let(:path) { 'README.md' }
 
-      context "valid branch, invalid file" do
-        let(:id) { 'master/invalid-path.rb' }
+          it { is_expected.to respond_with(:success) }
 
-        it 'redirects' do
-          expect(subject)
-              .to redirect_to("/#{project.full_path}/-/tree/master")
+          context 'and the ref_type is valid' do
+            let(:ref_type) { 'heads' }
+
+            it { is_expected.to respond_with(:success) }
+          end
+
+          context 'and the ref_type is wrong' do
+            let(:ref_type) { 'tags' }
+
+            it { is_expected.to respond_with(:not_found) }
+          end
+
+          context 'and ref is a sha' do
+            let(:ref) { head_sha }
+
+            it { is_expected.to respond_with(:success) }
+
+            context 'and there ref_type is present' do
+              let(:ref_type) { 'heads' }
+
+              it { is_expected.to respond_with(:not_found) }
+            end
+          end
+        end
+
+        context 'and the file is invalid' do
+          let(:path) { 'invalid-path.rb' }
+
+          it 'redirects' do
+            expect(subject)
+                .to redirect_to("/#{project.full_path}/-/tree/master")
+          end
         end
       end
 
-      context "invalid branch, valid file" do
+      context 'when the branch is invalid' do
         let(:id) { 'invalid-branch/README.md' }
 
         it { is_expected.to respond_with(:not_found) }
       end
 
-      context 'valid branch, valid file, correct ref_type' do
-        let(:id) { 'master/README.md' }
-        let(:ref_type) { 'heads' }
-
-        it { is_expected.to respond_with(:success) }
-      end
-
-      context 'valid branch, valid file, wrong ref_type' do
-        let(:id) { 'master/README.md' }
-        let(:ref_type) { 'tags' }
-
-        it { is_expected.to respond_with(:not_found) }
-      end
-
-      context 'sha ref, valid file' do
-        let(:id) { "#{head_sha}/README.md" }
-
-        it { is_expected.to respond_with(:success) }
-      end
-
       context 'wrong sha ref, valid file' do
         let(:id) { '0000000000000000000000000000000000000000/README.md' }
 
         it { is_expected.to respond_with(:not_found) }
       end
 
-      context 'sha ref, valid file, non-empty ref_type' do
-        let(:id) { "#{head_sha}/README.md" }
-        let(:ref_type) { 'heads' }
-
-        it { is_expected.to respond_with(:not_found) }
-      end
-
       context 'when default branch was renamed' do
         let_it_be_with_reload(:project) { create(:project, :public, :repository, previous_default_branch: 'old-default-branch') }
 
@@ -115,12 +117,6 @@ RSpec.describe Projects::BlobController, feature_category: :source_code_manageme
 
         it { is_expected.to respond_with(:success) }
       end
-
-      context "Markdown file" do
-        let(:id) { 'master/README.md' }
-
-        it { is_expected.to respond_with(:success) }
-      end
     end
 
     context 'with file path and JSON format' do
@@ -316,7 +312,7 @@ RSpec.describe Projects::BlobController, feature_category: :source_code_manageme
         get :edit, params: default_params
       end
 
-      it 'redirects to blob show' do
+      it 'allows to edit the file' do
         expect(response).to have_gitlab_http_status(:ok)
       end
     end
@@ -327,12 +323,26 @@ RSpec.describe Projects::BlobController, feature_category: :source_code_manageme
       before do
         project.add_maintainer(maintainer)
         sign_in(maintainer)
-        get :edit, params: default_params
       end
 
-      it 'redirects to blob show' do
+      it 'allows to edit the file' do
+        get :edit, params: default_params
+
         expect(response).to have_gitlab_http_status(:ok)
       end
+
+      context 'when file size exceeds limit' do
+        it 'redirects to blob show page with alert message' do
+          allow_next_instance_of(Blob) do |blob|
+            allow(blob).to receive(:raw_size).and_return(Projects::BlobController::MAX_EDIT_SIZE + 1.megabyte)
+          end
+
+          get :edit, params: default_params
+
+          expect(response).to redirect_to(project_blob_path(project, 'master/CHANGELOG'))
+          expect(flash[:alert]).to include(/File exceeds 10MB/)
+        end
+      end
     end
   end
 
@@ -366,6 +376,31 @@ RSpec.describe Projects::BlobController, feature_category: :source_code_manageme
       expect(response).to redirect_to(blob_after_edit_path)
     end
 
+    context "when user doesn't have permission to push" do
+      before do
+        create(:protected_branch, :no_one_can_push, project: mutable_project, name: '*')
+      end
+
+      context 'when branch_name is not provided' do
+        let(:params) do
+          {
+            project_id: mutable_project,
+            namespace_id: mutable_project.namespace,
+            id: 'master/CHANGELOG',
+            content: 'Added changes',
+            commit_message: 'Update CHANGELOG'
+          }
+        end
+
+        it 'handles missing branch_name gracefully and returns permission error' do
+          put :update, params: params, format: :json
+
+          expect(response).to have_gitlab_http_status(:unprocessable_entity)
+          expect(json_response['error']).to eq('You are not allowed to push into this branch')
+        end
+      end
+    end
+
     context 'when file is renamed' do
       let(:default_params) do
         {
@@ -644,6 +679,20 @@ RSpec.describe Projects::BlobController, feature_category: :source_code_manageme
       expect(response).to redirect_to(project_blob_path(project, 'master/docs/EXAMPLE_FILE'))
     end
 
+    context 'when commit message is missing' do
+      let(:default_params) { super().merge(commit_message: '') }
+
+      render_views
+
+      it 'renders an error message' do
+        request
+
+        expect(response).to be_successful
+        expect(response).to render_template(:new)
+        expect(response.body).to include('You must provide a commit message')
+      end
+    end
+
     context 'when file_name is missing' do
       let(:default_params) do
         {
