@@ -175,6 +175,30 @@ RSpec.describe 'Admin::Users', :with_current_organization, feature_category: :us
       end
     end
 
+    describe 'Humans filter' do
+      it 'filters by human users' do
+        bot_user = create(:user, user_type: :alert_bot)
+        normal_user = create(:user)
+
+        visit admin_users_path(filter: 'without_bots')
+
+        expect(has_user?(text: bot_user.email)).to be(false)
+        expect(has_user?(text: normal_user.email)).to be(true)
+      end
+    end
+
+    describe 'Bots filter' do
+      it 'filters by bot users' do
+        bot_user = create(:user, user_type: :alert_bot)
+        normal_user = create(:user)
+
+        visit admin_users_path(filter: 'bots')
+
+        expect(has_user?(text: bot_user.email)).to be(true)
+        expect(has_user?(text: normal_user.email)).to be(false)
+      end
+    end
+
     context 'when blocking/unblocking a user' do
       it 'shows confirmation and allows blocking and unblocking', :js do
         expect(has_user?(text: user.email)).to be(true)
@@ -257,7 +281,7 @@ RSpec.describe 'Admin::Users', :with_current_organization, feature_category: :us
       let_it_be(:locked_user) { create(:user, locked_at: DateTime.parse('2020-02-25 10:30:00 -0700')) }
 
       it "displays `Locked` badge next to user" do
-        expect(page).to have_content("#{locked_user.name} Locked")
+        expect(page).to have_content("#{locked_user.name} #{locked_user.email} Locked")
       end
 
       it 'allows a user to be unlocked from the `User administration dropdown', :js do
@@ -412,7 +436,7 @@ RSpec.describe 'Admin::Users', :with_current_organization, feature_category: :us
       let_it_be(:user_username) { 'Bing bang' }
 
       it "doesn't create the user and shows an error message" do
-        expect { click_button 'Create user' }.to change { User.count }.by(0)
+        expect { click_button 'Create user' }.not_to change { User.count }
 
         expect(page).to have_content('The form contains the following error')
         expect(page).to have_content('Username can contain only letters, digits')
@@ -605,13 +629,13 @@ RSpec.describe 'Admin::Users', :with_current_organization, feature_category: :us
       ])
     end
 
-    describe 'Update user' do
+    describe 'Update user', :js do
       before do
         fill_in 'user_name', with: 'Big Bang'
         fill_in 'user_email', with: 'bigbang@mail.com'
         fill_in 'user_password', with: 'AValidPassword1'
         fill_in 'user_password_confirmation', with: 'AValidPassword1'
-        choose 'user_access_level_admin'
+        choose 'Administrator'
         check 'Private profile'
       end
 
@@ -632,7 +656,7 @@ RSpec.describe 'Admin::Users', :with_current_organization, feature_category: :us
         expect(user.private_profile).to eq(true)
       end
 
-      context 'when updating the organization access level', :js do
+      context 'when updating the organization access level' do
         it 'updates the user organization access level' do
           organization_user = Organizations::OrganizationUser
             .find_by(user_id: user.id, organization_id: current_organization.id)
