@@ -13,8 +13,7 @@ import IssueCardTimeInfo from 'ee_else_ce/issues/list/components/issue_card_time
 import createMockApollo from 'helpers/mock_apollo_helper';
 import setWindowLocation from 'helpers/set_window_location_helper';
 import { TEST_HOST } from 'helpers/test_constants';
-import { mountExtended, shallowMountExtended } from 'helpers/vue_test_utils_helper';
-import { stubComponent } from 'helpers/stub_component';
+import { mountExtended } from 'helpers/vue_test_utils_helper';
 import waitForPromises from 'helpers/wait_for_promises';
 import {
   filteredTokens,
@@ -38,8 +37,8 @@ import { issuableListTabs } from '~/vue_shared/issuable/list/constants';
 import EmptyStateWithAnyIssues from '~/issues/list/components/empty_state_with_any_issues.vue';
 import EmptyStateWithoutAnyIssues from '~/issues/list/components/empty_state_without_any_issues.vue';
 import IssuesListApp from '~/issues/list/components/issues_list_app.vue';
-import LocalStorageSync from '~/vue_shared/components/local_storage_sync.vue';
 import NewResourceDropdown from '~/vue_shared/components/new_resource_dropdown/new_resource_dropdown.vue';
+import CreateWorkItemModal from '~/work_items/components/create_work_item_modal.vue';
 import WorkItemDrawer from '~/work_items/components/work_item_drawer.vue';
 import {
   CREATED_DESC,
@@ -61,6 +60,7 @@ import {
   removeParams,
 } from '~/lib/utils/url_utility';
 import {
+  CREATION_CONTEXT_LIST_ROUTE,
   WORK_ITEM_TYPE_ENUM_INCIDENT,
   WORK_ITEM_TYPE_ENUM_ISSUE,
   WORK_ITEM_TYPE_ENUM_TASK,
@@ -122,6 +122,7 @@ describe('CE IssuesListApp component', () => {
     hasAnyIssues: true,
     hasAnyProjects: true,
     hasBlockedIssuesFeature: true,
+    hasCustomFieldsFeature: true,
     hasIssueDateFilterFeature: true,
     hasIssuableHealthStatusFeature: true,
     hasIssueWeightsFeature: true,
@@ -142,7 +143,8 @@ describe('CE IssuesListApp component', () => {
     showNewIssueLink: true,
     signInPath: 'sign/in/path',
     groupId: '',
-    commentTemplatePaths: [],
+    timeTrackingLimitToHours: false,
+    hasStatusFeature: true,
   };
 
   let defaultQueryResponse = getIssuesQueryResponse;
@@ -156,20 +158,27 @@ describe('CE IssuesListApp component', () => {
     defaultQueryResponse.data.project.issues.nodes[0].epic = {
       id: 'gid://gitlab/Epic/1',
     };
+    defaultQueryResponse.data.project.issues.nodes[0].status = {
+      color: '#DD2B0E',
+      iconName: 'status-cancelled',
+      id: 'gid://gitlab/WorkItems::Statuses::SystemDefined::Status/4',
+      name: "Won't do",
+      description: '',
+      position: 0,
+      __typename: 'WorkItemStatus',
+    };
   }
 
   const mockIssuesQueryResponse = jest.fn().mockResolvedValue(defaultQueryResponse);
   const mockIssuesCountsQueryResponse = jest.fn().mockResolvedValue(getIssuesCountsQueryResponse);
 
+  const findCreateWorkItemModal = () => wrapper.findComponent(CreateWorkItemModal);
   const findCsvImportExportButtons = () => wrapper.findComponent(CsvImportExportButtons);
   const findDropdown = () => wrapper.findComponent(GlDisclosureDropdown);
   const findIssuableByEmail = () => wrapper.findComponent(IssuableByEmail);
   const findGlButton = () => wrapper.findComponent(GlButton);
   const findGlButtons = () => wrapper.findAllComponents(GlButton);
   const findIssuableList = () => wrapper.findComponent(IssuableList);
-  const findListViewTypeBtn = () => wrapper.findByTestId('list-view-type');
-  const findGridtViewTypeBtn = () => wrapper.findByTestId('grid-view-type');
-  const findViewTypeLocalStorageSync = () => wrapper.findAllComponents(LocalStorageSync).at(0);
   const findNewResourceDropdown = () => wrapper.findComponent(NewResourceDropdown);
   const findCalendarButton = () => wrapper.findByTestId('subscribe-calendar');
   const findRssButton = () => wrapper.findByTestId('subscribe-rss');
@@ -274,7 +283,6 @@ describe('CE IssuesListApp component', () => {
         hasPreviousPage: getIssuesQueryResponse.data.project.issues.pageInfo.hasPreviousPage,
         hasNextPage: getIssuesQueryResponse.data.project.issues.pageInfo.hasNextPage,
       });
-      expect(findIssuableList().props('isGridView')).toBe(false);
     });
   });
 
@@ -366,6 +374,25 @@ describe('CE IssuesListApp component', () => {
       });
     });
 
+    describe('create modal', () => {
+      it.each([true, false])(
+        'renders depending on whether issuesListCreateModal=%s',
+        (issuesListCreateModal) => {
+          wrapper = mountComponent({ provide: { glFeatures: { issuesListCreateModal } } });
+
+          expect(findCreateWorkItemModal().exists()).toBe(issuesListCreateModal);
+        },
+      );
+
+      it('renders in "list route" creation context', () => {
+        wrapper = mountComponent({ provide: { glFeatures: { issuesListCreateModal: true } } });
+
+        expect(findCreateWorkItemModal().props('creationContext')).toBe(
+          CREATION_CONTEXT_LIST_ROUTE,
+        );
+      });
+    });
+
     describe('new issue button', () => {
       it('renders when user has permissions', () => {
         wrapper = mountComponent({ provide: { showNewIssueLink: true }, mountFn: mount });
@@ -379,6 +406,12 @@ describe('CE IssuesListApp component', () => {
 
         expect(findGlButtons().filter((button) => button.text() === 'New issue')).toHaveLength(0);
       });
+
+      it('does not render when `issuesListCreateModal` is enabled', () => {
+        wrapper = mountComponent({ provide: { glFeatures: { issuesListCreateModal: true } } });
+
+        expect(findGlButtons().filter((button) => button.text() === 'New issue')).toHaveLength(0);
+      });
     });
 
     describe('new issue split dropdown', () => {
@@ -393,38 +426,15 @@ describe('CE IssuesListApp component', () => {
 
         expect(findNewResourceDropdown().exists()).toBe(true);
       });
-    });
-  });
 
-  describe('header action buttons with the grid view enabled', () => {
-    beforeEach(() => {
-      wrapper = mountComponent({
-        mountFn: shallowMountExtended,
-        provide: {
-          glFeatures: {
-            issuesGridView: true,
-          },
-        },
-        stubs: {
-          IssuableList: stubComponent(IssuableList, {
-            template: `<div><slot name="nav-actions" /></div>`,
-          }),
-        },
+      it('does not render when `issuesListCreateModal` is enabled', () => {
+        wrapper = mountComponent({
+          provide: { isProject: false, glFeatures: { issuesListCreateModal: true } },
+        });
+
+        expect(findNewResourceDropdown().exists()).toBe(false);
       });
     });
-
-    it('switch between list and grid', async () => {
-      findGridtViewTypeBtn().vm.$emit('click');
-      await nextTick();
-
-      expect(findIssuableList().props('isGridView')).toBe(true);
-      expect(findViewTypeLocalStorageSync().props('value')).toBe('Grid');
-
-      findListViewTypeBtn().vm.$emit('click');
-      await nextTick();
-      expect(findIssuableList().props('isGridView')).toBe(false);
-      expect(findViewTypeLocalStorageSync().props('value')).toBe('List');
-    });
   });
 
   describe('initial url params', () => {
@@ -460,6 +470,18 @@ describe('CE IssuesListApp component', () => {
     });
 
     describe('sort', () => {
+      describe('when sort is specified in the url params', () => {
+        getParameterByName.mockImplementation((args) =>
+          jest.requireActual('~/lib/utils/url_utility').getParameterByName(args),
+        );
+        it.each(Object.keys(urlSortParams))('sort is set to value %s', (sort) => {
+          setWindowLocation(`?sort=${sort}`);
+          wrapper = mountComponent();
+
+          expect(findIssuableList().props('initialSortBy')).toBe(sort);
+        });
+      });
+
       describe('when initial sort value uses old enum values', () => {
         const oldEnumSortValues = Object.values(urlSortParams);
 
@@ -657,7 +679,7 @@ describe('CE IssuesListApp component', () => {
         wrapper = mountComponent({ provide: { isSignedIn: false } });
       });
 
-      it('does not render My-Reaction or Confidential tokens', () => {
+      it('does not render My reaction or Confidential tokens', () => {
         expect(findIssuableList().props('searchTokens')).not.toMatchObject([
           { type: TOKEN_TYPE_AUTHOR, preloadedUsers: [mockCurrentUser] },
           { type: TOKEN_TYPE_ASSIGNEE, preloadedUsers: [mockCurrentUser] },
@@ -1086,33 +1108,15 @@ describe('CE IssuesListApp component', () => {
   });
 
   describe('when providing token for labels', () => {
-    it('passes function to fetchLatestLabels property if frontend caching is enabled', () => {
-      wrapper = mountComponent({
-        provide: {
-          glFeatures: {
-            frontendCaching: true,
-          },
-        },
-      });
+    it('passes function to fetchLatestLabels property', () => {
+      wrapper = mountComponent();
 
       expect(typeof findLabelsToken().fetchLatestLabels).toBe('function');
     });
-
-    it('passes null to fetchLatestLabels property if frontend caching is disabled', () => {
-      wrapper = mountComponent({
-        provide: {
-          glFeatures: {
-            frontendCaching: false,
-          },
-        },
-      });
-
-      expect(findLabelsToken().fetchLatestLabels).toBe(null);
-    });
   });
 
   describe('when issue drawer is enabled', () => {
-    beforeEach(() => {
+    beforeEach(async () => {
       wrapper = mountComponent({
         provide: {
           glFeatures: {
@@ -1120,6 +1124,7 @@ describe('CE IssuesListApp component', () => {
           },
         },
       });
+      await waitForPromises();
     });
 
     it('renders issuable drawer component', () => {
@@ -1257,7 +1262,7 @@ describe('CE IssuesListApp component', () => {
 
           await waitForPromises();
 
-          expect(findIssuableList().props('issuables')[0].title).toBe('Updated title');
+          expect(findIssuableList().props('issuables')[0].title).toBe('Updated _title_');
           expect(findIssuableList().props('issuables')[0].confidential).toBe(true);
         });
 
@@ -1397,5 +1402,19 @@ describe('CE IssuesListApp component', () => {
         expect(findWorkItemDrawer().props('open')).toBe(false);
       });
     });
+    describe('on window `popstate` event', () => {
+      it('sets the `activeIssuable` to null, closing the drawer if show parameter is not present', async () => {
+        findIssuableList().vm.$emit(
+          'select-issuable',
+          getIssuesQueryResponse.data.project.issues.nodes[0],
+        );
+        expect(findWorkItemDrawer().props('open')).toBe(true);
+
+        setWindowLocation('?otherThing=true');
+        window.dispatchEvent(new Event('popstate'));
+        await nextTick();
+        expect(findWorkItemDrawer().props('open')).toBe(false);
+      });
+    });
   });
 });
