@@ -1,16 +1,19 @@
-import { GlAlert, GlEmptyState, GlIntersectionObserver } from '@gitlab/ui';
+import { GlAlert, GlEmptyState, GlIntersectionObserver, GlButton } from '@gitlab/ui';
 import Vue, { nextTick } from 'vue';
 import VueApollo from 'vue-apollo';
 import { shallowMountExtended } from 'helpers/vue_test_utils_helper';
+import { useMockInternalEventsTracking } from 'helpers/tracking_internal_events_helper';
 import { isLoggedIn } from '~/lib/utils/common_utils';
 import createMockApollo from 'helpers/mock_apollo_helper';
 import waitForPromises from 'helpers/wait_for_promises';
 import setWindowLocation from 'helpers/set_window_location_helper';
+import { useRealDate } from 'helpers/fake_date';
 import WorkItemLoading from '~/work_items/components/work_item_loading.vue';
 import WorkItemDetail from '~/work_items/components/work_item_detail.vue';
 import WorkItemActions from '~/work_items/components/work_item_actions.vue';
 import WorkItemAncestors from '~/work_items/components/work_item_ancestors/work_item_ancestors.vue';
 import WorkItemDescription from '~/work_items/components/work_item_description.vue';
+import WorkItemLinkedResources from '~/work_items/components/work_item_linked_resources.vue';
 import WorkItemCreatedUpdated from '~/work_items/components/work_item_created_updated.vue';
 import WorkItemAttributesWrapper from '~/work_items/components/work_item_attributes_wrapper.vue';
 import WorkItemErrorTracking from '~/work_items/components/work_item_error_tracking.vue';
@@ -37,9 +40,9 @@ import workspacePermissionsQuery from '~/work_items/graphql/workspace_permission
 import workItemLinkedItemsQuery from '~/work_items/graphql/work_item_linked_items.query.graphql';
 
 import {
-  mockParent,
   workItemByIidResponseFactory,
   workItemQueryResponse,
+  mockParent,
   workItemLinkedItemsResponse,
   objectiveType,
   epicType,
@@ -49,7 +52,7 @@ import {
   mockUploadDesignMutationResponse,
   mockUploadSkippedDesignMutationResponse,
   mockUploadErrorDesignMutationResponse,
-} from '../mock_data';
+} from 'ee_else_ce_jest/work_items/mock_data';
 
 jest.mock('~/lib/utils/common_utils');
 jest.mock('~/work_items/components/design_management/cache_updates');
@@ -83,7 +86,9 @@ describe('WorkItemDetail component', () => {
     .fn()
     .mockResolvedValue({ data: { workItemUpdated: null } });
 
-  const allowedChildrenTypesHandler = jest.fn().mockResolvedValue(allowedChildrenTypesResponse);
+  const allowedChildrenTypesSuccessHandler = jest
+    .fn()
+    .mockResolvedValue(allowedChildrenTypesResponse);
   const workspacePermissionsAllowedHandler = jest
     .fn()
     .mockResolvedValue(mockProjectPermissionsQueryResponse());
@@ -118,6 +123,7 @@ describe('WorkItemDetail component', () => {
   const findCloseButton = () => wrapper.findByTestId('work-item-close');
   const findWorkItemType = () => wrapper.findByTestId('work-item-type');
   const findErrorTrackingWidget = () => wrapper.findComponent(WorkItemErrorTracking);
+  const findLinkedResourcesWidget = () => wrapper.findComponent(WorkItemLinkedResources);
   const findHierarchyTree = () => wrapper.findComponent(WorkItemTree);
   const findWorkItemRelationships = () => wrapper.findComponent(WorkItemRelationships);
   const findNotesWidget = () => wrapper.findComponent(WorkItemNotes);
@@ -136,6 +142,8 @@ describe('WorkItemDetail component', () => {
   const findDesignDropzone = () => wrapper.findComponent(DesignDropzone);
   const findWorkItemDetailInfo = () => wrapper.findByTestId('info-alert');
   const findShowSidebarButton = () => wrapper.findByTestId('work-item-show-sidebar-button');
+  const findRootNode = () => wrapper.findByTestId('work-item-detail');
+  const findRefetchAlert = () => wrapper.findByTestId('work-item-refetch-alert');
 
   const mockDragEvent = ({ types = ['Files'], files = [], items = [] }) => {
     return { dataTransfer: { types, files, items } };
@@ -157,8 +165,10 @@ describe('WorkItemDetail component', () => {
     modalIsGroup = null,
     workspacePermissionsHandler = workspacePermissionsAllowedHandler,
     uploadDesignMutationHandler = uploadSuccessDesignMutationHandler,
+    allowedChildrenTypesHandler = allowedChildrenTypesSuccessHandler,
     hasLinkedItemsEpicsFeature = true,
     showSidebar = true,
+    lastRealtimeUpdatedAt = new Date('2023-01-01T12:00:00.000Z'),
   } = {}) => {
     wrapper = shallowMountExtended(WorkItemDetail, {
       apolloProvider: createMockApollo([
@@ -173,6 +183,7 @@ describe('WorkItemDetail component', () => {
       ]),
       isLoggedIn: isLoggedIn(),
       propsData: {
+        workItemFullPath: 'group/project',
         workItemId,
         isModal,
         workItemIid,
@@ -184,6 +195,7 @@ describe('WorkItemDetail component', () => {
           updateInProgress,
           error,
           showSidebar,
+          lastRealtimeUpdatedAt,
         };
       },
       provide: {
@@ -191,9 +203,7 @@ describe('WorkItemDetail component', () => {
           workItemsAlpha: workItemsAlphaEnabled,
         },
         hasSubepicsFeature,
-        fullPath: 'group/project',
         groupPath: 'group',
-        reportAbusePath: '/report/abuse/path',
         hasLinkedItemsEpicsFeature,
       },
       stubs: {
@@ -201,6 +211,7 @@ describe('WorkItemDetail component', () => {
         WorkItemWeight: true,
         WorkItemIteration: true,
         WorkItemHealthStatus: true,
+        WorkItemErrorTracking,
       },
       mocks: {
         $router: router,
@@ -244,7 +255,7 @@ describe('WorkItemDetail component', () => {
     });
 
     it('does not fetch allowed children types for current work item', () => {
-      expect(allowedChildrenTypesHandler).not.toHaveBeenCalled();
+      expect(allowedChildrenTypesSuccessHandler).not.toHaveBeenCalled();
     });
   });
 
@@ -271,7 +282,7 @@ describe('WorkItemDetail component', () => {
     });
 
     it('updates the document title', () => {
-      expect(document.title).toEqual('Updated title (#1) · Task · test-project-path');
+      expect(document.title).toEqual('Updated _title_ (#1) · Task · test-project-path');
     });
 
     it('renders todos widget if logged in', () => {
@@ -283,7 +294,32 @@ describe('WorkItemDetail component', () => {
     });
 
     it('fetches allowed children types for current work item', () => {
-      expect(allowedChildrenTypesHandler).toHaveBeenCalled();
+      expect(allowedChildrenTypesSuccessHandler).toHaveBeenCalled();
+    });
+
+    it('fetches and sets allowedChildTypes when workItem.id changes', async () => {
+      wrapper.vm.workItem = { id: 'gid://gitlab/WorkItem/123' };
+
+      await nextTick();
+
+      expect(allowedChildrenTypesSuccessHandler).toHaveBeenCalledWith({
+        id: 'gid://gitlab/WorkItem/123',
+      });
+    });
+
+    it('handles Apollo error when fetching allowedChildTypes', async () => {
+      const allowedChildrenTypesErrorHandler = jest
+        .fn()
+        .mockRejectedValue(new Error('Apollo error'));
+
+      createComponent({
+        workItemId: 'gid://gitlab/WorkItem/123',
+        allowedChildrenTypesHandler: allowedChildrenTypesErrorHandler,
+      });
+
+      await waitForPromises();
+
+      expect(wrapper.vm.allowedChildTypes).toEqual([]);
     });
 
     it('passes `parentMilestone` prop to work item tree', () => {
@@ -297,7 +333,7 @@ describe('WorkItemDetail component', () => {
     it('renders error tracking widget', () => {
       expect(findErrorTrackingWidget().props()).toEqual({
         fullPath: 'group/project',
-        identifier: '1',
+        iid: '1',
       });
     });
   });
@@ -351,7 +387,7 @@ describe('WorkItemDetail component', () => {
       findWorkItemActions().vm.$emit('toggleWorkItemConfidentiality', true);
       await nextTick();
 
-      expect(findCreatedUpdated().props('updateInProgress')).toBe(true);
+      expect(findWorkItemActions().props('updateInProgress')).toBe(true);
     });
 
     it('emits workItemUpdated when mutation is successful', async () => {
@@ -494,7 +530,7 @@ describe('WorkItemDetail component', () => {
       });
 
       it('does not show title in the header when parent exists', () => {
-        expect(findWorkItemType().classes()).toEqual(['sm:!gl-hidden', 'gl-mt-3']);
+        expect(findWorkItemType().classes()).toEqual(['sm:!gl-hidden', '!gl-mt-3']);
       });
     });
 
@@ -511,7 +547,7 @@ describe('WorkItemDetail component', () => {
       });
 
       it('does not show title in the header when parent exists', () => {
-        expect(findWorkItemType().classes()).toEqual(['sm:!gl-hidden', 'gl-mt-3']);
+        expect(findWorkItemType().classes()).toEqual(['sm:!gl-hidden', '!gl-mt-3']);
       });
     });
   });
@@ -559,6 +595,13 @@ describe('WorkItemDetail component', () => {
     });
   });
 
+  it('renders the resources widget', async () => {
+    createComponent();
+    await waitForPromises();
+
+    expect(findLinkedResourcesWidget().exists()).toBe(true);
+  });
+
   it('shows an error message when WorkItemTitle emits an `error` event', async () => {
     createComponent();
     await waitForPromises();
@@ -699,6 +742,30 @@ describe('WorkItemDetail component', () => {
         expect(findDrawer().props('activeItem')).toEqual(null);
       });
 
+      it('closes the drawer when `show-modal` is emitted with `null`', async () => {
+        createComponent({ handler: objectiveHandler, workItemsAlphaEnabled: true });
+        await waitForPromises();
+        const event = {
+          preventDefault: jest.fn(),
+        };
+        const modalWorkItem = { id: 'childWorkItemId' };
+        findHierarchyTree().vm.$emit('show-modal', {
+          event,
+          modalWorkItem,
+        });
+        await waitForPromises();
+
+        expect(findDrawer().props('activeItem')).toEqual(modalWorkItem);
+
+        findHierarchyTree().vm.$emit('show-modal', {
+          event,
+          modalWorkItem: null,
+        });
+        await waitForPromises();
+
+        expect(findDrawer().props('activeItem')).toEqual(null);
+      });
+
       describe('work item is rendered in a modal and has children', () => {
         beforeEach(async () => {
           createComponent({
@@ -825,6 +892,42 @@ describe('WorkItemDetail component', () => {
 
       expect(findNotesWidget().exists()).toBe(true);
       expect(findNotesWidget().props('isWorkItemConfidential')).toBe(confidential);
+      expect(findNotesWidget().props('canCreateNote')).toBeDefined();
+    });
+
+    describe('comment templates', () => {
+      const mockCommentTemplatePaths = [
+        {
+          text: 'Your comment templates',
+          href: '/-/profile/comment_templates',
+          __typename: 'CommentTemplatePathType',
+        },
+        {
+          text: 'Project comment templates',
+          href: '/gitlab-org/gitlab-test/-/comment_templates',
+          __typename: 'CommentTemplatePathType',
+        },
+        {
+          text: 'Group comment templates',
+          href: '/groups/gitlab-org/-/comment_templates',
+          __typename: 'CommentTemplatePathType',
+        },
+      ];
+
+      it('passes fetched comment template paths to WorkItemNotes component', async () => {
+        const commentTemplateQueryResponse = workItemByIidResponseFactory({
+          commentTemplatesPaths: mockCommentTemplatePaths,
+        });
+
+        const commentTemplateHandler = jest.fn().mockResolvedValue(commentTemplateQueryResponse);
+
+        createComponent({ handler: commentTemplateHandler });
+        await waitForPromises();
+
+        expect(findNotesWidget().props('newCommentTemplatePaths')).toEqual(
+          mockCommentTemplatePaths,
+        );
+      });
     });
   });
 
@@ -900,11 +1003,11 @@ describe('WorkItemDetail component', () => {
           items: [{ type: 'image/png' }],
         });
 
-        wrapper.trigger('dragenter', dragEvent);
+        findRootNode().trigger('dragenter', dragEvent);
         glIntersectionObserver.vm.$emit('appear');
         await nextTick();
 
-        wrapper.trigger('dragover', dragEvent);
+        findRootNode().trigger('dragover', dragEvent);
         glIntersectionObserver.vm.$emit('appear');
         await nextTick();
 
@@ -1127,11 +1230,11 @@ describe('WorkItemDetail component', () => {
       expect(findStickyHeader().exists()).toBe(true);
     });
 
-    it('sticky header is not visible if is drawer view', async () => {
+    it('sticky header is visible in drawer view', async () => {
       createComponent({ isDrawer: true });
       await waitForPromises();
 
-      expect(findStickyHeader().exists()).toBe(false);
+      expect(findStickyHeader().exists()).toBe(true);
     });
   });
 
@@ -1193,13 +1296,6 @@ describe('WorkItemDetail component', () => {
   describe('work item parent id', () => {
     const parentId = 'gid://gitlab/Issue/1';
 
-    it('passes the `parentWorkItemId` value down to the `WorkItemStickyHeader` component', async () => {
-      createComponent();
-      await waitForPromises();
-
-      expect(findStickyHeader().props('parentId')).toBe(parentId);
-    });
-
     it('passes the `parentWorkItemId` value down to the `WorkItemActions` component', async () => {
       createComponent();
       await waitForPromises();
@@ -1255,4 +1351,195 @@ describe('WorkItemDetail component', () => {
       expect(findRightSidebar().isVisible()).toBe(true);
     });
   });
+
+  describe('tracking', () => {
+    const { bindInternalEventDocument } = useMockInternalEventsTracking();
+
+    beforeEach(async () => {
+      createComponent();
+      await waitForPromises();
+    });
+
+    describe('sidebar visibility tracking', () => {
+      it('tracks when sidebar is toggled', async () => {
+        const { trackEventSpy } = bindInternalEventDocument(wrapper.element);
+
+        findWorkItemActions().vm.$emit('toggleSidebar');
+        await nextTick();
+
+        expect(trackEventSpy).toHaveBeenCalledWith(
+          'change_work_item_sidebar_visibility',
+          {
+            label: 'false',
+          },
+          undefined,
+        );
+
+        findWorkItemActions().vm.$emit('toggleSidebar');
+        await nextTick();
+
+        expect(trackEventSpy).toHaveBeenCalledWith(
+          'change_work_item_sidebar_visibility',
+          {
+            label: 'true',
+          },
+          undefined,
+        );
+      });
+
+      it('tracks when show sidebar button is clicked', async () => {
+        const { trackEventSpy } = bindInternalEventDocument(wrapper.element);
+
+        createComponent({ showSidebar: false });
+        await waitForPromises();
+
+        findShowSidebarButton().vm.$emit('click');
+        await nextTick();
+
+        expect(trackEventSpy).toHaveBeenCalledWith(
+          'change_work_item_sidebar_visibility',
+          {
+            label: 'true',
+          },
+          undefined,
+        );
+      });
+    });
+
+    describe('description truncation tracking', () => {
+      it('tracks when truncation setting is toggled', async () => {
+        const { trackEventSpy } = bindInternalEventDocument(wrapper.element);
+
+        findWorkItemActions().vm.$emit('toggleTruncationEnabled');
+        await nextTick();
+
+        expect(trackEventSpy).toHaveBeenCalledWith(
+          'change_work_item_description_truncation',
+          {
+            label: 'false',
+          },
+          undefined,
+        );
+
+        findWorkItemActions().vm.$emit('toggleTruncationEnabled');
+        await nextTick();
+
+        expect(trackEventSpy).toHaveBeenCalledWith(
+          'change_work_item_description_truncation',
+          {
+            label: 'true',
+          },
+          undefined,
+        );
+      });
+    });
+  });
+
+  it('sets `canPasteDesign` to true on work item notes focus event', async () => {
+    createComponent();
+    await waitForPromises();
+
+    expect(findWorkItemDesigns().props('canPasteDesign')).toBe(true);
+
+    findNotesWidget().vm.$emit('focus');
+    await nextTick();
+
+    expect(findWorkItemDesigns().props('canPasteDesign')).toBe(false);
+  });
+
+  it('sets `canPasteDesign` to false on work item notes blur event', async () => {
+    createComponent();
+    await waitForPromises();
+
+    findNotesWidget().vm.$emit('focus');
+    await nextTick();
+
+    expect(findWorkItemDesigns().props('canPasteDesign')).toBe(false);
+
+    findNotesWidget().vm.$emit('blur');
+    await nextTick();
+
+    expect(findWorkItemDesigns().props('canPasteDesign')).toBe(true);
+  });
+
+  describe('when websocket is reconnecting', () => {
+    useRealDate();
+
+    it('refetches work item when `actioncable:reconnected` event is emitted', async () => {
+      createComponent();
+      await waitForPromises();
+
+      expect(successHandler).toHaveBeenCalledTimes(1);
+
+      document.dispatchEvent(new CustomEvent('actioncable:reconnected'));
+      await waitForPromises();
+
+      expect(successHandler).toHaveBeenCalledTimes(2);
+    });
+
+    it('does not refetch work item if less than 5 minutes have passed since last fetch', async () => {
+      createComponent({ lastRealtimeUpdatedAt: new Date() });
+      await waitForPromises();
+
+      expect(successHandler).toHaveBeenCalledTimes(1);
+
+      document.dispatchEvent(new CustomEvent('actioncable:reconnected'));
+      await waitForPromises();
+
+      expect(successHandler).toHaveBeenCalledTimes(1);
+    });
+  });
+
+  describe('when refetching work item fails', () => {
+    beforeEach(async () => {
+      createComponent();
+      await waitForPromises();
+
+      successHandler.mockRejectedValueOnce(new Error('Refetch failed'));
+      // unfortunately, calling refetch this way here is the only way to prevent Jest spec from failing
+      // if we try refetching via user action, we cannot handle refetch Apollo error properly
+      await wrapper.vm.$apollo.queries.workItem.refetch().catch(() => {});
+      await waitForPromises();
+    });
+
+    it('renders refetch alert', () => {
+      expect(findRefetchAlert().exists()).toBe(true); // Just to ensure the test runs without errors
+    });
+
+    it('applies correct classes to refetch alert', () => {
+      expect(findRefetchAlert().classes()).toEqual([
+        'flash-container',
+        'flash-container-page',
+        'sticky',
+      ]);
+    });
+
+    it('hides refetch alert when it is dismissed', async () => {
+      findRefetchAlert().findComponent(GlAlert).vm.$emit('dismiss');
+      await nextTick();
+
+      expect(findRefetchAlert().exists()).toBe(false);
+    });
+
+    it('hides refetch alert on successful refetch', async () => {
+      successHandler.mockResolvedValueOnce(workItemByIidQueryResponse);
+      findRefetchAlert().findComponent(GlButton).vm.$emit('click');
+      await waitForPromises();
+
+      expect(findRefetchAlert().exists()).toBe(false);
+    });
+  });
+
+  it('applied correct classes to refetch error banner in the drawer', async () => {
+    createComponent({ isDrawer: true });
+    await waitForPromises();
+
+    successHandler.mockRejectedValueOnce(new Error('Refetch failed'));
+    // unfortunately, calling refetch this way here is the only way to prevent Jest spec from failing
+    // if we try refetching via user action, we cannot handle refetch Apollo error properly
+    await wrapper.vm.$apollo.queries.workItem.refetch().catch(() => {});
+    await waitForPromises();
+
+    expect(findRefetchAlert().classes()).toEqual(['gl-sticky', 'gl-top-0']);
+  });
 });
