@@ -2,10 +2,12 @@ import { GlIntersectionObserver, GlLink } from '@gitlab/ui';
 import { nextTick } from 'vue';
 import { shallowMountExtended } from 'helpers/vue_test_utils_helper';
 import { STATE_OPEN } from '~/work_items/constants';
-import { workItemResponseFactory } from 'jest/work_items/mock_data';
+import { workItemResponseFactory } from 'ee_else_ce_jest/work_items/mock_data';
+import HiddenBadge from '~/issuable/components/hidden_badge.vue';
 import LockedBadge from '~/issuable/components/locked_badge.vue';
 import WorkItemStickyHeader from '~/work_items/components/work_item_sticky_header.vue';
 import ConfidentialityBadge from '~/vue_shared/components/confidentiality_badge.vue';
+import ImportedBadge from '~/vue_shared/components/imported_badge.vue';
 import TodosToggle from '~/work_items/components/shared/todos_toggle.vue';
 import WorkItemStateBadge from '~/work_items/components/work_item_state_badge.vue';
 import WorkItemNotificationsWidget from '~/work_items/components/work_item_notifications_widget.vue';
@@ -15,14 +17,16 @@ describe('WorkItemStickyHeader', () => {
 
   const createComponent = ({
     confidential = false,
+    hidden = false,
+    imported = false,
     discussionLocked = false,
     canUpdate = true,
     features = {},
-    parentId = null,
     movedToWorkItemUrl = null,
     duplicatedToWorkItemUrl = null,
     promotedToEpicUrl = null,
     slots = {},
+    isDrawer = false,
   } = {}) => {
     wrapper = shallowMountExtended(WorkItemStickyHeader, {
       propsData: {
@@ -30,23 +34,18 @@ describe('WorkItemStickyHeader', () => {
           canUpdate,
           confidential,
           discussionLocked,
+          hidden,
+          imported,
           movedToWorkItemUrl,
           duplicatedToWorkItemUrl,
           promotedToEpicUrl,
         }).data.workItem,
-        fullPath: '/test',
         isStickyHeaderShowing: true,
-        workItemNotificationsSubscribed: true,
         updateInProgress: false,
-        parentWorkItemConfidentiality: false,
         showWorkItemCurrentUserTodos: true,
-        isModal: false,
         currentUserTodos: [],
         workItemState: STATE_OPEN,
-        isGroup: false,
-        parentId,
-        showSidebar: true,
-        enableTruncation: true,
+        isDrawer,
       },
       provide: {
         glFeatures: {
@@ -59,6 +58,8 @@ describe('WorkItemStickyHeader', () => {
 
   const findStickyHeader = () => wrapper.findByTestId('work-item-sticky-header');
   const findConfidentialityBadge = () => wrapper.findComponent(ConfidentialityBadge);
+  const findHiddenBadge = () => wrapper.findComponent(HiddenBadge);
+  const findImportedBadge = () => wrapper.findComponent(ImportedBadge);
   const findLockedBadge = () => wrapper.findComponent(LockedBadge);
   const findTodosToggle = () => wrapper.findComponent(TodosToggle);
   const findIntersectionObserver = () => wrapper.findComponent(GlIntersectionObserver);
@@ -106,6 +107,28 @@ describe('WorkItemStickyHeader', () => {
     expect(findWorkItemStateBadge().exists()).toBe(true);
   });
 
+  describe('positioning classes', () => {
+    it('applies absolute positioning classes when isDrawer is true', () => {
+      createComponent({ isDrawer: true });
+
+      const stickyHeader = findStickyHeader();
+      expect(stickyHeader.classes()).toContain('gl-absolute');
+      expect(stickyHeader.classes()).toContain('gl-left-0');
+      expect(stickyHeader.classes()).toContain('gl-top-10');
+      expect(stickyHeader.classes()).not.toContain('gl-fixed');
+    });
+
+    it('applies fixed positioning classes when isDrawer is false', () => {
+      createComponent({ isDrawer: false });
+
+      const stickyHeader = findStickyHeader();
+      expect(stickyHeader.classes()).toContain('gl-fixed');
+      expect(stickyHeader.classes()).not.toContain('gl-absolute');
+      expect(stickyHeader.classes()).not.toContain('gl-left-0');
+      expect(stickyHeader.classes()).not.toContain('gl-top-10');
+    });
+  });
+
   describe('edit button', () => {
     it('renders the button when it has permissions to edit', () => {
       createComponent({ canUpdate: true });
@@ -198,4 +221,32 @@ describe('WorkItemStickyHeader', () => {
       });
     });
   });
+
+  describe('hidden badge', () => {
+    it('renders when the work item is hidden', () => {
+      createComponent({ hidden: true });
+
+      expect(findHiddenBadge().exists()).toBe(true);
+    });
+
+    it('does not render when the work item is not hidden', () => {
+      createComponent({ hidden: false });
+
+      expect(findHiddenBadge().exists()).toBe(false);
+    });
+  });
+
+  describe('imported badge', () => {
+    it('renders when the work item is imported', () => {
+      createComponent({ imported: true });
+
+      expect(findImportedBadge().exists()).toBe(true);
+    });
+
+    it('does not render when the work item is not imported', () => {
+      createComponent({ imported: false });
+
+      expect(findImportedBadge().exists()).toBe(false);
+    });
+  });
 });
