@@ -15,6 +15,8 @@ RSpec.describe GitlabSchema.types['Project'], feature_category: :groups_and_proj
 
   specify { expect(described_class.interfaces).to include(Types::TodoableInterface) }
 
+  specify { expect(described_class.interfaces).to include(::Types::Projects::ProjectInterface) }
+
   it 'has the expected fields' do
     expected_fields = %w[
       user_permissions id full_path path name_with_namespace
@@ -47,7 +49,8 @@ RSpec.describe GitlabSchema.types['Project'], feature_category: :groups_and_proj
       allows_multiple_merge_request_assignees allows_multiple_merge_request_reviewers is_forked
       protectable_branches available_deploy_keys explore_catalog_path
       container_protection_tag_rules pages_force_https pages_use_unique_domain ci_pipeline_creation_request
-      ci_pipeline_creation_inputs
+      ci_pipeline_creation_inputs marked_for_deletion_on permanent_deletion_date
+      merge_request_title_regex merge_request_title_regex_description
     ]
 
     expect(described_class).to include_graphql_fields(*expected_fields)
@@ -73,6 +76,10 @@ RSpec.describe GitlabSchema.types['Project'], feature_category: :groups_and_proj
 
     subject { GitlabSchema.execute(query, context: { current_user: user }).as_json }
 
+    before do
+      ::Current.organization = user.namespace.organization
+    end
+
     it 'returns valid projects count' do
       create(:project, namespace: user.namespace)
       create(:project, namespace: user.namespace)
@@ -81,6 +88,45 @@ RSpec.describe GitlabSchema.types['Project'], feature_category: :groups_and_proj
     end
   end
 
+  describe 'archived' do
+    let_it_be_with_reload(:parent_group) { create(:group) }
+    let_it_be_with_reload(:project) { create(:project, :public, namespace: parent_group) }
+
+    let(:project_full_path) { project.full_path }
+    let(:query) do
+      %(
+        query {
+          project(fullPath: "#{project_full_path}") {
+            archived
+          }
+        }
+      )
+    end
+
+    subject(:project_archived_result) do
+      result = GitlabSchema.execute(query).as_json
+      result.dig('data', 'project', 'archived')
+    end
+
+    where(:project_archived, :parent_archived, :expected_result) do
+      false | false | false
+      false | true  | true
+      true  | false | true
+      true  | true  | true
+    end
+
+    with_them do
+      before do
+        parent_group.update!(archived: parent_archived)
+        project.update!(archived: project_archived)
+      end
+
+      it 'returns expected archived result' do
+        expect(project_archived_result).to eq(expected_result)
+      end
+    end
+  end
+
   describe 'container_registry_enabled' do
     let_it_be(:project, reload: true) { create(:project, :public) }
     let_it_be(:user) { create(:user) }
@@ -345,7 +391,6 @@ RSpec.describe GitlabSchema.types['Project'], feature_category: :groups_and_proj
         :target_branches,
         :state,
         :draft,
-        :approved,
         :labels,
         :label_name,
         :before,
@@ -505,7 +550,7 @@ RSpec.describe GitlabSchema.types['Project'], feature_category: :groups_and_proj
   end
 
   it_behaves_like 'a GraphQL type with labels' do
-    let(:labels_resolver_arguments) { [:search_term, :includeAncestorGroups, :searchIn, :title] }
+    let(:labels_resolver_arguments) { [:search_term, :includeAncestorGroups, :searchIn, :title, :archived] }
   end
 
   describe 'jira_imports' do
@@ -548,7 +593,7 @@ RSpec.describe GitlabSchema.types['Project'], feature_category: :groups_and_proj
 
     it do
       is_expected.to have_graphql_arguments(:statuses, :with_artifacts, :name, :sources,
-        :after, :before, :first, :last)
+        :after, :before, :first, :last, :kind)
     end
   end
 
@@ -1466,4 +1511,182 @@ RSpec.describe GitlabSchema.types['Project'], feature_category: :groups_and_proj
       end
     end
   end
+
+  describe 'project adjourned deletion fields', time_travel_to: '2025-06-01', feature_category: :groups_and_projects do
+    let_it_be(:user) { create(:user) }
+    let_it_be(:project) { create(:project) }
+    let_it_be(:marked_for_deletion_at) { Time.new(2025, 5, 25) }
+    let_it_be(:pending_delete_group) do
+      create(:group_with_deletion_schedule, marked_for_deletion_on: marked_for_deletion_at, developers: user)
+    end
+
+    let_it_be(:project_being_deleted) do
+      create(:project, pending_delete: true, developers: user)
+    end
+
+    let_it_be(:pending_delete_project) { create(:project, marked_for_deletion_at: marked_for_deletion_at) }
+    let_it_be(:parent_pending_delete_project) { create(:project, group: pending_delete_group) }
+
+    let(:project_full_path) { pending_delete_project.full_path }
+
+    let(:query) do
+      %(
+        query {
+          project(fullPath: "#{project_full_path}") {
+            markedForDeletion
+            markedForDeletionOn
+            permanentDeletionDate
+            isSelfDeletionInProgress
+            isSelfDeletionScheduled
+          }
+        }
+      )
+    end
+
+    before do
+      pending_delete_project.add_developer(user)
+      project.add_developer(user)
+      stub_application_setting(deletion_adjourned_period: 7)
+    end
+
+    subject(:project_data) do
+      result = GitlabSchema.execute(query, context: { current_user: user }).as_json
+      {
+        marked_for_deletion: result.dig('data', 'project', 'markedForDeletion'),
+        marked_for_deletion_on: result.dig('data', 'project', 'markedForDeletionOn'),
+        permanent_deletion_date: result.dig('data', 'project', 'permanentDeletionDate'),
+        is_self_deletion_in_progress: result.dig('data', 'project', 'isSelfDeletionInProgress'),
+        is_self_deletion_scheduled: result.dig('data', 'project', 'isSelfDeletionScheduled')
+      }
+    end
+
+    it 'marked_for_deletion returns true' do
+      expect(project_data[:marked_for_deletion]).to be true
+    end
+
+    it 'marked_for_deletion_on returns correct date' do
+      marked_for_deletion_on_time = Time.zone.parse(project_data[:marked_for_deletion_on])
+
+      expect(marked_for_deletion_on_time).to eq(pending_delete_project.marked_for_deletion_at.iso8601)
+    end
+
+    it 'returns false for is_self_deletion_in_progress' do
+      expect(project_data[:is_self_deletion_in_progress]).to be false
+    end
+
+    context 'when project is scheduled for deletion' do
+      it 'returns date project will be permanently deleted for permanent_deletion_date' do
+        expect(project_data[:permanent_deletion_date])
+          .to eq(
+            ::Gitlab::CurrentSettings.deletion_adjourned_period.days.since(marked_for_deletion_at).strftime('%F')
+          )
+      end
+
+      it 'returns true for is_self_deletion_scheduled' do
+        expect(project_data[:is_self_deletion_scheduled]).to be true
+      end
+    end
+
+    context 'when parent is scheduled for deletion' do
+      let(:project_full_path) { parent_pending_delete_project.full_path }
+
+      it 'marked_for_deletion returns true' do
+        expect(project_data[:marked_for_deletion]).to be true
+      end
+
+      it 'returns false for is_self_deletion_scheduled' do
+        expect(project_data[:is_self_deletion_scheduled]).to be false
+      end
+    end
+
+    context 'when project is not scheduled for deletion' do
+      let(:project_full_path) { project.full_path }
+
+      it 'marked_for_deletion returns false' do
+        expect(project_data[:marked_for_deletion]).to be false
+      end
+
+      it 'returns false for is_self_deletion_scheduled' do
+        expect(project_data[:is_self_deletion_scheduled]).to be false
+      end
+
+      it 'returns theoretical date project will be permanently deleted for permanent_deletion_date' do
+        expect(project_data[:permanent_deletion_date])
+          .to eq(::Gitlab::CurrentSettings.deletion_adjourned_period.days.since(Date.current).strftime('%F'))
+      end
+    end
+
+    context 'when project is being deleted' do
+      let(:project_full_path) { project_being_deleted.full_path }
+
+      it 'returns true for is_self_deletion_in_progress' do
+        expect(project_data[:is_self_deletion_in_progress]).to be true
+      end
+    end
+  end
+
+  describe 'container_protection_tag_rules', unless: Gitlab.ee? do
+    let_it_be(:project) { create(:project) }
+    let_it_be(:user) { create(:user) }
+
+    let(:query) do
+      %(
+        query {
+          project(fullPath: "#{project.full_path}") {
+            containerProtectionTagRules {
+              nodes {
+                id
+                tagNamePattern
+                minimumAccessLevelForPush
+                minimumAccessLevelForDelete
+              }
+            }
+          }
+        }
+      )
+    end
+
+    before_all do
+      create(:container_registry_protection_tag_rule,
+        project: project,
+        minimum_access_level_for_push: Gitlab::Access::MAINTAINER,
+        minimum_access_level_for_delete: Gitlab::Access::OWNER,
+        tag_name_pattern: 'mutable'
+      )
+    end
+
+    subject do
+      GitlabSchema.execute(query, context: { current_user: user })
+        .as_json.dig('data', 'project', 'containerProtectionTagRules', 'nodes')
+    end
+
+    before do
+      project.add_maintainer(user)
+    end
+
+    it do
+      is_expected.to have_attributes(size: 1).and contain_exactly(
+        a_hash_including(
+          'tagNamePattern' => 'mutable',
+          'minimumAccessLevelForPush' => 'MAINTAINER',
+          'minimumAccessLevelForDelete' => 'OWNER'
+        )
+      )
+    end
+  end
+
+  describe '.authorization_scopes' do
+    it 'includes :ai_workflows' do
+      expect(described_class.authorization_scopes).to include(:ai_workflows)
+    end
+  end
+
+  describe 'fields with :ai_workflows scope' do
+    %w[id fullPath workItems languages statisticsDetailsPaths].each do |field_name|
+      it "includes :ai_workflows scope for the #{field_name} field" do
+        field = described_class.fields[field_name]
+        expect(field.instance_variable_get(:@scopes)).to include(:ai_workflows)
+      end
+    end
+  end
 end
