@@ -84,10 +84,6 @@ RSpec.describe BlobHelper, feature_category: :source_code_management do
   context 'viewer related' do
     let_it_be(:project) { create(:project, lfs_enabled: true) }
 
-    before do
-      allow(Gitlab.config.lfs).to receive(:enabled).and_return(true)
-    end
-
     let(:viewer_class) do
       Class.new(BlobViewer::Base) do
         include BlobViewer::ServerSide
@@ -101,6 +97,10 @@ RSpec.describe BlobHelper, feature_category: :source_code_management do
     let(:viewer) { viewer_class.new(blob) }
     let(:blob) { fake_blob }
 
+    before do
+      allow(Gitlab.config.lfs).to receive(:enabled).and_return(true)
+    end
+
     describe '#blob_render_error_reason' do
       context 'for error :too_large' do
         context 'when the blob size is larger than the absolute size limit' do
@@ -398,8 +398,10 @@ RSpec.describe BlobHelper, feature_category: :source_code_management do
     let(:project) { create(:project) }
     let(:user) { build_stubbed(:user) }
     let(:ref) { 'main' }
+    let(:organization) { build_stubbed(:organization) }
 
     before do
+      Current.organization = organization
       allow(helper).to receive_messages(selected_branch: ref, current_user: user)
     end
 
@@ -413,7 +415,9 @@ RSpec.describe BlobHelper, feature_category: :source_code_management do
         user_id: user.to_global_id,
         target_branch: ref,
         original_branch: ref,
-        can_download_code: 'false'
+        escaped_ref: ActionDispatch::Journey::Router::Utils.escape_path(ref),
+        can_download_code: 'false',
+        full_name: project.name_with_namespace
       })
     end
 
@@ -582,15 +586,19 @@ RSpec.describe BlobHelper, feature_category: :source_code_management do
   describe '#vue_blob_header_app_data' do
     let_it_be(:project) { create(:project) }
     let_it_be(:blob) { fake_blob(path: 'README.md') }
-    let(:ref) { 'main' }
+    let(:ref) { 'feature' }
     let(:ref_type) { :branch }
     let(:breadcrumb_data) { { title: 'README.md', 'is-last': true } }
+    let(:organization) { build_stubbed(:organization) }
 
     before do
+      Current.organization = organization
       assign(:project, project)
       assign(:ref, ref)
       assign(:ref_type, ref_type)
       allow(helper).to receive(:breadcrumb_data_attributes).and_return(breadcrumb_data)
+      allow(helper).to receive(:show_xcode_link?).and_return(true)
+      allow(helper).to receive(:xcode_uri_to_repo).with(project).and_return('xcode://example.com/project.git')
     end
 
     it 'returns data related to blob header' do
@@ -605,8 +613,23 @@ RSpec.describe BlobHelper, feature_category: :source_code_management do
         project_path: project.full_path,
         project_short_path: project.path,
         ref_type: ref_type.to_s,
-        ref: ref
+        ref: ref,
+        root_ref: project.repository.root_ref,
+        ssh_url: ssh_clone_url_to_repo(project),
+        http_url: http_clone_url_to_repo(project),
+        xcode_url: 'xcode://example.com/project.git',
+        download_links: helper.send(:archive_download_links, project, ref, "#{project.path}-#{ref.tr('/', '-')}").to_json
       })
     end
+
+    it 'returns download links for all supported archive formats' do
+      allow(helper).to receive(:external_storage_url_or_path) { |path| "download/#{path}" }
+
+      links = helper.send(:archive_download_links, project, 'master', 'prefix')
+
+      expect(links.pluck(:text)).to eq(Gitlab::Workhorse::ARCHIVE_FORMATS)
+      expect(links.pluck(:path)).to all(start_with('download/'))
+      expect(links).to all(include(:text, :path))
+    end
   end
 end
