@@ -42,11 +42,11 @@ RSpec.describe MergeRequestsHelper, feature_category: :code_review_workflow do
       let(:project) { create(:project) }
       let(:forked_project) { fork_project(project) }
       let(:merge_request) { create(:merge_request, source_project: forked_project, target_project: project) }
-      subject { format_mr_branch_names(merge_request) }
-
       let(:source_title) { "#{forked_project.full_path}:#{merge_request.source_branch}" }
       let(:target_title) { "#{project.full_path}:#{merge_request.target_branch}" }
 
+      subject { format_mr_branch_names(merge_request) }
+
       it { is_expected.to eq([source_title, target_title]) }
     end
   end
@@ -120,29 +120,6 @@ RSpec.describe MergeRequestsHelper, feature_category: :code_review_workflow do
     end
   end
 
-  describe '#user_merge_requests_counts' do
-    let(:user) do
-      double(
-        assigned_open_merge_requests_count: 1,
-        review_requested_open_merge_requests_count: 2
-      )
-    end
-
-    subject { helper.user_merge_requests_counts }
-
-    before do
-      allow(helper).to receive(:current_user).and_return(user)
-    end
-
-    it "returns assigned, review requested and total merge request counts" do
-      expect(subject).to eq(
-        assigned: user.assigned_open_merge_requests_count,
-        review_requested: user.review_requested_open_merge_requests_count,
-        total: user.assigned_open_merge_requests_count + user.review_requested_open_merge_requests_count
-      )
-    end
-  end
-
   describe '#reviewers_label' do
     let(:merge_request) { build_stubbed(:merge_request) }
     let(:reviewer1) { build_stubbed(:user, name: 'Jane Doe') }
@@ -234,13 +211,14 @@ RSpec.describe MergeRequestsHelper, feature_category: :code_review_workflow do
 
   describe '#sticky_header_data' do
     let_it_be(:project) { create(:project) }
-    let(:merge_request) do
+    let_it_be(:draft_merge_request) { create(:merge_request, :opened, :draft_merge_request) }
+    let(:imported_merge_request) do
       create(:merge_request, source_project: project, target_project: project, imported_from: imported_from)
     end
 
-    subject { sticky_header_data(project, merge_request) }
-
     context 'when the merge request is not imported' do
+      subject { sticky_header_data(project, imported_merge_request) }
+
       let(:imported_from) { :none }
 
       it 'returns data with imported set as false' do
@@ -249,12 +227,22 @@ RSpec.describe MergeRequestsHelper, feature_category: :code_review_workflow do
     end
 
     context 'when the merge request is imported' do
+      subject { sticky_header_data(project, imported_merge_request) }
+
       let(:imported_from) { :gitlab_migration }
 
       it 'returns data with imported set as true' do
         expect(subject[:imported]).to eq('true')
       end
     end
+
+    context 'when the merge request isDraft' do
+      subject { sticky_header_data(project, draft_merge_request) }
+
+      it 'returns data with is_draft set as true' do
+        expect(subject[:isDraft]).to eq('true')
+      end
+    end
   end
 
   describe '#tab_count_display' do
@@ -355,33 +343,6 @@ RSpec.describe MergeRequestsHelper, feature_category: :code_review_workflow do
     end
   end
 
-  describe '#project_merge_requests_list_more_actions_data' do
-    let(:project) { create(:project) }
-
-    subject { helper.project_merge_requests_list_more_actions_data(project, current_user) }
-
-    before do
-      allow(helper).to receive(:project).and_return(project)
-      allow(helper).to receive(:current_user).and_return(current_user)
-      allow(helper).to receive(:issuables_count_for_state).and_return(5)
-      allow(helper).to receive(:url_for).and_return("/rss-url")
-      allow(helper).to receive(:export_csv_project_merge_requests_path).and_return('/csv-url')
-    end
-
-    it 'returns the correct data' do
-      expected_data = {
-        is_signed_in: 'true',
-        issuable_type: :merge_request,
-        issuable_count: 5,
-        email: current_user.notification_email_or_default,
-        export_csv_path: '/csv-url',
-        rss_url: '/rss-url'
-      }
-
-      expect(subject).to eq(expected_data)
-    end
-  end
-
   describe '#identity_verification_alert_data' do
     let_it_be(:current_user) { build_stubbed(:user) }
     let(:merge_request) { build_stubbed(:merge_request, author: current_user) }
@@ -445,7 +406,7 @@ RSpec.describe MergeRequestsHelper, feature_category: :code_review_workflow do
 
     it 'returns the correct data' do
       expected_data = {
-        group_id: group.id,
+        namespace_id: group.id,
         full_path: group.full_path,
         show_new_resource_dropdown: "false",
         autocomplete_award_emojis_path: autocomplete_award_emojis_path,
@@ -495,4 +456,23 @@ RSpec.describe MergeRequestsHelper, feature_category: :code_review_workflow do
       it { is_expected.to eq(expected) }
     end
   end
+
+  describe '#merge_request_dashboard_role_based_data' do
+    subject(:data) { merge_request_dashboard_role_based_data }
+
+    before do
+      allow(helper).to receive(:current_user).and_return(current_user)
+    end
+
+    it do
+      expect(data.dig(:tabs, 0, :lists, 0, 2, :variables)).to include(
+        or: {
+          reviewerWildcard: "NONE",
+          onlyReviewerUsername: "GitLabDuo",
+          reviewStates: %w[REVIEWED REQUESTED_CHANGES]
+        },
+        perPage: 10
+      )
+    end
+  end
 end
