@@ -6,6 +6,13 @@ RSpec.describe SearchHelper, feature_category: :global_search do
   include MarkupHelper
   include BadgesHelper
 
+  before do
+    # TODO: When removing the feature flag,
+    # we won't need the tests for the issues listing page, since we'll be using
+    # the work items listing page.
+    stub_feature_flags(work_item_planning_view: false)
+  end
+
   # Override simple_sanitize for our testing purposes
   def simple_sanitize(str)
     str
@@ -598,8 +605,8 @@ RSpec.describe SearchHelper, feature_category: :global_search do
 
   describe 'projects_autocomplete' do
     let_it_be(:user) { create(:user) }
-    let_it_be(:project_1) { create(:project, name: 'test 1') }
-    let_it_be(:project_2) { create(:project, name: 'test 2') }
+    let_it_be(:project_1) { create(:project, name: 'test 1', star_count: 5) }
+    let_it_be(:project_2) { create(:project, name: 'test 2', star_count: 2) }
     let(:search_term) { 'test' }
 
     before do
@@ -621,6 +628,17 @@ RSpec.describe SearchHelper, feature_category: :global_search do
         expect(projects_autocomplete(search_term).pluck(:id)).to eq([project_2.id])
       end
 
+      it 'orders by star_count descending' do
+        project_1.add_developer(user)
+
+        expect(projects_autocomplete(search_term).pluck(:id)).to eq([project_1.id, project_2.id])
+
+        project_1.update!(star_count: 2)
+        project_2.update!(star_count: 5)
+
+        expect(projects_autocomplete(search_term).pluck(:id)).to eq([project_2.id, project_1.id])
+      end
+
       context 'when the search term is Gitlab::Search::Params::MIN_TERM_LENGTH characters long' do
         let(:search_term) { 'te' }
 
@@ -641,37 +659,6 @@ RSpec.describe SearchHelper, feature_category: :global_search do
           expect(projects_autocomplete(search_term).pluck(:id)).to match_array([project_2.id, project_3.id])
         end
       end
-
-      context 'with feature flag autocomplete_projects_use_search_service disabled' do
-        before do
-          stub_feature_flags(autocomplete_projects_use_search_service: false)
-        end
-
-        it 'returns the project' do
-          expect(projects_autocomplete(search_term).pluck(:id)).to eq([project_2.id])
-        end
-
-        context 'when the search term is Gitlab::Search::Params::MIN_TERM_LENGTH characters long' do
-          let(:search_term) { 'te' }
-
-          it 'returns the project' do
-            expect(projects_autocomplete(search_term).pluck(:id)).to eq([project_2.id])
-          end
-        end
-
-        context 'when a project namespace matches the search term but the project does not' do
-          let_it_be(:group) { create(:group, name: 'test group') }
-          let_it_be(:project_3) { create(:project, name: 'nothing', namespace: group) }
-
-          before do
-            group.add_owner(user)
-          end
-
-          it 'returns all projects matching the term' do
-            expect(projects_autocomplete(search_term).pluck(:id)).to match_array([project_2.id, project_3.id])
-          end
-        end
-      end
     end
   end
 
@@ -838,63 +825,6 @@ RSpec.describe SearchHelper, feature_category: :global_search do
     end
   end
 
-  describe 'search_filter_link' do
-    it 'renders a search filter link for the current scope' do
-      @scope = 'projects'
-      @search_results = double
-
-      expect(@search_results).to receive(:formatted_count).with('projects').and_return('23')
-
-      link = search_filter_link('projects', 'Projects')
-
-      expect(link).to have_css('li.active')
-      expect(link).to have_link('Projects', href: search_path(scope: 'projects'))
-      expect(link).to have_css('span.badge.badge-pill:not(.js-search-count):not(.hidden):not([data-url])', text: '23')
-    end
-
-    it 'renders a search filter link for another scope' do
-      link = search_filter_link('projects', 'Projects')
-      count_path = search_count_path(scope: 'projects')
-
-      expect(link).to have_css('li:not([class="active"])')
-      expect(link).to have_link('Projects', href: search_path(scope: 'projects'))
-      expect(link).to have_css("span.badge.badge-pill.js-search-count.hidden[data-url='#{count_path}']", text: '')
-    end
-
-    it 'merges in the current search params and given params' do
-      expect(self).to receive(:params).and_return(
-        ActionController::Parameters.new(
-          search: 'hello',
-          scope: 'ignored',
-          other_param: 'ignored'
-        )
-      )
-
-      link = search_filter_link('projects', 'Projects', search: { project_id: 23 })
-
-      expect(link).to have_link('Projects', href: search_path(scope: 'projects', search: 'hello', project_id: 23))
-    end
-
-    it 'restricts the params' do
-      expect(self).to receive(:params).and_return(
-        ActionController::Parameters.new(
-          search: 'hello',
-          unknown: 42
-        )
-      )
-
-      link = search_filter_link('projects', 'Projects')
-
-      expect(link).to have_link('Projects', href: search_path(scope: 'projects', search: 'hello'))
-    end
-
-    it 'assigns given data attributes on the list container' do
-      link = search_filter_link('projects', 'Projects', data: { foo: 'bar' })
-
-      expect(link).to have_css('li[data-foo="bar"]')
-    end
-  end
-
   describe '#repository_ref' do
     using RSpec::Parameterized::TableSyntax
 
