@@ -333,6 +333,137 @@ RSpec.describe Member, feature_category: :groups_and_projects do
       end
     end
 
+    describe '.seat_assignable' do
+      let_it_be(:user) { create(:user) }
+      let_it_be(:other_user) { create(:user) }
+
+      let_it_be(:other_group) { create(:group) }
+      let_it_be(:subgroup) { create(:group, parent: group) }
+      let_it_be(:project) { create(:project, group: group) }
+
+      let_it_be(:group_member) { create(:group_member, source: group, user: user) }
+      let_it_be(:subgroup_member) { create(:group_member, source: subgroup, user: user) }
+
+      let_it_be(:other_group_member) { create(:group_member, user: user, source: other_group) }
+      let_it_be(:other_user_group_member) { create(:group_member, user: other_user, source: other_group) }
+
+      context 'without namespace' do
+        it 'returns members of the user' do
+          expect(described_class.seat_assignable(users: user))
+            .to match_array([group_member, subgroup_member, other_group_member])
+        end
+      end
+
+      context 'with group' do
+        it 'returns members in namespace hierarchy' do
+          expect(described_class.seat_assignable(users: user, namespace: group))
+            .to match_array([group_member, subgroup_member])
+        end
+      end
+
+      context 'with subgroup' do
+        it 'returns members in namespace hierarchy' do
+          expect(described_class.seat_assignable(users: user, namespace: subgroup))
+            .to match_array([group_member, subgroup_member])
+        end
+      end
+
+      context 'with another user' do
+        it 'returns other users namespaces' do
+          expect(described_class.seat_assignable(users: other_user))
+            .to match_array([other_user_group_member])
+        end
+      end
+
+      it 'returns non invited users' do
+        group_member.update!(invite_token: Time.zone.now, invite_email: user.email)
+
+        expect(described_class.seat_assignable(users: user)).not_to include(group_member)
+      end
+
+      it 'returns non requested users' do
+        group_member.update!(requested_at: Time.zone.now)
+
+        expect(described_class.seat_assignable(users: user)).not_to include(group_member)
+      end
+    end
+
+    describe '.seat_assignable?' do
+      let_it_be(:user) { create(:user) }
+
+      let_it_be(:subgroup) { create(:group, parent: group) }
+      let_it_be(:subgroup_member) { create(:group_member, source: subgroup, user: user) }
+
+      it { expect(described_class.seat_assignable?(user: user)).to be true }
+      it { expect(described_class.seat_assignable?(user: user, namespace: group)).to be true }
+      it { expect(described_class.seat_assignable?(user: user, namespace: subgroup)).to be true }
+
+      it { expect(described_class.seat_assignable?(user: create(:user), namespace: subgroup)).to be false }
+      it { expect(described_class.seat_assignable?(user: user, namespace: create(:group))).to be false }
+    end
+
+    describe '.seat_assignable_highest_access_level' do
+      let_it_be(:user) { create(:user) }
+
+      let_it_be(:group) { create(:group).tap { |group| group.add_maintainer(user) } }
+      let_it_be(:subgroup) { create(:group, parent: group).tap { |group| group.add_developer(user) } }
+      let_it_be(:other_group) { create(:group).tap { |group| group.add_owner(user) } }
+
+      it 'returns the highest acecss level' do
+        expect(described_class.seat_assignable_highest_access_level(user: user))
+          .to eq Gitlab::Access::OWNER
+      end
+
+      it 'returns the highest access level scoped to a hierarchy' do
+        expect(described_class.seat_assignable_highest_access_level(user: user, namespace: group))
+          .to eq Gitlab::Access::MAINTAINER
+      end
+
+      it 'returns the highest access level scoped per hierarchy' do
+        expect(described_class.seat_assignable_highest_access_level(user: user, namespace: subgroup))
+          .to eq Gitlab::Access::MAINTAINER
+      end
+    end
+
+    describe '.seat_assignable_highest_access_levels' do
+      let_it_be(:user1) { create(:user) }
+      let_it_be(:user2) { create(:user) }
+
+      let_it_be(:group1) do
+        create(:group).tap do |group|
+          group.add_guest(user1)
+          group.add_maintainer(user2)
+        end
+      end
+
+      let_it_be(:group2) { create(:group).tap { |group| group.add_developer(user1) } }
+
+      it 'returns the highest access level for all namespaces' do
+        expect(described_class.seat_assignable_highest_access_levels(users: user1))
+          .to eq({ user1.id => Gitlab::Access::DEVELOPER })
+      end
+
+      it 'returns the highest access level in the namespace hierarchy' do
+        expect(described_class.seat_assignable_highest_access_levels(users: user1, namespace: group1))
+          .to eq({ user1.id => Gitlab::Access::GUEST })
+      end
+
+      it 'returns access levels for each user' do
+        expect(described_class.seat_assignable_highest_access_levels(users: [user1, user2])).to eq(
+          {
+            user1.id => Gitlab::Access::DEVELOPER,
+            user2.id => Gitlab::Access::MAINTAINER
+          }
+        )
+      end
+
+      context 'without namespace members' do
+        it 'returns nothing' do
+          expect(described_class.seat_assignable_highest_access_levels(users: user2, namespace: group2)).to eq({})
+        end
+      end
+    end
+
     describe '.with_case_insensitive_invite_emails' do
       let_it_be(:email) { 'bob@example.com' }
 
@@ -869,6 +1000,14 @@ RSpec.describe Member, feature_category: :groups_and_projects do
       end
     end
 
+    describe '.preload_users' do
+      let_it_be(:members) { described_class.preload_users.load }
+
+      it 'does not perform any additional queries' do
+        expect { members.map(&:user) }.not_to exceed_query_limit(0)
+      end
+    end
+
     describe '.active_state' do
       let_it_be(:active_group_member) { create(:group_member, group: group) }
       let_it_be(:active_project_member) { create(:project_member, project: project) }
@@ -901,6 +1040,15 @@ RSpec.describe Member, feature_category: :groups_and_projects do
         expect(group.members.excluding_users(active_group_member.user_id)).not_to include active_group_member
       end
     end
+
+    describe '.by_user_types' do
+      it 'returns users with matching types', :aggregate_failures do
+        service_account = create(:user, :service_account, developer_of: project)
+        bot = create(:user, :project_bot, developer_of: project)
+
+        expect(described_class.by_user_types([:service_account, :project_bot]).map(&:user)).to contain_exactly(service_account, bot)
+      end
+    end
   end
 
   describe 'Delegate methods' do
@@ -1272,7 +1420,7 @@ RSpec.describe Member, feature_category: :groups_and_projects do
 
       expect(member.invite_accepted_at).to be_nil
       expect(member.invite_token).not_to be_nil
-      expect_any_instance_of(described_class).not_to receive(:after_accept_invite)
+      expect(member).not_to receive(:after_accept_invite)
     end
 
     context 'when after accepting invite' do
@@ -1308,6 +1456,19 @@ RSpec.describe Member, feature_category: :groups_and_projects do
         end
       end
     end
+
+    context 'when after accept request' do
+      let_it_be(:group) { create(:group, require_two_factor_authentication: true) }
+      let_it_be(:member, reload: true) { create(:group_member, :awaiting, source: group) }
+
+      it 'calls updates the two factor requirement' do
+        expect(member.user).to receive(:require_two_factor_authentication_from_group).and_call_original
+
+        member.accept_request(group.first_owner)
+
+        expect(member.user.require_two_factor_authentication_from_group).to be_truthy
+      end
+    end
   end
 
   describe '#decline_invite!' do
@@ -1761,6 +1922,20 @@ RSpec.describe Member, feature_category: :groups_and_projects do
         it_behaves_like 'performs all the common hooks'
       end
     end
+
+    context 'when importing' do
+      let(:member) { create(:group_member, source: source, importing: true) }
+
+      it 'does not invoke a notification' do
+        allow(Notify).to receive(:member_access_granted_email).and_call_original
+
+        create_member
+
+        expect(Notify)
+          .not_to have_received(:member_access_granted_email)
+          .with(member.real_source_type, member.id)
+      end
+    end
   end
 
   context 'when after_create :update_two_factor_requirement' do
@@ -1783,6 +1958,22 @@ RSpec.describe Member, feature_category: :groups_and_projects do
     end
   end
 
+  context 'when after_commit :log_previous_state_on_update' do
+    let_it_be(:member) { create(:group_member) }
+
+    it 'logs a message on member update' do
+      expect(Gitlab::AppLogger)
+        .to receive(:info)
+        .with({
+          message: 'Refresh member authorized projects on update',
+          user_id: member.user.id,
+          previous_changes: %w[access_level updated_at]
+        })
+
+      member.update!(access_level: Gitlab::Access::GUEST)
+    end
+  end
+
   describe 'log_invitation_token_cleanup' do
     let_it_be(:project) { create :project }
 
