@@ -13,6 +13,10 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
     it { expect(personal_access_token.description).to be_nil }
   end
 
+  describe 'enums' do
+    it { is_expected.to define_enum_for(:user_type).with_values(HasUserType::USER_TYPES) }
+  end
+
   describe '.build' do
     let(:personal_access_token) { build(:personal_access_token) }
     let(:invalid_personal_access_token) { build(:personal_access_token, :invalid) }
@@ -34,6 +38,7 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
 
     it { is_expected.to belong_to(:previous_personal_access_token).class_name('PersonalAccessToken') }
     it { is_expected.to belong_to(:organization).class_name('Organizations::Organization') }
+    it { is_expected.to belong_to(:group).optional }
     it { is_expected.to have_many(:last_used_ips) }
   end
 
@@ -399,6 +404,12 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
 
           expect(personal_access_token).to be_valid
         end
+
+        it 'is valid with expiration date set beyond 400 days' do
+          personal_access_token.expires_at = 2.years.from_now
+
+          expect(personal_access_token).to be_valid
+        end
       end
     end
 
@@ -592,7 +603,7 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
       end
     end
 
-    describe '.expired_before' do
+    describe '.expired_after' do
       let_it_be(:cut_off) { 3.days.ago }
 
       let_it_be(:active_token) { create(:personal_access_token) }
@@ -601,8 +612,8 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
       let_it_be(:token_expired_at_cut_off) { create(:personal_access_token, expires_at: cut_off) }
       let_it_be(:token_expired_after_cut_off) { create(:personal_access_token, expires_at: cut_off + 1.day) }
 
-      it 'returns tokens that are expired before date passed in' do
-        expect(described_class.expired_before(cut_off)).to contain_exactly(token_expired_before_cut_off)
+      it 'returns tokens that are expired after date passed in' do
+        expect(described_class.expired_after(cut_off)).to contain_exactly(token_expired_at_cut_off, token_expired_after_cut_off)
       end
     end
 
@@ -616,7 +627,7 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
     end
 
     describe 'revoke scopes' do
-      let_it_be(:revoked_token) { create(:personal_access_token, :revoked) }
+      let_it_be(:revoked_token) { create(:personal_access_token, :revoked, updated_at: 4.days.ago) }
       let_it_be(:non_revoked_token) { create(:personal_access_token, revoked: false) }
       let_it_be(:non_revoked_token2) { create(:personal_access_token, revoked: nil) }
 
@@ -628,7 +639,7 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
         it { expect(described_class.not_revoked).to contain_exactly(non_revoked_token, non_revoked_token2) }
       end
 
-      describe '.revoked_before' do
+      describe '.revoked_after' do
         let_it_be(:cut_off) { 3.days.ago }
 
         let_it_be(:token_revoked_before_cut_off) { create(:personal_access_token, :revoked, updated_at: cut_off - 1.second) }
@@ -639,8 +650,8 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
         let_it_be(:non_revoked_token_updated_at_cut_off) { create(:personal_access_token, updated_at: cut_off) }
         let_it_be(:non_revoked_token_updated_after_cut_off) { create(:personal_access_token, updated_at: cut_off + 1.second) }
 
-        it 'returns tokens that are revoked before date passed in' do
-          expect(described_class.revoked_before(cut_off)).to contain_exactly(token_revoked_before_cut_off)
+        it 'returns tokens that are revoked after date passed in' do
+          expect(described_class.revoked_after(cut_off)).to contain_exactly(token_revoked_at_cut_off, token_revoked_after_cut_off)
         end
       end
     end
@@ -745,54 +756,23 @@ RSpec.describe PersonalAccessToken, feature_category: :system_access do
       stub_config(cell: { enabled: true, id: 1 })
     end
 
-    context 'when :routable_pat feature flag is disabled' do
-      before do
-        stub_feature_flags(routable_pat: false)
-      end
-
-      it_behaves_like 'a digested token' do
+    context 'when token_digest is not set yet' do
+      it_behaves_like 'a digested routable token' do
         let(:expected_token) { token }
-        let(:expected_token_payload) { devise_token }
+        let(:expected_routing_payload) { "c:1\no:#{organization.id.to_s(36)}\nu:#{user.id.to_s(36)}" }
+        let(:expected_random_bytes) { random_bytes }
         let(:expected_token_prefix) { described_class.token_prefix }
         let(:expected_token_digest) { token_owner_record.token_digest }
       end
     end
 
-    shared_examples 'a routable token' do
-      context 'when token_digest is not set yet' do
-        it_behaves_like 'a digested routable token' do
-          let(:expected_token) { token }
-          let(:expected_routing_payload) { "c:1\no:#{organization.id.to_s(36)}\nu:#{user.id.to_s(36)}" }
-          let(:expected_random_bytes) { random_bytes }
-          let(:expected_token_prefix) { described_class.token_prefix }
-          let(:expected_token_digest) { token_owner_record.token_digest }
-        end
+    context 'with token_digest already generated' do
+      let(:token_digest) { 's3cr3t' }
+
+      it 'does not change the token' do
+        expect(token).to be_nil
+        expect(token_owner_record.token_digest).to eq(token_digest)
       end
-
-      context 'with token_digest already generated' do
-        let(:token_digest) { 's3cr3t' }
-
-        it 'does not change the token' do
-          expect(token).to be_nil
-          expect(token_owner_record.token_digest).to eq(token_digest)
-        end
-      end
-    end
-
-    context 'when :routable_pat feature flag is enabled for the user' do
-      before do
-        stub_feature_flags(routable_pat: token_owner_record.user)
-      end
-
-      it_behaves_like 'a routable token'
-    end
-
-    context 'when :routable_pat feature flag is enabled globally' do
-      before do
-        stub_feature_flags(routable_pat: true)
-      end
-
-      it_behaves_like 'a routable token'
     end
   end
 end
