@@ -26,6 +26,13 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
   describe 'GET /projects/:id/pipelines ' do
     it_behaves_like 'pipelines visibility table'
 
+    it_behaves_like 'enforcing job token policies', :read_pipelines,
+      allow_public_access_for_enabled_project_features: [:repository, :builds] do
+      let(:request) do
+        get api("/projects/#{project.id}/pipelines"), params: { job_token: target_job.token }
+      end
+    end
+
     context 'authorized user' do
       it 'returns project pipelines', :aggregate_failures do
         get api("/projects/#{project.id}/pipelines", user)
@@ -370,183 +377,194 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
 
     let(:guest) { create(:project_member, :guest, project: project).user }
 
-    before do |example|
-      unless example.metadata[:skip_before_request]
-        project.update!(public_builds: false)
-        get api("/projects/#{project.id}/pipelines/#{pipeline.id}/jobs", api_user), params: query
-      end
-    end
-
-    context 'authorized user' do
-      it 'returns pipeline jobs', :aggregate_failures do
-        expect(response).to have_gitlab_http_status(:ok)
-        expect(response).to include_pagination_headers
-        expect(json_response).to be_an Array
-      end
-
-      context 'with oauth token that has ai_workflows scope' do
-        let(:token) { create(:oauth_access_token, user: user, scopes: [:ai_workflows]) }
-
-        it "allows access", :skip_before_request do
-          get api("/projects/#{project.id}/pipelines/#{pipeline.id}/jobs", oauth_access_token: token), params: query
+    context 'when public_builds is false' do
+      before do |example|
+        unless example.metadata[:skip_before_request]
           project.update!(public_builds: false)
-
-          expect(response).to have_gitlab_http_status(:ok)
-        end
-      end
-
-      it 'returns correct values', :aggregate_failures do
-        expect(json_response).not_to be_empty
-        expect(json_response.first['commit']['id']).to eq project.commit.id
-        expect(Time.parse(json_response.first['artifacts_expire_at'])).to be_like_time(job.artifacts_expire_at)
-        expect(json_response.first['artifacts_file']).to be_nil
-        expect(json_response.first['artifacts']).to be_an Array
-        expect(json_response.first['artifacts']).to be_empty
-      end
-
-      it_behaves_like 'a job with artifacts and trace' do
-        let(:api_endpoint) { "/projects/#{project.id}/pipelines/#{pipeline.id}/jobs" }
-      end
-
-      it 'returns pipeline data', :aggregate_failures do
-        json_job = json_response.first
-
-        expect(json_job['pipeline']).not_to be_empty
-        expect(json_job['pipeline']['id']).to eq job.pipeline.id
-        expect(json_job['pipeline']['project_id']).to eq job.pipeline.project_id
-        expect(json_job['pipeline']['ref']).to eq job.pipeline.ref
-        expect(json_job['pipeline']['sha']).to eq job.pipeline.sha
-        expect(json_job['pipeline']['status']).to eq job.pipeline.status
-      end
-
-      context 'filter jobs with one scope element' do
-        let(:query) { { 'scope' => 'pending' } }
-
-        it :aggregate_failures do
-          expect(response).to have_gitlab_http_status(:ok)
-          expect(json_response).to be_an Array
-
-          expect(json_response).to all match a_hash_including(
-            'duration' => be_nil,
-            'queued_duration' => (be >= 0.0)
-          )
-        end
-      end
-
-      context 'when filtering to only running jobs' do
-        let(:query) { { 'scope' => 'running' } }
-
-        it :aggregate_failures do
-          expect(response).to have_gitlab_http_status(:ok)
-          expect(json_response).to be_an Array
-
-          expect(json_response).to all match a_hash_including(
-            'duration' => (be >= 0.0),
-            'queued_duration' => (be >= 0.0)
-          )
-        end
-      end
-
-      context 'filter jobs with hash' do
-        let(:query) { { scope: { hello: 'pending', world: 'running' } } }
-
-        it { expect(response).to have_gitlab_http_status(:bad_request) }
-      end
-
-      context 'filter jobs with array of scope elements' do
-        let(:query) { { scope: %w[pending running] } }
-
-        it :aggregate_failures do
-          expect(response).to have_gitlab_http_status(:ok)
-          expect(json_response).to be_an Array
-        end
-      end
-
-      context 'respond 400 when scope contains invalid state' do
-        let(:query) { { scope: %w[unknown running] } }
-
-        it { expect(response).to have_gitlab_http_status(:bad_request) }
-      end
-
-      context 'jobs in different pipelines' do
-        let!(:pipeline2) { create(:ci_empty_pipeline, project: project) }
-        let!(:job2) { create(:ci_build, pipeline: pipeline2) }
-
-        it 'excludes jobs from other pipelines' do
-          json_response.each { |job| expect(job['pipeline']['id']).to eq(pipeline.id) }
-        end
-      end
-
-      it 'avoids N+1 queries' do
-        control = ActiveRecord::QueryRecorder.new(skip_cached: false) do
           get api("/projects/#{project.id}/pipelines/#{pipeline.id}/jobs", api_user), params: query
         end
-
-        create_list(:ci_build, 3, :trace_artifact, :artifacts, :test_reports, pipeline: pipeline)
-
-        expect do
-          get api("/projects/#{project.id}/pipelines/#{pipeline.id}/jobs", api_user), params: query
-        end.not_to exceed_all_query_limit(control)
       end
 
-      context 'pipeline has retried jobs' do
-        before_all do
-          job.update!(retried: true)
-        end
-
-        let_it_be(:successor) { create(:ci_build, :success, name: 'build', pipeline: pipeline) }
-
-        it 'does not return retried jobs by default', :aggregate_failures do
+      context 'authorized user' do
+        it 'returns pipeline jobs', :aggregate_failures do
+          expect(response).to have_gitlab_http_status(:ok)
+          expect(response).to include_pagination_headers
           expect(json_response).to be_an Array
-          expect(json_response.length).to eq(1)
         end
 
-        context 'when include_retried is false' do
-          let(:query) { { include_retried: false } }
+        context 'with oauth token that has ai_workflows scope' do
+          let(:token) { create(:oauth_access_token, user: user, scopes: [:ai_workflows]) }
 
-          it 'does not return retried jobs', :aggregate_failures do
+          it "allows access", :skip_before_request do
+            get api("/projects/#{project.id}/pipelines/#{pipeline.id}/jobs", oauth_access_token: token), params: query
+            project.update!(public_builds: false)
+
+            expect(response).to have_gitlab_http_status(:ok)
+          end
+        end
+
+        it 'returns correct values', :aggregate_failures do
+          expect(json_response).not_to be_empty
+          expect(json_response.first['commit']['id']).to eq project.commit.id
+          expect(Time.parse(json_response.first['artifacts_expire_at'])).to be_like_time(job.artifacts_expire_at)
+          expect(json_response.first['artifacts_file']).to be_nil
+          expect(json_response.first['artifacts']).to be_an Array
+          expect(json_response.first['artifacts']).to be_empty
+        end
+
+        it_behaves_like 'a job with artifacts and trace' do
+          let(:api_endpoint) { "/projects/#{project.id}/pipelines/#{pipeline.id}/jobs" }
+        end
+
+        it 'returns pipeline data', :aggregate_failures do
+          json_job = json_response.first
+
+          expect(json_job['pipeline']).not_to be_empty
+          expect(json_job['pipeline']['id']).to eq job.pipeline.id
+          expect(json_job['pipeline']['project_id']).to eq job.pipeline.project_id
+          expect(json_job['pipeline']['ref']).to eq job.pipeline.ref
+          expect(json_job['pipeline']['sha']).to eq job.pipeline.sha
+          expect(json_job['pipeline']['status']).to eq job.pipeline.status
+        end
+
+        context 'filter jobs with one scope element' do
+          let(:query) { { 'scope' => 'pending' } }
+
+          it :aggregate_failures do
+            expect(response).to have_gitlab_http_status(:ok)
+            expect(json_response).to be_an Array
+
+            expect(json_response).to all match a_hash_including(
+              'duration' => be_nil,
+              'queued_duration' => (be >= 0.0)
+            )
+          end
+        end
+
+        context 'when filtering to only running jobs' do
+          let(:query) { { 'scope' => 'running' } }
+
+          it :aggregate_failures do
+            expect(response).to have_gitlab_http_status(:ok)
+            expect(json_response).to be_an Array
+
+            expect(json_response).to all match a_hash_including(
+              'duration' => (be >= 0.0),
+              'queued_duration' => (be >= 0.0)
+            )
+          end
+        end
+
+        context 'filter jobs with hash' do
+          let(:query) { { scope: { hello: 'pending', world: 'running' } } }
+
+          it { expect(response).to have_gitlab_http_status(:bad_request) }
+        end
+
+        context 'filter jobs with array of scope elements' do
+          let(:query) { { scope: %w[pending running] } }
+
+          it :aggregate_failures do
+            expect(response).to have_gitlab_http_status(:ok)
+            expect(json_response).to be_an Array
+          end
+        end
+
+        context 'respond 400 when scope contains invalid state' do
+          let(:query) { { scope: %w[unknown running] } }
+
+          it { expect(response).to have_gitlab_http_status(:bad_request) }
+        end
+
+        context 'jobs in different pipelines' do
+          let!(:pipeline2) { create(:ci_empty_pipeline, project: project) }
+          let!(:job2) { create(:ci_build, pipeline: pipeline2) }
+
+          it 'excludes jobs from other pipelines' do
+            json_response.each { |job| expect(job['pipeline']['id']).to eq(pipeline.id) }
+          end
+        end
+
+        it 'avoids N+1 queries' do
+          control = ActiveRecord::QueryRecorder.new(skip_cached: false) do
+            get api("/projects/#{project.id}/pipelines/#{pipeline.id}/jobs", api_user), params: query
+          end
+
+          create_list(:ci_build, 3, :trace_artifact, :artifacts, :test_reports, pipeline: pipeline)
+
+          expect do
+            get api("/projects/#{project.id}/pipelines/#{pipeline.id}/jobs", api_user), params: query
+          end.not_to exceed_all_query_limit(control)
+        end
+
+        context 'pipeline has retried jobs' do
+          before_all do
+            job.update!(retried: true)
+          end
+
+          let_it_be(:successor) { create(:ci_build, :success, name: 'build', pipeline: pipeline) }
+
+          it 'does not return retried jobs by default', :aggregate_failures do
             expect(json_response).to be_an Array
             expect(json_response.length).to eq(1)
           end
-        end
 
-        context 'when include_retried is true' do
-          let(:query) { { include_retried: true } }
+          context 'when include_retried is false' do
+            let(:query) { { include_retried: false } }
 
-          it 'returns retried jobs', :aggregate_failures do
-            expect(json_response).to be_an Array
-            expect(json_response.length).to eq(2)
-            expect(json_response[0]['name']).to eq(json_response[1]['name'])
+            it 'does not return retried jobs', :aggregate_failures do
+              expect(json_response).to be_an Array
+              expect(json_response.length).to eq(1)
+            end
+          end
+
+          context 'when include_retried is true' do
+            let(:query) { { include_retried: true } }
+
+            it 'returns retried jobs', :aggregate_failures do
+              expect(json_response).to be_an Array
+              expect(json_response.length).to eq(2)
+              expect(json_response[0]['name']).to eq(json_response[1]['name'])
+            end
           end
         end
       end
-    end
-
-    context 'no pipeline is found' do
-      it 'does not return jobs', :aggregate_failures do
-        get api("/projects/#{project2.id}/pipelines/#{pipeline.id}/jobs", user)
-
-        expect(json_response['message']).to eq '404 Project Not Found'
-        expect(response).to have_gitlab_http_status(:not_found)
-      end
-    end
-
-    context 'unauthorized user' do
-      context 'when user is not logged in' do
-        let(:api_user) { nil }
 
+      context 'no pipeline is found' do
         it 'does not return jobs', :aggregate_failures do
+          get api("/projects/#{project2.id}/pipelines/#{pipeline.id}/jobs", user)
+
           expect(json_response['message']).to eq '404 Project Not Found'
           expect(response).to have_gitlab_http_status(:not_found)
         end
       end
 
-      context 'when user is guest' do
-        let(:guest) { create(:project_member, :guest, project: project).user }
-        let(:api_user) { guest }
+      context 'unauthorized user' do
+        context 'when user is not logged in' do
+          let(:api_user) { nil }
 
-        it 'does not return jobs' do
-          expect(response).to have_gitlab_http_status(:forbidden)
+          it 'does not return jobs', :aggregate_failures do
+            expect(json_response['message']).to eq '404 Project Not Found'
+            expect(response).to have_gitlab_http_status(:not_found)
+          end
+        end
+
+        context 'when user is guest' do
+          let(:guest) { create(:project_member, :guest, project: project).user }
+          let(:api_user) { guest }
+
+          it 'does not return jobs' do
+            expect(response).to have_gitlab_http_status(:forbidden)
+          end
+        end
+      end
+    end
+
+    context 'when public_builds is true' do
+      it_behaves_like 'enforcing job token policies', :read_jobs,
+        allow_public_access_for_enabled_project_features: [:repository, :builds] do
+        let(:request) do
+          get api("/projects/#{project.id}/pipelines/#{pipeline.id}/jobs"), params: { job_token: target_job.token }
         end
       end
     end
@@ -571,176 +589,187 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
     let(:query) { {} }
     let(:api_user) { user }
 
-    before do |example|
-      unless example.metadata[:skip_before_request]
-        project.update!(public_builds: false)
-        get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
-      end
-    end
-
-    context 'authorized user' do
-      it 'returns pipeline bridges', :aggregate_failures do
-        expect(response).to have_gitlab_http_status(:ok)
-        expect(response).to include_pagination_headers
-        expect(json_response).to be_an Array
+    context 'when public_builds is false' do
+      before do |example|
+        unless example.metadata[:skip_before_request]
+          project.update!(public_builds: false)
+          get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
+        end
       end
 
-      it 'returns correct values', :aggregate_failures do
-        expect(json_response).not_to be_empty
-        expect(json_response.first['commit']['id']).to eq project.commit.id
-        expect(json_response.first['id']).to eq bridge.id
-        expect(json_response.first['name']).to eq bridge.name
-        expect(json_response.first['stage']).to eq bridge.stage
-      end
-
-      it 'returns pipeline data', :aggregate_failures do
-        json_bridge = json_response.first
-
-        expect(json_bridge['pipeline']).not_to be_empty
-        expect(json_bridge['pipeline']['id']).to eq bridge.pipeline.id
-        expect(json_bridge['pipeline']['project_id']).to eq bridge.pipeline.project_id
-        expect(json_bridge['pipeline']['ref']).to eq bridge.pipeline.ref
-        expect(json_bridge['pipeline']['sha']).to eq bridge.pipeline.sha
-        expect(json_bridge['pipeline']['status']).to eq bridge.pipeline.status
-      end
-
-      it 'returns downstream pipeline data', :aggregate_failures do
-        json_bridge = json_response.first
-
-        expect(json_bridge['downstream_pipeline']).not_to be_empty
-        expect(json_bridge['downstream_pipeline']['id']).to eq downstream_pipeline.id
-        expect(json_bridge['downstream_pipeline']['project_id']).to eq downstream_pipeline.project_id
-        expect(json_bridge['downstream_pipeline']['ref']).to eq downstream_pipeline.ref
-        expect(json_bridge['downstream_pipeline']['sha']).to eq downstream_pipeline.sha
-        expect(json_bridge['downstream_pipeline']['status']).to eq downstream_pipeline.status
-      end
-
-      context 'filter bridges' do
-        before_all do
-          create_bridge(pipeline, :pending)
-          create_bridge(pipeline, :running)
+      context 'authorized user' do
+        it 'returns pipeline bridges', :aggregate_failures do
+          expect(response).to have_gitlab_http_status(:ok)
+          expect(response).to include_pagination_headers
+          expect(json_response).to be_an Array
         end
 
-        context 'with one scope element' do
-          let(:query) { { 'scope' => 'pending' } }
+        it 'returns correct values', :aggregate_failures do
+          expect(json_response).not_to be_empty
+          expect(json_response.first['commit']['id']).to eq project.commit.id
+          expect(json_response.first['id']).to eq bridge.id
+          expect(json_response.first['name']).to eq bridge.name
+          expect(json_response.first['stage']).to eq bridge.stage
+        end
 
-          it :skip_before_request, :aggregate_failures do
-            get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
+        it 'returns pipeline data', :aggregate_failures do
+          json_bridge = json_response.first
 
-            expect(response).to have_gitlab_http_status(:ok)
-            expect(json_response).to be_an Array
-            expect(json_response.count).to eq 1
-            expect(json_response.first["status"]).to eq "pending"
+          expect(json_bridge['pipeline']).not_to be_empty
+          expect(json_bridge['pipeline']['id']).to eq bridge.pipeline.id
+          expect(json_bridge['pipeline']['project_id']).to eq bridge.pipeline.project_id
+          expect(json_bridge['pipeline']['ref']).to eq bridge.pipeline.ref
+          expect(json_bridge['pipeline']['sha']).to eq bridge.pipeline.sha
+          expect(json_bridge['pipeline']['status']).to eq bridge.pipeline.status
+        end
+
+        it 'returns downstream pipeline data', :aggregate_failures do
+          json_bridge = json_response.first
+
+          expect(json_bridge['downstream_pipeline']).not_to be_empty
+          expect(json_bridge['downstream_pipeline']['id']).to eq downstream_pipeline.id
+          expect(json_bridge['downstream_pipeline']['project_id']).to eq downstream_pipeline.project_id
+          expect(json_bridge['downstream_pipeline']['ref']).to eq downstream_pipeline.ref
+          expect(json_bridge['downstream_pipeline']['sha']).to eq downstream_pipeline.sha
+          expect(json_bridge['downstream_pipeline']['status']).to eq downstream_pipeline.status
+        end
+
+        context 'filter bridges' do
+          before_all do
+            create_bridge(pipeline, :pending)
+            create_bridge(pipeline, :running)
+          end
+
+          context 'with one scope element' do
+            let(:query) { { 'scope' => 'pending' } }
+
+            it :skip_before_request, :aggregate_failures do
+              get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
+
+              expect(response).to have_gitlab_http_status(:ok)
+              expect(json_response).to be_an Array
+              expect(json_response.count).to eq 1
+              expect(json_response.first["status"]).to eq "pending"
+            end
+          end
+
+          context 'with array of scope elements' do
+            let(:query) { { scope: %w[pending running] } }
+
+            it :skip_before_request, :aggregate_failures do
+              get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
+
+              expect(response).to have_gitlab_http_status(:ok)
+              expect(json_response).to be_an Array
+              expect(json_response.count).to eq 2
+              json_response.each { |r| expect(%w[pending running].include?(r['status'])).to be true }
+            end
           end
         end
 
-        context 'with array of scope elements' do
-          let(:query) { { scope: %w[pending running] } }
+        context 'respond 400 when scope contains invalid state' do
+          context 'in an array' do
+            let(:query) { { scope: %w[unknown running] } }
 
-          it :skip_before_request, :aggregate_failures do
-            get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
+            it { expect(response).to have_gitlab_http_status(:bad_request) }
+          end
 
-            expect(response).to have_gitlab_http_status(:ok)
-            expect(json_response).to be_an Array
-            expect(json_response.count).to eq 2
-            json_response.each { |r| expect(%w[pending running].include?(r['status'])).to be true }
+          context 'in a hash' do
+            let(:query) { { scope: { unknown: true } } }
+
+            it { expect(response).to have_gitlab_http_status(:bad_request) }
+          end
+
+          context 'in a string' do
+            let(:query) { { scope: "unknown" } }
+
+            it { expect(response).to have_gitlab_http_status(:bad_request) }
           end
         end
-      end
 
-      context 'respond 400 when scope contains invalid state' do
-        context 'in an array' do
-          let(:query) { { scope: %w[unknown running] } }
+        context 'bridges in different pipelines' do
+          let!(:pipeline2) { create(:ci_empty_pipeline, project: project) }
+          let!(:bridge2) { create(:ci_bridge, pipeline: pipeline2) }
 
-          it { expect(response).to have_gitlab_http_status(:bad_request) }
+          it 'excludes bridges from other pipelines' do
+            json_response.each { |bridge| expect(bridge['pipeline']['id']).to eq(pipeline.id) }
+          end
         end
 
-        context 'in a hash' do
-          let(:query) { { scope: { unknown: true } } }
+        it 'avoids N+1 queries', :use_sql_query_cache, :request_store do
+          control = ActiveRecord::QueryRecorder.new(skip_cached: false) do
+            get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
+          end
 
-          it { expect(response).to have_gitlab_http_status(:bad_request) }
-        end
+          3.times { create_bridge(pipeline) }
 
-        context 'in a string' do
-          let(:query) { { scope: "unknown" } }
-
-          it { expect(response).to have_gitlab_http_status(:bad_request) }
+          expect do
+            get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
+          end.to issue_same_number_of_queries_as(control)
         end
       end
 
-      context 'bridges in different pipelines' do
-        let!(:pipeline2) { create(:ci_empty_pipeline, project: project) }
-        let!(:bridge2) { create(:ci_bridge, pipeline: pipeline2) }
-
-        it 'excludes bridges from other pipelines' do
-          json_response.each { |bridge| expect(bridge['pipeline']['id']).to eq(pipeline.id) }
-        end
-      end
-
-      it 'avoids N+1 queries', :use_sql_query_cache, :request_store do
-        control = ActiveRecord::QueryRecorder.new(skip_cached: false) do
-          get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
-        end
-
-        3.times { create_bridge(pipeline) }
-
-        expect do
-          get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user), params: query
-        end.to issue_same_number_of_queries_as(control)
-      end
-    end
-
-    context 'no pipeline is found' do
-      it 'does not return bridges', :aggregate_failures do
-        get api("/projects/#{project2.id}/pipelines/#{pipeline.id}/bridges", user)
-
-        expect(json_response['message']).to eq '404 Project Not Found'
-        expect(response).to have_gitlab_http_status(:not_found)
-      end
-    end
-
-    context 'unauthorized user' do
-      context 'when user is not logged in' do
-        let(:api_user) { nil }
-
+      context 'no pipeline is found' do
         it 'does not return bridges', :aggregate_failures do
+          get api("/projects/#{project2.id}/pipelines/#{pipeline.id}/bridges", user)
+
           expect(json_response['message']).to eq '404 Project Not Found'
           expect(response).to have_gitlab_http_status(:not_found)
         end
       end
 
-      context 'when user is guest' do
-        let(:api_user) { guest }
-        let(:guest) { create(:project_member, :guest, project: project).user }
+      context 'unauthorized user' do
+        context 'when user is not logged in' do
+          let(:api_user) { nil }
 
-        it 'does not return bridges' do
-          expect(response).to have_gitlab_http_status(:forbidden)
+          it 'does not return bridges', :aggregate_failures do
+            expect(json_response['message']).to eq '404 Project Not Found'
+            expect(response).to have_gitlab_http_status(:not_found)
+          end
+        end
+
+        context 'when user is guest' do
+          let(:api_user) { guest }
+          let(:guest) { create(:project_member, :guest, project: project).user }
+
+          it 'does not return bridges' do
+            expect(response).to have_gitlab_http_status(:forbidden)
+          end
+        end
+
+        context 'when user has no read_build access for project' do
+          before do
+            project.add_guest(api_user)
+          end
+
+          it 'does not return bridges' do
+            get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user)
+            expect(response).to have_gitlab_http_status(:forbidden)
+          end
         end
       end
 
-      context 'when user has no read_build access for project' do
-        before do
-          project.add_guest(api_user)
-        end
-
-        it 'does not return bridges' do
-          get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges", api_user)
-          expect(response).to have_gitlab_http_status(:forbidden)
+      def create_bridge(pipeline, status = :created)
+        create(:ci_bridge, status: status, pipeline: pipeline, user: pipeline.user).tap do |bridge|
+          downstream_pipeline = create(:ci_pipeline)
+          create(
+            :ci_sources_pipeline,
+            source_pipeline: pipeline,
+            source_project: pipeline.project,
+            source_job: bridge,
+            pipeline: downstream_pipeline,
+            project: downstream_pipeline.project
+          )
         end
       end
     end
 
-    def create_bridge(pipeline, status = :created)
-      create(:ci_bridge, status: status, pipeline: pipeline, user: pipeline.user).tap do |bridge|
-        downstream_pipeline = create(:ci_pipeline)
-        create(
-          :ci_sources_pipeline,
-          source_pipeline: pipeline,
-          source_project: pipeline.project,
-          source_job: bridge,
-          pipeline: downstream_pipeline,
-          project: downstream_pipeline.project
-        )
+    context 'when public_builds is true' do
+      it_behaves_like 'enforcing job token policies', :read_pipelines,
+        allow_public_access_for_enabled_project_features: [:repository, :builds] do
+        let(:request) do
+          get api("/projects/#{project.id}/pipelines/#{pipeline.id}/bridges"), params: { job_token: target_job.token }
+        end
       end
     end
   end
@@ -889,10 +918,14 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
             { 'Content-Type' => 'application/x-www-form-urlencoded' }
           end
 
+          let(:transformed_values) do
+            inputs.transform_values { |value| value.is_a?(String) ? value : value.to_json }
+          end
+
           subject(:post_request) do
             post api("/projects/#{project.id}/pipeline", user),
               headers: headers,
-              params: { ref: project.default_branch, inputs: inputs.transform_values(&:to_json) }
+              params: { ref: project.default_branch, inputs: transformed_values }
           end
 
           it_behaves_like 'creating a succesful pipeline'
@@ -937,6 +970,13 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
       let(:response_200) { match_response_schema('public_api/v4/pipeline/detail') }
     end
 
+    it_behaves_like 'enforcing job token policies', :read_pipelines,
+      allow_public_access_for_enabled_project_features: [:repository, :builds] do
+      let(:request) do
+        get api("/projects/#{project.id}/pipelines/#{pipeline.id}"), params: { job_token: target_job.token }
+      end
+    end
+
     context 'authorized user' do
       it 'exposes known attributes', :aggregate_failures do
         get api("/projects/#{project.id}/pipelines/#{pipeline.id}", user)
@@ -1091,11 +1131,11 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
 
           expect(response).to have_gitlab_http_status(:ok)
           expect(json_response).to contain_exactly({
-                                                     "variable_type" => "env_var",
-                                                     "key" => "foo",
-                                                     "value" => "bar",
-                                                     "raw" => false
-                                                   })
+            "variable_type" => "env_var",
+            "key" => "foo",
+            "value" => "bar",
+            "raw" => false
+          })
         end
       end
     end
@@ -1117,11 +1157,11 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
 
           expect(response).to have_gitlab_http_status(:ok)
           expect(json_response).to contain_exactly({
-                                                     "variable_type" => "env_var",
-                                                     "key" => "foo",
-                                                     "value" => "bar",
-                                                     "raw" => false
-                                                   })
+            "variable_type" => "env_var",
+            "key" => "foo",
+            "value" => "bar",
+            "raw" => false
+          })
         end
       end
 
@@ -1228,7 +1268,7 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
       put api("/projects/#{project.id}/pipelines/#{pipeline.id}/metadata", current_user), params: { name: name }
     end
 
-    it_behaves_like 'enforcing job token policies', :admin_jobs do
+    it_behaves_like 'enforcing job token policies', :admin_pipelines do
       let(:request) do
         put api("/projects/#{source_project.id}/pipelines/#{pipeline.id}/metadata"),
           params: { name: name, job_token: target_job.token }
@@ -1361,14 +1401,14 @@ RSpec.describe API::Ci::Pipelines, feature_category: :continuous_integration do
           expect(response).to have_gitlab_http_status(:ok)
           expect(json_response['status']).to eq('canceling')
         end
+      end
 
-        context 'when cancel_gracefully is not supported by the runner' do
-          it 'cancels builds', :sidekiq_inline do
-            post api("/projects/#{project.id}/pipelines/#{pipeline.id}/cancel", user)
+      context 'when cancel_gracefully is not supported by the runner' do
+        it 'cancels builds', :sidekiq_inline do
+          post api("/projects/#{project.id}/pipelines/#{pipeline.id}/cancel", user)
 
-            expect(response).to have_gitlab_http_status(:ok)
-            expect(json_response['status']).to eq('canceled')
-          end
+          expect(response).to have_gitlab_http_status(:ok)
+          expect(json_response['status']).to eq('canceled')
         end
       end
     end
