@@ -8,7 +8,7 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
   include WorkhorseHelpers
 
   before do
-    stub_feature_flags(ci_enable_live_trace: true)
+    stub_application_setting(ci_job_live_trace_enabled: true)
     stub_gitlab_calls
     allow_any_instance_of(::Ci::Runner).to receive(:cache_attributes)
     allow(Ci::Build).to receive(:find_by!).and_call_original
@@ -20,9 +20,11 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
     let_it_be(:user) { create(:user) }
 
     let(:project) do
-      create(:project, :empty_repo, namespace: group, shared_runners_enabled: false).tap(&:track_project_repository)
+      create(:project, *project_traits, namespace: group, shared_runners_enabled: false).tap(&:track_project_repository)
     end
 
+    let(:project_traits) { :empty_repo }
+
     let(:runner) { create(:ci_runner, :project, projects: [project]) }
     let(:pipeline) { create(:ci_pipeline, project: project, ref: 'master') }
     let(:job) do
@@ -209,18 +211,19 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
               'refspecs' => ["+refs/pipelines/#{pipeline.id}:refs/pipelines/#{pipeline.id}",
                              "+refs/heads/#{job.ref}:refs/remotes/origin/#{job.ref}"],
               'depth' => project.ci_default_git_depth,
-              'repo_object_format' => 'sha1' }
+              'repo_object_format' => 'sha1',
+              'protected' => job.protected }
           end
 
           let(:expected_steps) do
             [{ 'name' => 'script',
                'script' => %w[echo],
-               'timeout' => job.metadata_timeout,
+               'timeout' => job.timeout_value,
                'when' => 'on_success',
                'allow_failure' => false },
              { 'name' => 'after_script',
                'script' => %w[ls date],
-               'timeout' => job.metadata_timeout,
+               'timeout' => job.timeout_value,
                'when' => 'always',
                'allow_failure' => true }]
           end
@@ -350,6 +353,8 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
               end
 
               it 'fails the job as a scheduler failure' do
+                allow(Gitlab::ErrorTracking).to receive(:track_and_raise_for_dev_exception)
+
                 request_job
 
                 expect(response).to have_gitlab_http_status(:no_content)
@@ -429,7 +434,7 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
 
                 expect(response).to have_gitlab_http_status(:created)
                 expect(response.headers).not_to have_key('X-GitLab-Last-Update')
-                expect(json_response['steps']).to eq(
+                expect(json_response['steps']).to match_array(
                   [
                     {
                       "name" => "script",
@@ -440,14 +445,43 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
                     },
                     {
                       "name" => "release",
-                      "script" =>
-                      ["release-cli create --name \"Release $CI_COMMIT_SHA\" --description \"Created using the release-cli $EXTRA_DESCRIPTION\" --tag-name \"release-$CI_COMMIT_SHA\" --ref \"$CI_COMMIT_SHA\" --assets-link \"{\\\"name\\\":\\\"asset1\\\",\\\"url\\\":\\\"https://example.com/assets/1\\\"}\""],
+                      "script" => [a_string_including("glab release create -R $CI_PROJECT_PATH")],
                       "timeout" => 3600,
                       "when" => "on_success",
                       "allow_failure" => false
                     }
                   ])
               end
+
+              context 'when the FF ci_glab_for_release is disabled' do
+                before do
+                  stub_feature_flags(ci_glab_for_release: false)
+                end
+
+                it 'exposes release info' do
+                  request_job info: { features: { multi_build_steps: true } }
+
+                  expect(response).to have_gitlab_http_status(:created)
+                  expect(response.headers).not_to have_key('X-GitLab-Last-Update')
+                  expect(json_response['steps']).to match_array(
+                    [
+                      {
+                        "name" => "script",
+                        "script" => ["make changelog | tee release_changelog.txt"],
+                        "timeout" => 3600,
+                        "when" => "on_success",
+                        "allow_failure" => false
+                      },
+                      {
+                        "name" => "release",
+                        "script" => [a_string_including("release-cli create --name ")],
+                        "timeout" => 3600,
+                        "when" => "on_success",
+                        "allow_failure" => false
+                      }
+                    ])
+                end
+              end
             end
 
             context 'when `multi_build_steps` is not passed by the runner' do
@@ -460,6 +494,7 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
           end
 
           context 'when job is made for merge request' do
+            let(:project_traits) { :repository }
             let(:pipeline) { create(:ci_pipeline, source: :merge_request_event, project: project, ref: 'feature', merge_request: merge_request) }
             let!(:job) { create(:ci_build, :pending, :queued, pipeline: pipeline, name: 'spinach', ref: 'feature', stage: 'test', stage_idx: 0) }
 
@@ -486,6 +521,33 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
             end
           end
 
+          context 'when job is on a protected branch' do
+            before do
+              create(:protected_branch, project: project, name: job.ref)
+              job.update!(protected: true)
+            end
+
+            it 'includes protected status in git_info' do
+              request_job
+
+              expect(response).to have_gitlab_http_status(:created)
+              expect(json_response['git_info']['protected']).to be true
+            end
+          end
+
+          context 'when job is not on a protected branch' do
+            before do
+              job.update!(protected: false)
+            end
+
+            it 'includes protected status in git_info' do
+              request_job
+
+              expect(response).to have_gitlab_http_status(:created)
+              expect(json_response['git_info']['protected']).to be false
+            end
+          end
+
           context 'with run keyword' do
             let(:execution_config) { create(:ci_builds_execution_configs, :with_step_and_script) }
 
@@ -630,6 +692,8 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
             end
 
             describe 'preloading job_artifacts_archive' do
+              let(:project_traits) { :repository }
+
               it 'queries the ci_job_artifacts table once only' do
                 expect { request_job }.not_to exceed_all_query_limit(1).for_model(::Ci::JobArtifact)
               end
@@ -793,7 +857,6 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
 
             let(:trigger) { create(:ci_trigger, project: project) }
             let(:pipeline) { create(:ci_pipeline, trigger: trigger, project: project, ref: 'master') }
-            let!(:trigger_request) { create(:ci_trigger_request, pipeline: pipeline, builds: [job], trigger: trigger) }
 
             before do
               project.variables << ::Ci::Variable.new(key: 'SECRET_KEY', value: 'secret_value')
@@ -1042,6 +1105,76 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
           end
         end
 
+        context 'when image has kubernetes options' do
+          let(:job) { create(:ci_build, :pending, :queued, pipeline: pipeline, options: options) }
+
+          let(:options) do
+            {
+              image: {
+                name: 'ruby',
+                executor_opts: {
+                  kubernetes: {
+                    user: '1001'
+                  }
+                }
+              }
+            }
+          end
+
+          it 'returns the image with kubernetes options' do
+            request_job
+
+            expect(response).to have_gitlab_http_status(:created)
+            expect(json_response).to include(
+              'id' => job.id,
+              'image' => { 'name' => 'ruby',
+                           'executor_opts' => {
+                             'kubernetes' => {
+                               'user' => '1001'
+                             }
+                           },
+                           'pull_policy' => nil,
+                           'entrypoint' => nil,
+                           'ports' => [] }
+            )
+          end
+        end
+
+        context 'when image has kubernetes options with user an int' do
+          let(:job) { create(:ci_build, :pending, :queued, pipeline: pipeline, options: options) }
+
+          let(:options) do
+            {
+              image: {
+                name: 'ruby',
+                executor_opts: {
+                  kubernetes: {
+                    user: 1001
+                  }
+                }
+              }
+            }
+          end
+
+          it 'returns the image with kubernetes options' do
+            request_job
+
+            expect(response).to have_gitlab_http_status(:created)
+            expect(json_response).to include(
+              'id' => job.id,
+              'image' => { 'name' => 'ruby',
+                           'executor_opts' => {
+                             'kubernetes' => {
+                               'user' => 1001
+                             }
+                           },
+                           'pull_policy' => nil,
+                           'entrypoint' => nil,
+                           'ports' => [] }
+            )
+          end
+        end
+
         context 'when image has pull_policy' do
           let(:job) { create(:ci_build, :pending, :queued, pipeline: pipeline, options: options) }
 
@@ -1168,7 +1301,7 @@ RSpec.describe API::Ci::Runner, :clean_gitlab_redis_shared_state, feature_catego
               let(:expected_params) { { root_namespace: group.full_path_components.first, client_id: "runner/#{runner.id}" } }
             end
 
-            it_behaves_like 'not executing any extra queries for the application context', 2 do
+            it_behaves_like 'not executing any extra queries for the application context', 3 do
               # Extra queries: Group, Route
               let(:subject_proc) { proc { request_job } }
             end
