@@ -19,7 +19,9 @@ RSpec.describe API::Integrations, feature_category: :integrations do
 
     let_it_be(:project_integrations_map) do
       available_integration_names.index_with do |name|
-        create(integration_factory(name), :inactive, project: project)
+        # Activate Confluence so it appears in API response
+        traits = (name == 'confluence' ? [] : [:inactive])
+        create(integration_factory(name), *traits, project: project)
       end
     end
 
@@ -44,8 +46,8 @@ RSpec.describe API::Integrations, feature_category: :integrations do
           aggregate_failures 'expect successful response with all active integrations' do
             expect(response).to have_gitlab_http_status(:ok)
             expect(json_response).to be_an Array
-            expect(json_response.count).to eq(1)
-            expect(json_response.first['slug']).to eq('prometheus')
+            expect(json_response.count).to eq(2)
+            expect(json_response.first['slug']).to eq('confluence')
             expect(response).to match_response_schema('public_api/v4/integrations')
           end
         end
@@ -455,7 +457,8 @@ RSpec.describe API::Integrations, feature_category: :integrations do
 
     let_it_be(:group_integrations_map) do
       available_integration_names.index_with do |name|
-        create(integration_factory(name), :inactive, :group, group: group)
+        traits = (name == 'confluence' ? [] : [:inactive])
+        create(integration_factory(name), *traits, :group, group: group)
       end
     end
 
@@ -482,8 +485,8 @@ RSpec.describe API::Integrations, feature_category: :integrations do
           aggregate_failures 'expect successful response with all active integrations' do
             expect(response).to have_gitlab_http_status(:ok)
             expect(json_response).to be_an Array
-            expect(json_response.count).to eq(1)
-            expect(json_response.first['slug']).to eq('prometheus')
+            expect(json_response.count).to eq(2)
+            expect(json_response.first['slug']).to eq('confluence')
             expect(response).to match_response_schema('public_api/v4/integrations')
           end
         end
@@ -502,8 +505,8 @@ RSpec.describe API::Integrations, feature_category: :integrations do
         # You cannot create a GitLab for Slack app. You must install the app from the GitLab UI.
         unavailable_integration_names = [
           Integrations::GitlabSlackApplication.to_param,
-          Integrations::Zentao.to_param,
-          Integrations::Prometheus.to_param
+          Integrations::Prometheus.to_param,
+          Integrations::Zentao.to_param
         ]
 
         names = Integration.available_integration_names(include_instance_specific: false, include_project_specific: false)
