@@ -342,7 +342,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
             get_token
 
             expect(response).to have_gitlab_http_status(:not_found)
-            expect(response.body).to include("Could not find #{source_type} access token with token_id: #{token_id}")
+            expect(json_response["message"]).to eq("404 #{source_type} Access Token Not Found")
           end
         end
 
@@ -353,7 +353,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
             get_token
 
             expect(response).to have_gitlab_http_status(:not_found)
-            expect(response.body).to include("Could not find #{source_type} access token with token_id: #{token_id}")
+            expect(json_response["message"]).to eq("404 #{source_type} Access Token Not Found")
           end
         end
       end
@@ -416,7 +416,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
             delete_token
 
             expect(response).to have_gitlab_http_status(:not_found)
-            expect(response.body).to include("Could not find #{source_type} access token with token_id: #{token_id}")
+            expect(json_response["message"]).to eq("404 #{source_type} Access Token Not Found")
           end
         end
 
@@ -427,7 +427,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
             delete_token
 
             expect(response).to have_gitlab_http_status(:not_found)
-            expect(response.body).to include("Could not find #{source_type} access token with token_id: #{token_id}")
+            expect(json_response["message"]).to eq("404 #{source_type} Access Token Not Found")
           end
         end
       end
@@ -478,15 +478,17 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
             let(:expires_at) { nil }
 
             it "creates a #{source_type} access token with the default expires_at value", :aggregate_failures do
-              freeze_time do
-                create_token
-                expires_at = PersonalAccessToken::MAX_PERSONAL_ACCESS_TOKEN_LIFETIME_IN_DAYS.days.from_now
+              create_token
+              # When the test run just before 00:00Z sometimes this expires_at is one day later.
+              # We have tried both freeze_time and time_travel_to, but it doesn't work. It seems `create_token`
+              # operates in a different context.
+              expires_at = PersonalAccessToken::MAX_PERSONAL_ACCESS_TOKEN_LIFETIME_IN_DAYS.days.from_now.to_date
 
-                expect(response).to have_gitlab_http_status(:created)
-                expect(json_response["name"]).to eq("test")
-                expect(json_response["scopes"]).to eq(["api"])
-                expect(json_response["expires_at"]).to eq(expires_at.to_date.iso8601)
-              end
+              expect(response).to have_gitlab_http_status(:created)
+              expect(json_response["name"]).to eq("test")
+              expect(json_response["scopes"]).to eq(["api"])
+              # Because of the above issue, we decided to compare with `<=` operator instead of `eq`
+              expect(json_response["expires_at"].to_date).to be <= expires_at
             end
           end
 
@@ -635,7 +637,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
 
           expect(response).to have_gitlab_http_status(:ok)
           expect(json_response['token']).not_to eq(token.token)
-          expect(json_response['expires_at']).to eq((Date.today + 1.week).to_s)
+          expect(json_response['expires_at']).to eq(1.week.from_now.to_date.iso8601)
         end
       end
 
@@ -674,7 +676,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
             if source_type == 'project'
               expect(response).to have_gitlab_http_status(:ok)
               expect(json_response['token']).not_to eq(token.token)
-              expect(json_response['expires_at']).to eq((Date.today + 1.week).to_s)
+              expect(json_response['expires_at']).to eq(1.week.from_now.to_date.iso8601)
             else
               expect(response).to have_gitlab_http_status(:unauthorized)
             end
@@ -683,7 +685,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
       end
 
       context 'when expiry is defined' do
-        let(:expiry_date) { Date.today + 1.month }
+        let(:expiry_date) { 1.month.from_now }
         let(:params) { { expires_at: expiry_date } }
 
         before do
@@ -696,7 +698,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
 
           expect(response).to have_gitlab_http_status(:ok)
           expect(json_response['token']).not_to eq(token.token)
-          expect(json_response['expires_at']).to eq(expiry_date.to_s)
+          expect(json_response['expires_at']).to eq(expiry_date.to_date.iso8601)
         end
       end
 
@@ -764,7 +766,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
         end
 
         context 'for admin user', :enable_admin_mode do
-          it 'returns not found', quarantine: 'https://gitlab.com/gitlab-org/gitlab/-/issues/448693' do
+          it 'returns not found' do
             admin = create(:admin)
             post api(invalid_path, admin)
 
