@@ -51,11 +51,13 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
       --------------------------------------------------
       # RSPEC
 
-      it_behaves_like 'internal event tracking' do
-        let(:event) { 'internal_events_cli_used' }
-        let(:category) { described_class.name }
-        let(:project) { create(:project) }
-        let(:user) { create(:user) }
+      it "triggers an internal event" do
+        expect { subject }.to trigger_internal_events('internal_events_cli_used').with(
+          project: project,
+          user: user
+        ).and increment_usage_metrics(
+          'redis_hll_counters.count_distinct_user_id_from_internal_events_cli_used_weekly'
+        )
       end
 
       --------------------------------------------------
@@ -98,37 +100,74 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
       TEXT
     end
 
-    before do
-      File.write(event1_filepath, File.read(event1_content))
-      File.write(
-        'config/metrics/counts_7d/count_distinct_user_id_from_internal_events_cli_used_weekly.yml',
-        File.read('spec/fixtures/scripts/internal_events/metrics/user_id_7d_single_event.yml')
-      )
+    context 'for single metric in string time_frame format' do
+      before do
+        File.write(event1_filepath, File.read(event1_content))
+        File.write(
+          'config/metrics/counts_7d/count_distinct_user_id_from_internal_events_cli_used_weekly.yml',
+          File.read('spec/fixtures/scripts/internal_events/metrics/user_id_7d_single_event.yml')
+        )
+      end
+
+      it 'shows backend examples' do
+        queue_cli_inputs([
+          "3\n", # Enum-select: View Usage -- look at code examples for an existing event
+          'internal_events_cli_used', # Filters to this event
+          "\n", # Select: config/events/internal_events_cli_used.yml
+          "\n", # Select: ruby/rails
+          "\e[B", # Arrow down to: rspec
+          "\n", # Select: rspec
+          "7\n", # Select: Manual testing: check current values of metrics from rails console (any data source)
+          "8\n", # Select: Data verification in Tableau
+          "Exit", # Filters to this item
+          "\n" # select: Exit
+        ])
+
+        with_cli_thread do
+          expect { plain_last_lines(200) }.to eventually_include_cli_text(
+            expected_example_prompt,
+            expected_rails_example,
+            expected_rspec_example,
+            expected_gdk_example,
+            expected_tableau_example
+          )
+        end
+      end
     end
 
-    it 'shows backend examples' do
-      queue_cli_inputs([
-        "3\n", # Enum-select: View Usage -- look at code examples for an existing event
-        'internal_events_cli_used', # Filters to this event
-        "\n", # Select: config/events/internal_events_cli_used.yml
-        "\n", # Select: ruby/rails
-        "\e[B", # Arrow down to: rspec
-        "\n", # Select: rspec
-        "7\n", # Select: Manual testing: check current values of metrics from rails console (any data source)
-        "8\n", # Select: Data verification in Tableau
-        "Exit", # Filters to this item
-        "\n" # select: Exit
-      ])
-
-      with_cli_thread do
-        expect { plain_last_lines(200) }.to eventually_include_cli_text(
-          expected_example_prompt,
-          expected_rails_example,
-          expected_rspec_example,
-          expected_gdk_example,
-          expected_tableau_example
+    context 'for single metric in array time_frame format' do
+      before do
+        File.write(event1_filepath, File.read(event1_content))
+        File.write(
+          'config/metrics/counts_all/count_distinct_user_id_from_internal_events_cli_used.yml',
+          File.read('spec/fixtures/scripts/internal_events/metrics/ee_total_7d_single_event_array_metric.yml')
         )
       end
+
+      it 'shows backend examples' do
+        queue_cli_inputs([
+          "3\n", # Enum-select: View Usage -- look at code examples for an existing event
+          'internal_events_cli_used', # Filters to this event
+          "\n", # Select: config/events/internal_events_cli_used.yml
+          "\n", # Select: ruby/rails
+          "\e[B", # Arrow down to: rspec
+          "\n", # Select: rspec
+          "7\n", # Select: Manual testing: check current values of metrics from rails console (any data source)
+          "8\n", # Select: Data verification in Tableau
+          "Exit", # Filters to this item
+          "\n" # select: Exit
+        ])
+
+        with_cli_thread do
+          expect { plain_last_lines(200) }.to eventually_include_cli_text(
+            expected_example_prompt,
+            expected_rails_example,
+            expected_rspec_example,
+            expected_gdk_example,
+            expected_tableau_example
+          )
+        end
+      end
     end
   end
 
@@ -155,11 +194,14 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
       --------------------------------------------------
       # RSPEC
 
-      it_behaves_like 'internal event tracking' do
-        let(:event) { 'internal_events_cli_used' }
-        let(:category) { described_class.name }
-        let(:project) { create(:project) }
-        let(:user) { create(:user) }
+      it "triggers an internal event" do
+        expect { subject }.to trigger_internal_events('internal_events_cli_used').with(
+          project: project,
+          user: user
+        ).and increment_usage_metrics(
+          'redis_hll_counters.count_distinct_user_id_from_internal_events_cli_used_monthly',
+          'redis_hll_counters.count_distinct_user_id_from_internal_events_cli_used_weekly'
+        )
       end
 
       --------------------------------------------------
@@ -257,9 +299,8 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
       --------------------------------------------------
       # RSPEC
 
-      it_behaves_like 'internal event tracking' do
-        let(:event) { 'internal_events_cli_opened' }
-        let(:category) { described_class.name }
+      it "triggers an internal event" do
+        expect { subject }.to trigger_internal_events('internal_events_cli_opened')
       end
 
       --------------------------------------------------
@@ -545,7 +586,7 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
         additional_properties: {
           label: 'string', # TODO
           value: 72, # Time the CLI ran before closing (seconds)
-          custom_key: custom_value # The extra custom property name
+          custom_key: 'custom_value' # The extra custom property name
         }
       )
 
@@ -558,18 +599,16 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
       --------------------------------------------------
       # RSPEC
 
-      it_behaves_like 'internal event tracking' do
-        let(:event) { 'internal_events_cli_used' }
-        let(:category) { described_class.name }
-        let(:project) { create(:project) }
-        let(:user) { create(:user) }
-        let(:additional_properties) do
-          {
+      it "triggers an internal event" do
+        expect { subject }.to trigger_internal_events('internal_events_cli_used').with(
+          project: project,
+          user: user,
+          additional_properties: {
             label: 'string',
             value: 72,
-            custom_key: custom_value
+            custom_key: 'custom_value'
           }
-        end
+        )
       end
 
       --------------------------------------------------
@@ -597,7 +636,7 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
               {
                 label: 'string', // TODO
                 value: 72, // Time the CLI ran before closing (seconds)
-                custom_key: custom_value, // The extra custom property name
+                custom_key: 'custom_value', // The extra custom property name
               },
             );
           },
@@ -626,7 +665,7 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
           {
             label: 'string', // TODO
             value: 72, // Time the CLI ran before closing (seconds)
-            custom_key: custom_value, // The extra custom property name
+            custom_key: 'custom_value', // The extra custom property name
           },
         );
 
@@ -655,7 +694,7 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
           data-event-tracking="internal_events_cli_used"
           data-event-label="string"
           data-event-value=72
-          data-event-custom_key=custom_value
+          data-event-custom_key="custom_value"
         >
           Click Me
         </gl-button>
@@ -677,7 +716,7 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
           data-event-tracking-load="internal_events_cli_used"
           data-event-label="string"
           data-event-value=72
-          data-event-custom_key=custom_value
+          data-event-custom_key="custom_value"
         >
           Click Me
         </gl-button>
@@ -692,18 +731,18 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
       --------------------------------------------------
       # HAML -- ON-CLICK
 
-      .inline-block{ data: { event_tracking: 'internal_events_cli_used', event_label: 'string', event_value: 72, event_custom_key: custom_value } }
+      .inline-block{ data: { event_tracking: 'internal_events_cli_used', event_label: 'string', event_value: 72, event_custom_key: 'custom_value' } }
         = _('Important Text')
 
       --------------------------------------------------
       # HAML -- COMPONENT ON-CLICK
 
-      = render Pajamas::ButtonComponent.new(button_options: { data: { event_tracking: 'internal_events_cli_used', event_label: 'string', event_value: 72, event_custom_key: custom_value } })
+      = render Pajamas::ButtonComponent.new(button_options: { data: { event_tracking: 'internal_events_cli_used', event_label: 'string', event_value: 72, event_custom_key: 'custom_value' } })
 
       --------------------------------------------------
       # HAML -- COMPONENT ON-LOAD
 
-      = render Pajamas::ButtonComponent.new(button_options: { data: { event_tracking_load: true, event_tracking: 'internal_events_cli_used', event_label: 'string', event_value: 72, event_custom_key: custom_value } })
+      = render Pajamas::ButtonComponent.new(button_options: { data: { event_tracking_load: true, event_tracking: 'internal_events_cli_used', event_label: 'string', event_value: 72, event_custom_key: 'custom_value' } })
 
       --------------------------------------------------
       TEXT
@@ -744,5 +783,188 @@ RSpec.describe 'InternalEventsCli::Flows::UsageViewer', :aggregate_failures, fea
         )
       end
     end
+
+    context 'for an event with sum operator metrics' do
+      let(:expected_rspec_example) do
+        <<~TEXT.chomp
+        --------------------------------------------------
+        # RSPEC
+
+        it "triggers an internal event" do
+          expect { subject }.to trigger_internal_events('internal_events_cli_used').with(
+            project: project,
+            user: user,
+            additional_properties: {
+              label: 'string',
+              value: 72,
+              custom_key: 'custom_value'
+            }
+          ).and increment_usage_metrics(
+            'sums.sum_value_from_internal_events_cli_used_monthly',
+            'sums.sum_value_from_internal_events_cli_used_weekly',
+            'sums.sum_value_from_internal_events_cli_used'
+          ).by(72)
+        end
+
+        --------------------------------------------------
+        TEXT
+      end
+
+      before do
+        File.write(
+          'config/metrics/counts_all/sum_value_from_internal_events_cli_used.yml',
+          File.read('spec/fixtures/scripts/internal_events/metrics/sum_single_event.yml')
+        )
+      end
+
+      it 'shows examples with additional properties included' do
+        queue_cli_inputs([
+          "3\n", # Enum-select: View Usage -- look at code examples for an existing event
+          'internal_events_cli_used', # Filters to this event
+          "\n", # Select: config/events/internal_events_cli_used.yml
+          "\e[B", # Arrow down to: rspec
+          "\n", # Select: rspec
+          "Exit", # Filters to this item
+          "\n" # select: Exit
+        ])
+
+        with_cli_thread do
+          expect { plain_last_lines }.to eventually_include_cli_text(expected_rspec_example)
+        end
+      end
+
+      context 'for an event with sum operator metrics and non-sum operator metrics' do
+        let(:expected_rspec_example) do
+          <<~TEXT.chomp
+          --------------------------------------------------
+          # RSPEC
+
+          it "triggers an internal event" do
+            expect { subject }.to trigger_internal_events('internal_events_cli_used').with(
+              project: project,
+              user: user,
+              additional_properties: {
+                label: 'string',
+                value: 72,
+                custom_key: 'custom_value'
+              }
+            ).and increment_usage_metrics(
+              'redis_hll_counters.count_distinct_user_id_from_internal_events_cli_used_monthly',
+              'redis_hll_counters.count_distinct_user_id_from_internal_events_cli_used_weekly'
+            ).and increment_usage_metrics(
+              'sums.sum_value_from_internal_events_cli_used_monthly',
+              'sums.sum_value_from_internal_events_cli_used_weekly',
+              'sums.sum_value_from_internal_events_cli_used'
+            ).by(72)
+          end
+
+          --------------------------------------------------
+          TEXT
+        end
+
+        before do
+          File.write(
+            'config/metrics/counts_all/count_distinct_user_id_from_internal_events_cli_used.yml',
+            File.read('spec/fixtures/scripts/internal_events/metrics/user_id_single_event.yml')
+          )
+        end
+
+        it 'shows examples with additional properties included' do
+          queue_cli_inputs([
+            "3\n", # Enum-select: View Usage -- look at code examples for an existing event
+            'internal_events_cli_used', # Filters to this event
+            "\n", # Select: config/events/internal_events_cli_used.yml
+            "\e[B", # Arrow down to: rspec
+            "\n", # Select: rspec
+            "Exit", # Filters to this item
+            "\n" # select: Exit
+          ])
+
+          with_cli_thread do
+            expect { plain_last_lines }.to eventually_include_cli_text(expected_rspec_example)
+          end
+        end
+      end
+    end
+
+    context 'for an event without identifiers' do
+      let(:event_filepath) { 'config/events/internal_events_cli_used.yml' }
+      let(:event_content) { internal_event_fixture('events/event_with_additional_properties_without_identifiers.yml') }
+
+      let(:expected_rails_example) do
+        <<~TEXT.chomp
+        --------------------------------------------------
+        # RAILS
+
+        include Gitlab::InternalEventsTracking
+
+        track_internal_event(
+          'internal_events_cli_used',
+          additional_properties: {
+            label: 'string', # TODO
+            value: 72, # Time the CLI ran before closing (seconds)
+            custom_key: 'custom_value' # The extra custom property name
+          }
+        )
+
+        --------------------------------------------------
+        TEXT
+      end
+
+      let(:expected_rspec_example) do
+        <<~TEXT.chomp
+        --------------------------------------------------
+        # RSPEC
+
+        it "triggers an internal event" do
+          expect { subject }.to trigger_internal_events('internal_events_cli_used').with(
+            additional_properties: {
+              label: 'string',
+              value: 72,
+              custom_key: 'custom_value'
+            }
+          )
+        end
+
+        --------------------------------------------------
+        TEXT
+      end
+
+      before do
+        File.write(event_filepath, File.read(event_content))
+      end
+
+      it 'shows examples with additional properties included' do
+        queue_cli_inputs([
+          "3\n", # Enum-select: View Usage -- look at code examples for an existing event
+          'internal_events_cli_used', # Filters to this event
+          "\n", # Select: config/events/internal_events_cli_used.yml
+          "\n", # Select: ruby/rails
+          "\e[B", # Arrow down to: rspec
+          "\n", # Select: rspec
+          "\e[B", # Arrow down to: js vue
+          "\n", # Select: js vue
+          "\e[B", # Arrow down to: js plain
+          "\n", # Select: js plain
+          "\e[B", # Arrow down to: vue template
+          "\n", # Select: vue template
+          "\e[B", # Arrow down to: haml
+          "\n", # Select: haml
+          "Exit", # Filters to this item
+          "\n" # select: Exit
+        ])
+
+        with_cli_thread do
+          expect { plain_last_lines }.to eventually_include_cli_text(
+            expected_rails_example,
+            expected_rspec_example,
+            expected_vue_example,
+            expected_js_example,
+            expected_vue_template_example,
+            expected_haml_example
+          )
+        end
+      end
+    end
   end
 end
