@@ -1,12 +1,29 @@
 # frozen_string_literal: true
 
 require 'parallel'
+require 'timeout'
 require_relative 'gitaly_setup'
 require_relative '../../../lib/gitlab/setup_helper'
 
 module TestEnv
   extend self
 
+  def self.measure_setup_duration(name)
+    start = Process.clock_gettime(Process::CLOCK_MONOTONIC)
+    result = yield
+    duration = Process.clock_gettime(Process::CLOCK_MONOTONIC) - start
+
+    if duration > 0.5
+      duration = duration.round(3)
+      @durations_mutex.synchronize { @component_durations[name] ||= duration }
+      name = name.to_s
+      display_name = name.start_with?('setup_') ? name.delete_prefix('setup_').tr('_', ' ').capitalize : name
+      puts "==> #{display_name} set up in #{duration} seconds..."
+    end
+
+    result
+  end
+
   def self.included(_)
     raise "Don't include TestEnv. Use TestEnv.<method> instead."
   end
@@ -165,17 +182,51 @@ module TestEnv
       exit 1
     end
 
-    start = Time.now
+    @component_durations = {}
+    @durations_mutex = Mutex.new
+
+    start = Process.clock_gettime(Process::CLOCK_MONOTONIC)
     # Disable mailer for spinach tests
     clean_test_path
 
     # Install components in parallel as most of the setup is I/O.
-    Parallel.each(setup_methods) do |method|
-      public_send(method)
+    Parallel.each(setup_methods, in_threads: setup_methods.size) do |method|
+      measure_setup_duration(method.to_s) { public_send(method) }
     end
-    post_init
 
-    puts "\nTest environment set up in #{Time.now - start} seconds"
+    post_init
+    duration = (Process.clock_gettime(Process::CLOCK_MONOTONIC) - start)
+
+    puts "\nTest environment set up in #{duration} seconds"
+    send_rspec_setup_duration_telemetry(duration, @component_durations)
+  end
+
+  def send_rspec_setup_duration_telemetry(duration, component_durations)
+    gdk_path = Gitlab::Utils.which('gdk')
+    return unless gdk_path
+
+    extra_args = ["--extra=gitlab_sha:#{gitlab_sha}"]
+    component_durations.each do |name, time|
+      metric_name = name.downcase.gsub(/\s+/, '_').gsub(/[^a-z0-9_]/, '_')
+      extra_args << "--extra=#{metric_name}:#{time}"
+    end
+
+    Bundler.with_unbundled_env do
+      # Add timeout in case GDK command hangs unexpectedly
+      Timeout.timeout(2) do
+        success = system(gdk_path, 'send-telemetry', 'rspec_setup_duration', duration.round(3).to_s, *extra_args)
+        warn "Failed to send RSpec setup time via telemetry command." unless success
+      end
+    end
+  rescue Timeout::Error
+    warn "Sending telemetry timed out."
+  rescue StandardError => e
+    warn "Failed to send telemetry: #{e.message}"
+  end
+
+  def gitlab_sha
+    sha, exit_status = Gitlab::Popen.popen(%W[#{Gitlab.config.git.bin_path} rev-parse HEAD], Rails.root.to_s)
+    exit_status == 0 && !sha.chomp.empty? ? sha.chomp : 'unknown'
   end
 
   # Can be overriden
@@ -233,21 +284,18 @@ module TestEnv
 
   # Feature specs are run through Workhorse
   def setup_workhorse
-    # Always rebuild the config file
-    if skip_compile_workhorse?
-      Gitlab::SetupHelper::Workhorse.create_configuration(workhorse_dir, nil, force: true)
-      return
+    measure_setup_duration('GitLab Workhorse') do
+      # Always rebuild the config file
+      if skip_compile_workhorse?
+        Gitlab::SetupHelper::Workhorse.create_configuration(workhorse_dir, nil, force: true)
+      else
+        FileUtils.rm_rf(workhorse_dir)
+        Gitlab::SetupHelper::Workhorse.compile_into(workhorse_dir)
+        Gitlab::SetupHelper::Workhorse.create_configuration(workhorse_dir, nil)
+
+        File.write(workhorse_tree_file, workhorse_tree) if workhorse_source_clean?
+      end
     end
-
-    start = Time.now
-
-    FileUtils.rm_rf(workhorse_dir)
-    Gitlab::SetupHelper::Workhorse.compile_into(workhorse_dir)
-    Gitlab::SetupHelper::Workhorse.create_configuration(workhorse_dir, nil)
-
-    File.write(workhorse_tree_file, workhorse_tree) if workhorse_source_clean?
-
-    puts "==> GitLab Workhorse set up in #{Time.now - start} seconds...\n"
   end
 
   def skip_compile_workhorse?
@@ -321,9 +369,7 @@ module TestEnv
     clone_url = "https://gitlab.com/gitlab-org/#{repo_name}.git"
 
     unless File.directory?(repo_path)
-      start = Time.now
-      system(*%W[#{Gitlab.config.git.bin_path} clone --quiet -- #{clone_url} #{repo_path}])
-      puts "==> #{repo_path} set up in #{Time.now - start} seconds...\n"
+      measure_setup_duration(repo_path) { system(*%W[#{Gitlab.config.git.bin_path} clone --quiet -- #{clone_url} #{repo_path}]) }
     end
 
     create_bundle = !File.file?(repo_bundle_path)
@@ -345,9 +391,7 @@ module TestEnv
     end
 
     if create_bundle
-      start = Time.now
-      system(git_env, *%W[#{Gitlab.config.git.bin_path} -C #{repo_path} bundle create #{repo_bundle_path} --exclude refs/remotes/* --all])
-      puts "==> #{repo_bundle_path} generated in #{Time.now - start} seconds...\n"
+      measure_setup_duration(repo_bundle_path) { system(git_env, *%W[#{Gitlab.config.git.bin_path} -C #{repo_path} bundle create #{repo_bundle_path} --exclude refs/remotes/* --all]) }
     end
   end
 
@@ -415,14 +459,6 @@ module TestEnv
     # record deletions.
     Gitlab::DatabaseImporters::WorkItems::BaseTypeImporter.upsert_types
     Gitlab::DatabaseImporters::WorkItems::HierarchyRestrictionsImporter.upsert_restrictions
-    Gitlab::DatabaseImporters::WorkItems::RelatedLinksRestrictionsImporter.upsert_restrictions
-
-    # Updating old_id to simulate an environment that has gone through the process of cleaning
-    # the issues.work_item_type_id column. old_id is used as a fallback id.
-    # TODO: https://gitlab.com/gitlab-org/gitlab/-/issues/520023
-    WorkItems::Type.find_each do |work_item_type|
-      work_item_type.update!(old_id: -work_item_type.id)
-    end
   end
 
   private
@@ -469,32 +505,30 @@ module TestEnv
   end
 
   def component_timed_setup(component, install_dir:, version:, task:, fresh_install: true, task_args: [])
-    start = Time.now
-
     ensure_component_dir_name_is_correct!(component, install_dir)
 
     # On CI, once installed, components never need update
     return if File.exist?(install_dir) && ci?
 
     if component_needs_update?(install_dir, version)
-      puts "==> Starting #{component} (#{version}) set up...\n"
+      measure_setup_duration(component) do
+        puts "==> Starting #{component} (#{version}) set up...\n"
 
-      # Cleanup the component entirely to ensure we start fresh
-      FileUtils.rm_rf(install_dir) if fresh_install
+        # Cleanup the component entirely to ensure we start fresh
+        FileUtils.rm_rf(install_dir) if fresh_install
 
-      if ENV['SKIP_RAILS_ENV_IN_RAKE']
-        # When we run `scripts/setup-test-env`, we take care of loading the necessary dependencies
-        # so we can run the rake task programmatically.
-        Rake::Task[task].invoke(*task_args)
-      else
-        # In other cases, we run the task via `rake` so that the environment
-        # and dependencies are automatically loaded.
-        raise ComponentFailedToInstallError unless system('rake', "#{task}[#{task_args.join(',')}]")
+        if ENV['SKIP_RAILS_ENV_IN_RAKE']
+          # When we run `scripts/setup-test-env`, we take care of loading the necessary dependencies
+          # so we can run the rake task programmatically.
+          Rake::Task[task].invoke(*task_args)
+        else
+          # In other cases, we run the task via `rake` so that the environment
+          # and dependencies are automatically loaded.
+          raise ComponentFailedToInstallError unless system('rake', "#{task}[#{task_args.join(',')}]")
+        end
+
+        yield if block_given?
       end
-
-      yield if block_given?
-
-      puts "==> #{component} set up in #{Time.now - start} seconds...\n"
     end
   rescue ComponentFailedToInstallError
     puts "\n#{component} failed to install, cleaning up #{install_dir}!\n"
