@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
+RSpec.shared_examples 'a webhook' do |factory:|
   include AfterNextHelpers
 
   let(:hook) { build(factory) }
@@ -20,6 +20,8 @@ RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
     it { is_expected.to validate_length_of(:custom_webhook_template).is_at_most(4096) }
     it { is_expected.to validate_length_of(:name).is_at_most(255) }
     it { is_expected.to validate_length_of(:description).is_at_most(2048) }
+    it { is_expected.to validate_length_of(:url).is_at_most(described_class::MAX_PARAM_LENGTH) }
+    it { is_expected.to validate_length_of(:token).is_at_most(described_class::MAX_PARAM_LENGTH) }
 
     describe 'url_variables' do
       it { is_expected.to allow_value({}).for(:url_variables) }
@@ -54,6 +56,14 @@ RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
     end
 
     describe 'custom_headers' do
+      let(:multiple_line_string) do
+        <<~TEXT
+          This is line one
+          This is line two
+          This is line three
+        TEXT
+      end
+
       it { is_expected.to allow_value({}).for(:custom_headers) }
       it { is_expected.to allow_value({ 'foo' => 'bar' }).for(:custom_headers) }
       it { is_expected.to allow_value({ 'FOO' => 'bar' }).for(:custom_headers) }
@@ -68,6 +78,7 @@ RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
       it { is_expected.to allow_value({ 'x-y-z' => 'bar' }).for(:custom_headers) }
       it { is_expected.to allow_value({ 'x_y_z' => 'bar' }).for(:custom_headers) }
       it { is_expected.to allow_value({ 'f.o.o' => 'bar' }).for(:custom_headers) }
+      it { is_expected.to allow_value({ 'Content-Length' => 'all alone' }).for(:custom_headers) }
 
       it { is_expected.not_to allow_value([]).for(:custom_headers) }
       it { is_expected.not_to allow_value({ 'foo' => 1 }).for(:custom_headers) }
@@ -83,6 +94,16 @@ RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
       it { is_expected.not_to allow_value({ 'MY__SECRET' => 'foo' }).for(:custom_headers) }
       it { is_expected.not_to allow_value({ 'x-_y' => 'foo' }).for(:custom_headers) }
       it { is_expected.not_to allow_value({ 'x..y' => 'foo' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length: 3' => 'foo' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ ' Content-Length-3' => 'foo' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length ' => 'foo' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length' => ' foo' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length' => 'foo ' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length' => '\r' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length' => '\n' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length' => '%0A' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length' => '%0D' }).for(:custom_headers) }
+      it { is_expected.not_to allow_value({ 'Content-Length' => multiple_line_string }).for(:custom_headers) }
     end
 
     describe 'url' do
@@ -110,6 +131,33 @@ RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
         end
       end
 
+      context 'when testing PublicUrlValidator execution around MAX_PARAM_LENGTH threshold' do
+        # Ensures invalid URLs are rejected at all lengths around MAX_PARAM_LENGTH boundary.
+        # PublicUrlValidator runs only when length <= MAX_PARAM_LENGTH, so we verify
+        # the webhook stays invalid whether rejected by URL format or by length.
+
+        let(:invalid_url_base) { 'ftp://example.com/' }
+        let(:padding_to_max_length) { described_class::MAX_PARAM_LENGTH - invalid_url_base.length }
+
+        context 'with URL length 1 less than MAX_PARAM_LENGTH' do
+          let(:url) { invalid_url_base + ('x' * (padding_to_max_length - 1)) }
+
+          it { is_expected.not_to allow_value(url).for(:url).with_message(including('allowed schemes are http')) }
+        end
+
+        context 'with URL length exactly MAX_PARAM_LENGTH' do
+          let(:url) { invalid_url_base + ('x' * padding_to_max_length) }
+
+          it { is_expected.not_to allow_value(url).for(:url).with_message(including('allowed schemes are http')) }
+        end
+
+        context 'with URL length 1 more than MAX_PARAM_LENGTH' do
+          let(:url) { invalid_url_base + ('x' * (padding_to_max_length + 1)) }
+
+          it { is_expected.not_to allow_value(url).for(:url).with_message(including('is too long')) }
+        end
+      end
+
       it 'strips :url before saving it' do
         hook.url = ' https://example.com '
         hook.save!
@@ -332,7 +380,7 @@ RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
   end
 
   describe 'encrypted attributes' do
-    subject { described_class.attr_encrypted_attributes.keys }
+    subject { described_class.attr_encrypted_encrypted_attributes.keys }
 
     it { is_expected.to contain_exactly(:token, :url, :url_variables, :custom_headers) }
   end
@@ -421,48 +469,6 @@ RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
     end
   end
 
-  describe '#next_backoff' do
-    before do
-      hook.backoff_count = backoff_count
-    end
-
-    context 'when there was no last backoff' do
-      let(:backoff_count) { 0 }
-
-      it 'is the initial value' do
-        expect(hook.next_backoff).to eq(WebHooks::AutoDisabling::INITIAL_BACKOFF)
-      end
-    end
-
-    context 'when we have backed off once' do
-      let(:backoff_count) { 1 }
-
-      it 'is twice the initial value' do
-        expect(hook.next_backoff).to eq(2 * WebHooks::AutoDisabling::INITIAL_BACKOFF)
-      end
-    end
-
-    context 'when the next backoff is just before the max backoff limit' do
-      let(:backoff_count) { WebHooks::AutoDisabling::MAX_BACKOFF_COUNT - 1 }
-
-      it 'is an exponential of the initial backoff' do
-        expect(hook.next_backoff).to eq((2**backoff_count) * WebHooks::AutoDisabling::INITIAL_BACKOFF)
-      end
-
-      it 'is not yet capped at the max limit' do
-        expect(hook.next_backoff).to be < WebHooks::AutoDisabling::MAX_BACKOFF
-      end
-    end
-
-    describe 'when next_backoff has reached the MAX_BACKOFF limit' do
-      let(:backoff_count) { WebHooks::AutoDisabling::MAX_BACKOFF_COUNT }
-
-      it 'does not exceed the max backoff value' do
-        expect(hook.next_backoff).to eq(WebHooks::AutoDisabling::MAX_BACKOFF)
-      end
-    end
-  end
-
   describe '#rate_limited?' do
     it 'is false when hook has not been rate limited' do
       expect_next_instance_of(Gitlab::WebHooks::RateLimiter) do |rate_limiter|
@@ -560,148 +566,4 @@ RSpec.shared_examples 'a webhook' do |factory:, auto_disabling: true|
       it { expect(hook.masked_token).to eq described_class::SECRET_MASK }
     end
   end
-
-  describe '#backoff!', if: auto_disabling do
-    context 'when we have not backed off before' do
-      it 'increments the recent_failures count but does not disable the hook yet' do
-        expect { hook.backoff! }.to change { hook.recent_failures }.to(1)
-        expect(hook.class.executable).to include(hook)
-      end
-    end
-
-    context 'when hook is at the failure threshold' do
-      before do
-        WebHooks::AutoDisabling::FAILURE_THRESHOLD.times { hook.backoff! }
-      end
-
-      it 'is not yet disabled' do
-        expect(hook.class.executable).to include(hook)
-        expect(hook).to have_attributes(
-          recent_failures: WebHooks::AutoDisabling::FAILURE_THRESHOLD,
-          backoff_count: 0,
-          disabled_until: nil
-        )
-      end
-
-      context 'when hook is next told to backoff' do
-        before do
-          hook.backoff!
-        end
-
-        it 'causes the hook to become disabled for initial backoff period' do
-          expect(hook.class.executable).not_to include(hook)
-          expect(hook).to have_attributes(
-            recent_failures: (WebHooks::AutoDisabling::FAILURE_THRESHOLD + 1),
-            backoff_count: 1,
-            disabled_until: 1.minute.from_now
-          )
-        end
-
-        context 'when the backoff time has elapsed', :skip_freeze_time do
-          it 'is no longer disabled' do
-            travel_to(hook.disabled_until + 1.minute) do
-              expect(hook.class.executable).to include(hook)
-            end
-          end
-
-          context 'when the hook is next told to backoff' do
-            it 'disables the hook again, increasing the backoff time exponentially' do
-              travel_to(hook.disabled_until + 1.minute) do
-                hook.backoff!
-
-                expect(hook.class.executable).not_to include(hook)
-                expect(hook).to have_attributes(
-                  recent_failures: (WebHooks::AutoDisabling::FAILURE_THRESHOLD + 2),
-                  backoff_count: 2,
-                  disabled_until: 2.minutes.from_now
-                )
-              end
-            end
-          end
-        end
-      end
-    end
-
-    it 'does not do anything if the hook is currently temporarily disabled' do
-      allow(hook).to receive(:temporarily_disabled?).and_return(true)
-
-      sql_count = ActiveRecord::QueryRecorder.new { hook.backoff! }.count
-
-      expect(sql_count).to eq(0)
-    end
-
-    it 'does not do anything if the hook is currently permanently disabled' do
-      allow(hook).to receive(:permanently_disabled?).and_return(true)
-
-      sql_count = ActiveRecord::QueryRecorder.new { hook.backoff! }.count
-
-      expect(sql_count).to eq(0)
-    end
-
-    context 'when the counter are above MAX_FAILURES' do
-      let(:max_failures) { WebHooks::AutoDisabling::MAX_FAILURES }
-
-      before do
-        hook.update!(
-          recent_failures: (max_failures + 1),
-          backoff_count: (max_failures + 1),
-          disabled_until: 1.hour.ago
-        )
-      end
-
-      it 'reduces the counter to MAX_FAILURES' do
-        hook.backoff!
-
-        expect(hook).to have_attributes(
-          recent_failures: max_failures,
-          backoff_count: max_failures
-        )
-      end
-    end
-  end
-
-  describe '#failed!', if: auto_disabling do
-    it 'increments the recent_failures count but does not disable the hook yet' do
-      expect { hook.failed! }.to change { hook.recent_failures }.to(1)
-      expect(hook.class.executable).to include(hook)
-    end
-
-    context 'when hook is at the failure threshold' do
-      before do
-        WebHooks::AutoDisabling::FAILURE_THRESHOLD.times { hook.failed! }
-      end
-
-      it 'is not yet disabled' do
-        expect(hook.class.executable).to include(hook)
-        expect(hook).to have_attributes(
-          recent_failures: WebHooks::AutoDisabling::FAILURE_THRESHOLD,
-          backoff_count: 0,
-          disabled_until: nil
-        )
-      end
-
-      context 'when hook is next failed' do
-        before do
-          hook.failed!
-        end
-
-        it 'causes the hook to become disabled' do
-          expect(hook.class.executable).not_to include(hook)
-          expect(hook).to have_attributes(
-            recent_failures: (WebHooks::AutoDisabling::FAILURE_THRESHOLD + 1),
-            backoff_count: 0,
-            disabled_until: nil
-          )
-        end
-      end
-    end
-
-    it 'does not do anything if recent_failures is at MAX_FAILURES' do
-      hook.recent_failures = WebHooks::AutoDisabling::MAX_FAILURES
-
-      sql_count = ActiveRecord::QueryRecorder.new { hook.failed! }.count
-
-      expect(sql_count).to eq(0)
-    end
-  end
 end
