@@ -146,6 +146,11 @@ RSpec.shared_examples 'conan search endpoint with access to package registry for
 end
 
 RSpec.shared_examples 'conan authenticate endpoint' do
+  let(:auth_token) { personal_access_token.token }
+  let(:headers) do
+    { 'HTTP_AUTHORIZATION' => ActionController::HttpAuthentication::Basic.encode_credentials('foo', auth_token) }
+  end
+
   subject { get api(url), headers: headers }
 
   it_behaves_like 'conan FIPS mode'
@@ -219,6 +224,8 @@ RSpec.shared_examples 'conan authenticate endpoint' do
       expect(response).to have_gitlab_http_status(:ok)
     end
   end
+
+  it_behaves_like 'updating personal access token last used'
 end
 
 RSpec.shared_examples 'conan check_credentials endpoint' do
@@ -307,16 +314,16 @@ RSpec.shared_examples 'handling validation error for package' do
   end
 end
 
-RSpec.shared_examples 'handling empty values for username and channel' do
+RSpec.shared_examples 'handling empty values for username and channel' do |success_status: :ok|
   using RSpec::Parameterized::TableSyntax
 
   let(:recipe_path) { "#{package.name}/#{package.version}/#{package_username}/#{channel}" }
 
   where(:username, :channel, :status) do
-    'username' | 'channel' | :ok
+    'username' | 'channel' | success_status
     'username' | '_'       | :bad_request
     '_'        | 'channel' | :bad_request_or_not_found
-    '_'        | '_'       | :ok_or_not_found
+    '_'        | '_'       | :success_status_or_not_found
   end
 
   with_them do
@@ -336,15 +343,15 @@ RSpec.shared_examples 'handling empty values for username and channel' do
       project_level = example.full_description.include?('api/v4/projects')
 
       expected_status = case status
-                        when :ok_or_not_found
-                          project_level ? :ok : :not_found
+                        when :success_status_or_not_found
+                          project_level ? success_status : :not_found
                         when :bad_request_or_not_found
                           project_level ? :bad_request : :not_found
                         else
                           status
                         end
 
-      if expected_status == :ok
+      if expected_status == success_status
         package.conan_metadatum.update!(package_username: package_username, package_channel: channel)
       end
 
@@ -486,6 +493,7 @@ RSpec.shared_examples 'recipe snapshot endpoint' do
   it_behaves_like 'rejects recipe for invalid project'
   it_behaves_like 'empty recipe for not found package'
   it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'updating personal access token last used'
 
   context 'with existing package' do
     it 'returns a hash of files with their md5 hashes' do
@@ -513,6 +521,7 @@ RSpec.shared_examples 'package snapshot endpoint' do
   it_behaves_like 'rejects recipe for invalid project'
   it_behaves_like 'empty recipe for not found package'
   it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'updating personal access token last used'
 
   context 'with existing package' do
     it 'returns a hash of md5 values for the files' do
@@ -538,6 +547,7 @@ RSpec.shared_examples 'recipe download_urls endpoint' do
   it_behaves_like 'rejects recipe for invalid project'
   it_behaves_like 'recipe download_urls'
   it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'updating personal access token last used'
 end
 
 RSpec.shared_examples 'package download_urls endpoint' do
@@ -549,6 +559,7 @@ RSpec.shared_examples 'package download_urls endpoint' do
   it_behaves_like 'rejects recipe for invalid project'
   it_behaves_like 'package download_urls'
   it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'updating personal access token last used'
 end
 
 RSpec.shared_examples 'recipe upload_urls endpoint' do
@@ -565,6 +576,7 @@ RSpec.shared_examples 'recipe upload_urls endpoint' do
   it_behaves_like 'rejects invalid recipe'
   it_behaves_like 'rejects invalid upload_url params'
   it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'updating personal access token last used'
 
   it 'returns a set of upload urls for the files requested' do
     subject
@@ -630,6 +642,7 @@ RSpec.shared_examples 'package upload_urls endpoint' do
   it_behaves_like 'rejects invalid recipe'
   it_behaves_like 'rejects invalid upload_url params'
   it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'updating personal access token last used'
 
   it 'returns a set of upload urls for the files requested' do
     expected_response = {
@@ -667,6 +680,7 @@ RSpec.shared_examples 'delete package endpoint' do
   it_behaves_like 'conan FIPS mode'
   it_behaves_like 'rejects invalid recipe'
   it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'updating personal access token last used'
 
   it 'returns unauthorized for users without valid permission' do
     subject
@@ -797,7 +811,7 @@ RSpec.shared_examples 'recipe file download endpoint' do
   it_behaves_like 'an internal project with packages'
   it_behaves_like 'a private project with packages'
   it_behaves_like 'handling empty values for username and channel'
-  it_behaves_like 'package not found download'
+  it_behaves_like 'package not found'
 end
 
 RSpec.shared_examples 'package file download endpoint' do
@@ -806,7 +820,7 @@ RSpec.shared_examples 'package file download endpoint' do
   it_behaves_like 'an internal project with packages'
   it_behaves_like 'a private project with packages'
   it_behaves_like 'handling empty values for username and channel'
-  it_behaves_like 'package not found download'
+  it_behaves_like 'package not found'
 
   context 'tracking the conan_package.tgz download' do
     let(:package_file) { package.package_files.find_by(file_name: ::Packages::Conan::FileMetadatum::PACKAGE_BINARY) }
@@ -827,13 +841,15 @@ RSpec.shared_examples 'project not found by project id' do
   it_behaves_like 'not found request'
 end
 
-RSpec.shared_examples 'workhorse authorize endpoint' do
+RSpec.shared_examples 'workhorse authorize endpoint' do |with_checksum_deploy_header: true|
   it_behaves_like 'enforcing admin_packages job token policy'
   it_behaves_like 'conan FIPS mode'
   it_behaves_like 'rejects invalid recipe'
   it_behaves_like 'rejects invalid file_name', 'conanfile.py.git%2fgit-upload-pack'
   it_behaves_like 'workhorse authorization'
   it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'handling checksum deploy header' if with_checksum_deploy_header
+  it_behaves_like 'updating personal access token last used'
 end
 
 RSpec.shared_examples 'protected package main example' do
@@ -886,27 +902,10 @@ RSpec.shared_examples 'protected package main example' do
     with_them do
       it_behaves_like params[:shared_examples_name]
     end
-
-    context 'when feature flag :packages_protected_packages_conan is disabled' do
-      before do
-        stub_feature_flags(packages_protected_packages_conan: false)
-      end
-
-      where(:package_name_pattern, :minimum_access_level_for_push, :personal_access_token, :shared_examples_name) do
-        ref(:conan_package_name)          | :maintainer | ref(:pat_project_developer) | 'uploads a package file'
-        ref(:conan_package_name)          | :admin      | ref(:pat_project_owner)     | 'uploads a package file'
-        ref(:conan_package_name_no_match) | :maintainer | ref(:pat_project_developer) | 'uploads a package file'
-        ref(:conan_package_name_no_match) | :admin      | ref(:pat_project_owner)     | 'uploads a package file'
-      end
-
-      with_them do
-        it_behaves_like params[:shared_examples_name]
-      end
-    end
   end
 end
 
-RSpec.shared_examples 'workhorse recipe file upload endpoint' do |recipe_revision: false|
+RSpec.shared_examples 'workhorse recipe file upload endpoint' do |revision: false|
   let(:file_name) { 'conanfile.py' }
   let(:params) { { file: temp_file(file_name) } }
 
@@ -930,11 +929,28 @@ RSpec.shared_examples 'workhorse recipe file upload endpoint' do |recipe_revisio
   it_behaves_like 'handling empty values for username and channel'
   it_behaves_like 'handling validation error for package'
   it_behaves_like 'protected package main example'
+  it_behaves_like 'updating personal access token last used'
 
-  it { expect { request }.to change { Packages::Conan::RecipeRevision.count }.by(1) } if recipe_revision
+  if revision
+    it { expect { request }.to change { Packages::Conan::RecipeRevision.count }.by(1) }
+
+    context 'when the file already exists' do
+      let(:recipe_revision) { package.conan_recipe_revisions.first.revision }
+      let(:recipe_path_name) { package.name }
+
+      it 'does not upload the file again' do
+        expect { request }.not_to change { Packages::PackageFile.count }
+        expect(response).to have_gitlab_http_status(:bad_request)
+        expect(json_response).to eq({
+          'message' => '400 Bad request - Validation failed: ' \
+            'File name already exists for the given recipe revision, package reference, and package revision'
+        })
+      end
+    end
+  end
 end
 
-RSpec.shared_examples 'workhorse package file upload endpoint' do
+RSpec.shared_examples 'workhorse package file upload endpoint' do |revision: false|
   let(:file_name) { 'conaninfo.txt' }
   let(:params) { { file: temp_file(file_name) } }
 
@@ -957,6 +973,33 @@ RSpec.shared_examples 'workhorse package file upload endpoint' do
   it_behaves_like 'handling empty values for username and channel'
   it_behaves_like 'handling validation error for package'
   it_behaves_like 'protected package main example'
+  it_behaves_like 'updating personal access token last used'
+
+  if revision
+    it 'creates a recipe and package revision' do
+      expect { request }
+        .to change { Packages::Conan::RecipeRevision.count }.by(1)
+        .and change { Packages::Conan::PackageRevision.count }.by(1)
+    end
+
+    context 'when the file already exists' do
+      let(:recipe_revision) { package.conan_recipe_revisions.first.revision }
+      let(:package_revision) { package.conan_package_revisions.first.revision }
+      let(:conan_package_reference) { package.conan_package_references.first.reference }
+      let(:recipe_path_name) { package.name }
+
+      it 'does not upload the file again' do
+        expect { request }.not_to change { Packages::PackageFile.count }
+        expect(response).to have_gitlab_http_status(:bad_request)
+        expect(json_response).to eq({
+          'message' => '400 Bad request - Validation failed: ' \
+            'File name already exists for the given recipe revision, package reference, and package revision'
+        })
+      end
+    end
+  end
+
+  it { expect { request }.to change { Packages::Conan::PackageReference.count }.by(1) }
 
   context 'tracking the conan_package.tgz upload' do
     let(:file_name) { ::Packages::Conan::FileMetadatum::PACKAGE_BINARY }
@@ -1020,14 +1063,20 @@ RSpec.shared_examples 'uploads a package file' do
     context 'when params from workhorse are correct' do
       it 'creates package and stores package file' do
         expect { subject }
-          .to change { project.packages.count }.by(1)
+          .to change { ::Packages::Conan::Package.for_projects(project).count }.by(1)
           .and change { Packages::PackageFile.count }.by(1)
 
         expect(response).to have_gitlab_http_status(:ok)
 
-        package_file = project.packages.last.package_files.reload.last
+        package_file = ::Packages::Conan::Package.for_projects(project).last.package_files.reload.last
         expect(package_file.file_name).to eq(params[:file].original_filename)
         expect(package_file.conan_file_metadatum.recipe_revision_value).to eq(recipe_revision)
+        expect(package_file.conan_file_metadatum.package_reference_value).to eq(
+          package_file.conan_file_metadatum.package_file? ? conan_package_reference : nil
+        )
+        expect(package_file.conan_file_metadatum.package_revision_value).to eq(
+          package_file.conan_file_metadatum.package_file? ? package_revision : nil
+        )
       end
 
       context 'with existing package' do
@@ -1042,7 +1091,7 @@ RSpec.shared_examples 'uploads a package file' do
 
         it 'does not create a new package' do
           expect { subject }
-            .to not_change { project.packages.count }
+            .to not_change { ::Packages::Conan::Package.for_projects(project).count }
             .and not_change { Packages::Conan::Metadatum.count }
             .and change { Packages::PackageFile.count }.by(1)
         end
@@ -1052,7 +1101,7 @@ RSpec.shared_examples 'uploads a package file' do
             existing_package.pending_destruction!
 
             expect { subject }
-              .to change { project.packages.count }.by(1)
+              .to change { ::Packages::Conan::Package.for_projects(project).count }.by(1)
               .and change { Packages::Conan::Metadatum.count }.by(1)
               .and change { Packages::PackageFile.count }.by(1)
           end
@@ -1103,12 +1152,12 @@ RSpec.shared_examples 'uploads a package file' do
 
         it 'creates package and stores package file' do
           expect { subject }
-            .to change { project.packages.count }.by(1)
+            .to change { ::Packages::Conan::Package.for_projects(project).count }.by(1)
             .and change { Packages::PackageFile.count }.by(1)
 
           expect(response).to have_gitlab_http_status(:ok)
 
-          package_file = project.packages.last.package_files.reload.last
+          package_file = ::Packages::Conan::Package.for_projects(project).last.package_files.reload.last
           expect(package_file.file_name).to eq(params[:file].original_filename)
           expect(package_file.file.read).to eq('content')
         end
@@ -1209,7 +1258,7 @@ RSpec.shared_examples 'accept get request on private project with access to pack
   it_behaves_like 'returning response status', :ok
 end
 
-RSpec.shared_examples 'package not found download' do
+RSpec.shared_examples 'package not found' do
   context 'when package does not exist' do
     let(:recipe_path) { "missing/0.1.0/#{project.full_path.tr('/', '+')}/stable" }
 
@@ -1221,3 +1270,120 @@ RSpec.shared_examples 'package not found download' do
     end
   end
 end
+
+RSpec.shared_examples 'packages feature check' do
+  before do
+    stub_packages_setting(enabled: false)
+  end
+
+  it_behaves_like 'returning response status', :not_found
+end
+
+RSpec.shared_examples 'GET package references metadata endpoint' do |with_recipe_revision: false|
+  subject(:request) { get api(url), headers: headers }
+
+  let_it_be(:reference1) { package.conan_package_references.first }
+
+  let_it_be(:reference2) do
+    create(:conan_package_reference, package: package, info: { 'settings' => { 'os' => 'Linux' } })
+  end
+
+  it_behaves_like 'conan FIPS mode'
+  it_behaves_like 'packages feature check'
+  it_behaves_like 'handling empty values for username and channel'
+  it_behaves_like 'package not found'
+  it_behaves_like 'enforcing read_packages job token policy'
+
+  context 'When the project is public' do
+    before do
+      project.update_column(:visibility_level, Gitlab::VisibilityLevel::PUBLIC)
+    end
+
+    it_behaves_like 'allows download with no token'
+  end
+
+  context 'When the project is internal' do
+    before do
+      project.team.truncate
+      project.update_column(:visibility_level, Gitlab::VisibilityLevel::INTERNAL)
+    end
+
+    it_behaves_like 'denies download with no token'
+  end
+
+  context 'When the project is private' do
+    before do
+      project.update_column(:visibility_level, Gitlab::VisibilityLevel::PRIVATE)
+    end
+
+    it 'returns success with package references metadata', :aggregate_failures do
+      subject
+
+      expect(response).to have_gitlab_http_status(:ok)
+      expect(json_response).to include(
+        reference1.reference => reference1.info,
+        reference2.reference => reference2.info
+      )
+    end
+
+    it_behaves_like 'denies download with no token'
+
+    context 'when allow_guest_plus_roles_to_pull_packages is disabled' do
+      before do
+        stub_feature_flags(allow_guest_plus_roles_to_pull_packages: false)
+      end
+
+      it 'denies download when not enough permissions' do
+        project.add_guest(user)
+
+        subject
+
+        expect(response).to have_gitlab_http_status(:forbidden)
+      end
+    end
+  end
+
+  if with_recipe_revision
+    context 'when recipe revision does not exist' do
+      let(:recipe_revision) { OpenSSL::Digest.hexdigest('MD5', 'nonexistent-revision') }
+
+      it_behaves_like 'returning response status with message', status: :not_found,
+        message: '404 Revision Not Found'
+    end
+
+    context 'with different recipe revisions' do
+      let_it_be(:recipe_revision2) { create(:conan_recipe_revision, package: package) }
+      let_it_be(:reference2) do
+        create(:conan_package_reference, package: package, info: { 'settings' => { 'os' => 'Linux' } },
+          recipe_revision: recipe_revision2)
+      end
+
+      it 'returns only the package references for the requested recipe revision' do
+        request
+
+        expect(response).to have_gitlab_http_status(:ok)
+        expect(json_response).to include(
+          reference1.reference => reference1.info
+        )
+      end
+    end
+  end
+end
+
+RSpec.shared_examples 'handling checksum deploy header' do
+  context 'when X-Checksum-Deploy header is "true"' do
+    before do
+      headers_with_token['X-Checksum-Deploy'] = 'true'
+    end
+
+    it_behaves_like 'returning response status', :not_found
+  end
+
+  context 'when X-Checksum-Deploy header is not "true"' do
+    before do
+      headers_with_token['X-Checksum-Deploy'] = 0
+    end
+
+    it_behaves_like 'returning response status', :ok
+  end
+end
