@@ -270,9 +270,9 @@ RSpec.shared_examples 'handling audit request' do |path:, scope: :project|
   let(:params) do
     ActiveSupport::Gzip.compress(
       Gitlab::Json.dump({
-                          '@gitlab-org/npm-test': ['1.0.6'],
-                          'call-bind': ['1.0.2']
-                        })
+        '@gitlab-org/npm-test': ['1.0.6'],
+        'call-bind': ['1.0.2']
+      })
     )
   end
 
@@ -755,6 +755,18 @@ RSpec.shared_examples 'handles authenticated requests, for tags create or delete
         end
       end
     end
+
+    if action == :delete
+      context 'with packages_tags_finder_use_packages_class feature flag disabled' do
+        let(:headers) { build_headers_for_auth_type(:oauth) }
+
+        before do
+          stub_feature_flags(packages_tags_finder_use_packages_class: false)
+        end
+
+        it_behaves_like 'accept delete package tag request', status: :ok
+      end
+    end
   end
 end
 
