@@ -1,6 +1,8 @@
 package upstream
 
 import (
+	"context"
+	"fmt"
 	"net/http"
 	"net/url"
 	"regexp"
@@ -11,16 +13,20 @@ import (
 	"gitlab.com/gitlab-org/labkit/log"
 	"gitlab.com/gitlab-org/labkit/tracing"
 
+	"gitlab.com/gitlab-org/gitlab/workhorse/internal/ai_assist/duoworkflow"
 	apipkg "gitlab.com/gitlab-org/gitlab/workhorse/internal/api"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/artifacts"
+	"gitlab.com/gitlab-org/gitlab/workhorse/internal/bodylimit"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/builds"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/channel"
+	"gitlab.com/gitlab-org/gitlab/workhorse/internal/circuitbreaker"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/config"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/dependencyproxy"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/git"
 	gobpkg "gitlab.com/gitlab-org/gitlab/workhorse/internal/gob"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/helper"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/imageresizer"
+	"gitlab.com/gitlab-org/gitlab/workhorse/internal/metrics"
 	proxypkg "gitlab.com/gitlab-org/gitlab/workhorse/internal/proxy"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/queueing"
 	"gitlab.com/gitlab-org/gitlab/workhorse/internal/secret"
@@ -53,6 +59,8 @@ type routeOptions struct {
 	isGeoProxyRoute bool
 	matchers        []matcherFunc
 	allowOrigins    *regexp.Regexp
+	bodyLimit       int64
+	bodyLimitMode   bodylimit.Mode
 }
 
 const (
@@ -118,16 +126,38 @@ func withAllowOrigins(pattern string) func(*routeOptions) {
 	}
 }
 
+func withBodyLimit(bodyLimit int64) func(*routeOptions) {
+	return func(options *routeOptions) {
+		options.bodyLimit = bodyLimit
+	}
+}
+
+func withBodyLimitMode(bodyLimitMode bodylimit.Mode) func(*routeOptions) {
+	return func(options *routeOptions) {
+		if bodyLimitMode < bodylimit.ModeDisabled || bodyLimitMode > bodylimit.ModeEnforced {
+			panic(fmt.Sprintf("invalid body limit mode: %d", bodyLimitMode))
+		}
+		options.bodyLimitMode = bodyLimitMode
+	}
+}
+
 func (u *upstream) observabilityMiddlewares(handler http.Handler, method string, metadata routeMetadata, opts *routeOptions) http.Handler {
 	handler = log.AccessLogger(
 		handler,
 		log.WithAccessLogger(u.accessLogger),
+		log.WithTrustedProxies(u.TrustedCIDRsForXForwardedFor),
 		log.WithExtraFields(func(_ *http.Request) log.Fields {
-			return log.Fields{
+			fields := log.Fields{
 				"route":      metadata.regexpStr, // This field matches the `route` label in Prometheus metrics
 				"route_id":   metadata.routeID,
 				"backend_id": metadata.backendID,
 			}
+
+			if opts != nil {
+				fields["body_limit"] = opts.bodyLimit
+			}
+
+			return fields
 		}),
 	)
 
@@ -137,13 +167,25 @@ func (u *upstream) observabilityMiddlewares(handler http.Handler, method string,
 		handler = instrumentGeoProxyRoute(handler, method, metadata) // Add Geo prometheus metrics
 	}
 
+	originalHandler := handler
+
+	// Wrap with metrics tracking (add the tracker to the context)
+	handler = http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		tracker := metrics.NewRequestTracker()
+		ctx := metrics.NewContext(r.Context(), tracker)
+		r = r.WithContext(ctx)
+		originalHandler.ServeHTTP(w, r)
+	})
+
 	return handler
 }
 
 func (u *upstream) route(method string, metadata routeMetadata, handler http.Handler, opts ...func(*routeOptions)) routeEntry {
 	// Instantiate a route with the defaults
 	options := routeOptions{
-		tracing: true,
+		tracing:       true,
+		bodyLimit:     100 * 1024 * 1024,       // 100MB
+		bodyLimitMode: bodylimit.ModeUseGlobal, // use global mode without redefining
 	}
 
 	for _, f := range opts {
@@ -160,6 +202,10 @@ func (u *upstream) route(method string, metadata routeMetadata, handler http.Han
 		handler = corsMiddleware(handler, options.allowOrigins)
 	}
 
+	if options.bodyLimit > 0 {
+		handler = withBodyLimitContext(options.bodyLimit, options.bodyLimitMode, handler)
+	}
+
 	return routeEntry{
 		method:   method,
 		regex:    compileRegexp(metadata.regexpStr),
@@ -311,6 +357,11 @@ func configureRoutes(u *upstream) {
 			newRoute(projectPattern+`-/jobs/[0-9]+/proxy.ws\z`, "project_jobs_proxy_ws", railsBackend),
 			channel.Handler(api)),
 
+		// Duo Workflow websocket
+		u.wsRoute(
+			newRoute(apiPattern+`v4/ai/duo_workflows/ws\z`, "duo_workflow_ws", railsBackend),
+			duoworkflow.Handler(api)),
+
 		// Long poll and limit capacity given to jobs/request and builds/register.json
 		u.route("",
 			newRoute(apiPattern+`v4/jobs/request\z`, "api_jobs_request", railsBackend), ciAPILongPolling),
@@ -380,7 +431,10 @@ func configureRoutes(u *upstream) {
 		u.route("POST",
 			newRoute(apiGroupPattern+`/wikis/attachments\z`, "api_groups_wikis_attachments", railsBackend), tempfileMultipartProxy),
 		u.route("POST",
-			newRoute(apiPattern+`graphql\z`, "api_graphql", railsBackend), tempfileMultipartProxy),
+			newRoute(apiPattern+`graphql\z`, "api_graphql", railsBackend), tempfileMultipartProxy, withBodyLimit(20*1024*1024)), // 20 Mb
+		// See https://gitlab.com/gitlab-org/gitlab/-/issues/535366
+		u.route("POST",
+			newRoute(apiProjectPattern+`/remote_mirrors\z`, "api_projects_remote_mirrors", railsBackend), proxy, withBodyLimit(100*1024), withBodyLimitMode(bodylimit.ModeEnforced)), // 100 Kb
 		u.route("POST",
 			newRoute(apiTopicPattern, "api_topics", railsBackend), tempfileMultipartProxy),
 		u.route("PUT",
@@ -461,6 +515,8 @@ func configureRoutes(u *upstream) {
 		u.route("GET", newRoute(apiProjectPattern+`/observability/v1/services`, "api_observability_services", railsBackend), gob.WithProjectAuth("/read/services")),
 
 		// Explicitly proxy API requests
+		u.route("POST", newRoute(apiPattern+`v4/internal/allowed`, "api_internal_allowed", railsBackend), allowedProxy(proxy, dependencyProxyInjector, u)),
+
 		u.route("",
 			newRoute(apiPattern, "api", railsBackend), proxy),
 
@@ -600,3 +656,29 @@ func corsMiddleware(next http.Handler, allowOriginRegex *regexp.Regexp) http.Han
 		next.ServeHTTP(w, r)
 	})
 }
+
+func allowedProxy(proxy http.Handler, dependencyProxyInjector *dependencyproxy.Injector, u *upstream) http.Handler {
+	if u.Config.CircuitBreakerConfig.Enabled {
+		roundTripperCircuitBreaker := circuitbreaker.NewRoundTripper(u.RoundTripper, &u.CircuitBreakerConfig, u.rdb)
+
+		return buildProxy(u.Backend, u.Version, roundTripperCircuitBreaker, u.Config, dependencyProxyInjector)
+	}
+
+	return proxy
+}
+
+// Define a context key with a body limit value for route
+func withBodyLimitContext(bodyLimit int64, bodyLimitMode bodylimit.Mode, next http.Handler) http.Handler {
+	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		ctx := r.Context()
+		ctx = context.WithValue(ctx, bodylimit.BodyLimitKey, bodyLimit)
+
+		// if mode is redefined for the route
+		if bodyLimitMode != bodylimit.ModeUseGlobal {
+			ctx = context.WithValue(ctx, bodylimit.BodyLimitMode, bodyLimitMode)
+		}
+
+		r = r.WithContext(ctx)
+		next.ServeHTTP(w, r)
+	})
+}
